const locale = {
    "(area: {measure})": "(plocha: {measure})",
    "(length: {measure})": "(délka: {measure})",
    "# one hash for main heading": "# jedna mřížka pro hlavní nadpis",
    "## two hashes for second heading": "## dvě mřížky pro nadpis druhé úrovně",
    "### three hashes for third heading": "### podnadpis třetí úrovně",
    "**double star for bold**": "**vše mezi dvěma hvězdičkami je tučně**",
    "*single star for italic*": "*vše mezi hvězdičkami bude kurzívou*",
    "--- for a horizontal rule": "--- vytvoří vodorovnou linku",
    "1 day": "1 den",
    "1 hour": "1 hodina",
    "5 min": "5 minut",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Čárkami oddělený seznam čísel, který popisuje vzorek přerušované čáry. Např. «5, 10, 15».",
    "About": "O mapě",
    "Action not allowed :(": "Akce nepovolena :(",
    "Activate slideshow mode": "Aktivovat prezentační mód",
    "Add a layer": "Přidat vrstvu",
    "Add a line to the current multi": "Přidat čáru k současnému multi",
    "Add a new property": "Přidat novou vlastnost",
    "Add a polygon to the current multi": "Přidat polygon k současnému multi",
    "Add image URL": "Přidat URL obrázku",
    "Advanced actions": "Pokročilé akce",
    "Advanced properties": "Pokročilé vlastnosti",
    "All data and settings of the map": "Všechna data a nastavení mapy",
    "All properties are imported.": "Všechny vlastnosti jsou importovány.",
    "Allow interactions": "Povolit interakce",
    "Allow scroll wheel zoom?": "Povolit přibližování kolečkem myši?",
    "always": "vždy",
    "Animated transitions": "Animované přechody",
    "Are you sure you want to clone this map and all its datalayers?": "Určitě chcete vytvořit kopii celé této mapy a všech jejich vrstev?",
    "Are you sure you want to delete this map?": "Jste si jisti, že chcete vymazat tuto celou mapu?",
    "Are you sure you want to delete this property on all the features?": "Určitě chcete smazat tuto vlastnost na všech objektech?",
    "Are you sure you want to restore this version?": "Opravdu si přejete obnovit tuto verzi?",
    "Attach the map to my account": "Připojte mapu k mému účtu",
    "attribution": "autorství",
    "Auto": "Automatická",
    "Automatic": "Automatic",
    "Autostart when map is loaded": "Spustit po načtení mapy",
    "Back to preview": "Zpět na náhled",
    "Background overlay url": "Url překrytí pozadí",
    "Ball": "špendlík",
    "Bring feature to center": "Centruj mapu na objektu",
    "Browse data": "Prohlížet data",
    "by": "od",
    "Cache proxied request": "Požadavek na zástupnou mezipaměť",
    "Caption": "Popisek",
    "Center map on your location": "Přemístit se na mapě na vaši polohu",
    "Change map background": "Změnit pozadí mapy",
    "Change tilelayers": "Změnit pozadí mapy",
    "Change": "Změnit",
    "Choose the data format": "Vyberte formát dat",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth třídy",
    "Choropleth color palette": "Choropleth paleta barev",
    "Choropleth mode": "Choropleth režim",
    "Choropleth property value": "Choropleth hodnota objektu",
    "Choropleth": "Choropleth",
    "Circle": "Kruh",
    "clear": "vymazat",
    "Click last point to finish shape": "Klikněte na poslední bod pro dokončení tvaru",
    "Click to add a marker": "Kliknutím přidáš značku",
    "Click to continue drawing": "Kliknutím můžeš pokračovat v kreslení",
    "Click to edit": "Klikněte pro úpravy",
    "Click to start drawing a line": "Klikněte pro začátek kreslení čáry",
    "Click to start drawing a polygon": "Klikněte pro začátek kreslení polygonu",
    "Clone of {name}": "Klon objektu {name}",
    "Clone this feature": "Vytvoř vlastní kopii této vlastnosti",
    "Clone this map": "Vytvořit vlastní kopii této mapy",
    "Clone": "Klonovat",
    "Close": "Zavřít",
    "Clustered": "Shluková",
    "Clustering radius": "Poloměr shlukování",
    "collapsed": "sbalené",
    "color": "barva",
    "Comma separated list of numbers, including min and max values.": "Seznam čísel oddělených čárkou, včetně minimálních a maximálních hodnot.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Čárkami oddělený seznam vlastností, které se mají použít pro třídění prvků. Chcete-li řazení obrátit, vložte před něj znaménko mínus (-). Např. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Hodnoty oddělené čárkou, tabulátorem, nebo středníkem. předpokládá se SRS WGS84 a jsou importovány jen polohy bodů. Import hledá záhlaví sloupců začínající na \"lat\" nebo \"lon\" a ty považuje za souřadnice (na velikosti písmen nesejde). Ostatní sloupce jsou importovány jako vlastnosti.",
    "Congratulations, your map has been created!": "Gratulujeme, vaše mapa byla vytvořena!",
    "Continue line": "Pokračovat v čáře",
    "Coordinates": "Souřadnice",
    "copy": "kopírovat",
    "Credits": "Autorství",
    "Current map view": "Aktuální zobrazení mapy",
    "Current view instead of default map view?": "Současný pohled namísto výchozího?",
    "Custom background": "Vlastní pozadí",
    "Custom overlay": "Vlastní překryv",
    "dash array": "styl přerušované čáry",
    "Data is browsable": "Data se dají procházet",
    "Datalayers": "Datové vrstvy",
    "Default interaction options": "Výchozí možnosti interakce",
    "Default properties": "Výchozí vlastnosti",
    "Default shape properties": "Výchozí nastavení tvaru",
    "Default view": "Výchozí zobrazení",
    "Default zoom level": "Výchozí přiblížení",
    "Default": "Výchozí",
    "Default: name": "Výchozí: name (název objektu)",
    "Define link to open in a new window on polygon click.": "Definice odkazu, který se otevře v novém okně po kliknutí na polygon.",
    "define": "definovat",
    "Delay between two transitions when in play mode": "Zpoždění mezi dvěma předěly v přehrávacím módu",
    "Delete layer": "Vymazat vrstvu",
    "Delete this feature": "Vymazat objekt",
    "Delete this shape": "Smazat tento tvar",
    "Delete this vertex (Alt+Click)": "Smazat tento bod (Alt+Klik)",
    "Delete": "Vymazat",
    "description": "popis",
    "Direct link": "Přímý odkaz",
    "Directions from here": "Navigovat odsud",
    "Display label": "Zobrazit popisek",
    "Display measure": "Zobrazit měřítko",
    "display name": "zobrazit název",
    "Display on load": "Zobrazit při startu",
    "Display the control to open OpenStreetMap editor": "Zobrazit možnost upravit mapu v OpenStreetMap editoru",
    "Display the embed control": "Zobrazit tlačítko pro sdílení mapy",
    "Display the fullscreen control": "Zobrazit tlačítko pro celoobrazovkový režim",
    "Display the locate control": "Zobrazit tlačítko pro určení polohy",
    "Display the measure control": "Zobrazit tlačítko pro měření vzdálenosti",
    "Display the search control": "Zobrazit vyhledávání",
    "Display the tile layers control": "Zobrazit tlačítko pro změnu mapového podkladu",
    "Display the zoom control": "Zobrazit ovládání přiblížení",
    "Do you want to display a caption bar?": "Chcete zobrazit panel s popiskem?",
    "Do you want to display a minimap?": "Chcete zobrazit minimapu?",
    "Do you want to display a panel on load?": "Chcete při načtení zobrazit panel?",
    "Do you want to display caption menus?": "Chcete zobrazit nabídky s popiskem?",
    "Do you want to display popup footer?": "Chcete v bublině zobrazit navigační panel?",
    "Do you want to display the scale control?": "Chcete zobrazit měřítko mapy?",
    "Do you want to display the «more» control?": "Přejete si zobrazovat ovládací prvek «více»?",
    "Download": "Stažení",
    "Drag to reorder": "Přetáhni pro přeskupení",
    "Draw a marker": "Umístit značku místa",
    "Draw a polygon": "Vyznačit oblast",
    "Draw a polyline": "Nakreslit čáru",
    "Drawing": "Kresba",
    "Drop": "Kapka",
    "Dynamic properties": "Dynamické vlastnosti",
    "Dynamic": "Dynamicky",
    "Edit feature's layer": "Upravit vrstvu objektu",
    "Edit properties in a table": "Upravit vlastnosti v tabulce",
    "Edit the title of the map": "Upravit název mapy",
    "Edit this feature": "Upravit tento objekt",
    "Edit": "Upravit",
    "Embed and link options": "Možnosti vložení a propojení",
    "Embed the map": "Vložit mapu do jiného webu",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Vyprázdnit",
    "Equidistant": "Stejně vzdálené",
    "Error in the overlay URL": "Chyba u URL překryvu dlaždic",
    "Error in the tilelayer URL": "Chyba v URL vrstvy dlaždic",
    "Exit Fullscreen": "Ukončit režim celé obrazovky",
    "expanded": "rozbalené",
    "Extract shape to separate feature": "Vyjmout tvar do samostatného objektu",
    "Feature identifier key": "Identifikační klíč funkce",
    "Feature properties": "Vlastnosti funkce",
    "Fetch data each time map view changes.": "Získat data při každé změně zobrazení mapy.",
    "fill color": "barva výplně",
    "fill opacity": "průhlednost výplně",
    "fill": "výplň",
    "Fit all data": "Přizpůsobení všech dat",
    "Format": "Formát",
    "From zoom": "Maximální oddálení",
    "full backup": "plná záloha",
    "Generic": "Generický",
    "GeoRSS (only link)": "GeoRSS (jen odkaz)",
    "GeoRSS (title + image)": "GeoRSS (titulek + obrázek)",
    "Go to \"{coords}\"": "Přejít na „{coords}“",
    "Go to the homepage": "Přejít na domovskou stránku",
    "Go to «{feature}»": "Jdi na  \"{feature}\"",
    "Heatmap intensity property": "Vlastnost pro intenzitu teplotní mapy",
    "Heatmap radius": "Poloměr teplotní mapy",
    "Heatmap": "Teplotní mapa",
    "height": "výška",
    "Help": "Nápověda",
    "hidden": "skryté",
    "Hide controls": "Skrýt ovládací prvky",
    "Home": "Domů",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak moc zahlazovat a zjednodušovat při oddálení (větší = rychlejší odezva a plynulejší vzhled, menší = přesnější)",
    "icon opacity": "průhlednost ikony",
    "Icon shape": "Tvar ikony",
    "Icon symbol": "Symbol ikony",
    "If false, the polygon or line will act as a part of the underlying map.": "Pokud je hodnota false, polygon nebo linie bude fungovat jako součást podkladové mapy.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe s vlastní výškou (v px): 1{{{https://iframe.url.com|výška}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe s vlastní výškou a šířkou (v px): 1{{{https://iframe.url.com|výška*šířka}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Obrázek s vlastní šířkou (v px): 1{{{https://iframe.url.com|šířka}}}",
    "Image: {{https://image.url.com}}": "Obrázek: 1{{https://obrázek.url.com}}",
    "Import data": "Import dat",
    "Import in a new layer": "Importovat do nové vrstvy",
    "Imports all umap data, including layers and settings.": "Importuje všechy data umapy, včetně vrstev a nastavení",
    "Include full screen link?": "Zahrnout odkaz na celou obrazovku?",
    "Inherit": "výchozí",
    "inherit": "výchozí",
    "Interaction options": "Možnosti interakce",
    "Invalid latitude or longitude": "Neplatná zeměpisná šířka nebo délka",
    "Invalid umap data in {filename}": "Neplatná data umapy v souboru {filename}",
    "Invalid umap data": "Neplatná data umapy",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Použít aktuální zobrazení vrstev",
    "kilometers": "kilometry",
    "km": "km",
    "Label direction": "Směr popisku",
    "Label key": "Tlačítko popisku",
    "Labels are clickable": "Popisky jsou klikatelné",
    "Latest feature": "Nejnovější funkce",
    "Latitude": "Sev. šířka",
    "Layer properties": "Vlastnosti vrstvy",
    "Layer": "Vrstva",
    "Licence": "Licence",
    "licence": "licence",
    "Limit bounds": "Hranice zobrazení",
    "Link to view the map": "Odkaz pro zobrazení mapy",
    "Link to…": "Odkaz na…",
    "Link with text: [[https://example.com|text of the link]]": "Odkaz s textem: [[https://priklad.cz|text odkazu]]",
    "Long credits": "Dlouhý text autorství",
    "Longitude": "Délka",
    "Make main shape": "Učinit hlavním tvarem",
    "Manage layers": "Spravovat vrstvy",
    "Manual": "Ručně",
    "Map background credits": "Autorství pozadí mapy",
    "Map has been attached to your account": "Mapa byla připojena k vašemu účtu",
    "Map has been saved!": "Mapa byla uložena",
    "Map has been starred": "Mapa byla označena hvězdičkou",
    "Map has been unstarred": "Označení mapy hvězdičkou bylo zrušeno",
    "Map user content has been published under licence": "Uživatelská data jsou zveřejněna pod licencí",
    "Map's editors": "Mapoví editoři",
    "Map's owner": "Majitel mapy",
    "max East": "maximálně na Východ",
    "max North": "maximálně na Sever",
    "max South": "maximálně na Jih",
    "max West": "maximálně na Západ",
    "max zoom": "maximální přiblížení",
    "Measure distances": "Měření vzdáleností",
    "Merge lines": "Spojit čáry",
    "mi": "mi",
    "miles": "míle",
    "min zoom": "maximální oddálení",
    "More controls": "Více ovládacích prvků",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Platný název v CSS (např.: Red, Blue nebo #123456)",
    "name": "název",
    "nautical miles": "námořní míle",
    "never": "nikdy",
    "new window": "nové okno",
    "next": "další",
    "NM": "NM",
    "No cache": "Žádná mezipaměť",
    "No licence has been set": "Nebyla nastavena licence",
    "No results": "Žádné výsledky",
    "no": "ne",
    "No.": "Ne.",
    "None": "Žádný",
    "Number of desired classes (default 5)": "Počet požadovaných tříd (výchozí 5)",
    "On the bottom": "Zespod",
    "On the left": "Nalevo",
    "On the right": "Napravo",
    "On the top": "Shora",
    "Only visible layers' data": "Pouze data viditelných vrstev",
    "opacity": "průhlednost",
    "Opacity": "Průhlednost",
    "Open current feature on load": "Otevřít současnou funkci při zatížení",
    "Open link in…": "Otevřít adresu v…",
    "Open share & download panel": "Otevřít panel na sdílení a stahování",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otevři tuto oblast v editoru OpenStreetMap. Toto vám umožní editovat přímo základní mapová data a přispět tak v tvorbě svobodné mapy pro všechny.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Volitelná vlastnost pro výpočet intenzity v teplotní mapě",
    "Optional. Same as color if not set.": "Nepovinné. Stejné jako barva, pokud není nastaveno.",
    "Optional.": "Volitelné.",
    "Override clustering radius (default 80)": "Přepsat shlukovací poloměr (výchozí hodnota 80)",
    "Override heatmap radius (default 25)": "Přepsat poloměr teplotní mapy (výchozí hodnota 25)",
    "parent window": "rodičovské okno",
    "Paste your data here": "Zde vložte svá data",
    "Permalink": "Trvalý odkaz",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Prosíme ujistěte se, že licence je ve shodě s tím jak mapu používáte.",
    "Please choose a format": "Zvolte formát",
    "Please enter the name of the property": "Zadejte prosím název vlastnosti",
    "Please enter the new name of this property": "Zadejte prosím nový název této vlastnosti",
    "Please save the map first": "Prosím, nejprve uložte mapu",
    "Popup (large)": "Popup (velký)",
    "Popup content style": "Styl obsahu popupu",
    "Popup content template": "Šablona obsahu bubliny",
    "Popup shape": "Tvar popupu",
    "Popup": "Popup",
    "Powered by uMap": "Běží na uMap",
    "previous": "předchozí",
    "Problem in the response": "Problém při odpovědi",
    "Properties imported:": "Importované vlastnosti:",
    "Provide an URL here": "Sem vložte odkaz",
    "Proxy request": "Požadavky přes proxy",
    "Quantiles": "Kvantily",
    "Recent": "Nedávné",
    "Remote data": "Vzdálená data",
    "Remove shape from the multi": "Odebrat tvar z multi",
    "Replace layer content": "Nahradit obsah vrstvy",
    "Restore this version": "Obnovit tuto verzi",
    "Save current edits": "Ulož nedávné změny",
    "Save map": "Uložit mapu",
    "Save": "Ulož",
    "Saved center and zoom": "Uložený střed a zoom",
    "Search location": "Vyhledat místo na mapě",
    "Search": "Hledat",
    "Secret edit link:": "Tajný odkaz na úpravy:",
    "See full screen": "Na celou obrazovku",
    "See on OpenStreetMap": "Zobrazit na OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Nastavte na false pro ukrytí této vrstvy z prezentace, prohlížeče dat, vyskakovací navigace...",
    "settings": "nastavení",
    "Shape properties": "Vlastností tvaru",
    "Share and download": "Sdílet a stáhnout",
    "Share this link to open a customized map view": "Sdílet tento odkaz pro otevření přizpůsobeného zobrazení mapy",
    "Short credits": "Krátký text autorství",
    "Short link": "Krátký odkaz",
    "Show this layer in the caption": "Zobrazit tuto vrstvu v nadpisu",
    "Show/hide layer": "Skrytí/zobrazení vrstvy",
    "Side panel": "Boční panel",
    "Simple link: [[https://example.com]]": "Jednoduchý odkaz: [[https://priklad.cz]]",
    "Simplify": "Zjednodušit",
    "Skipping unknown geometry.type: {type}": "Přeskakuji neznámý geometry.type: {type}",
    "Slideshow": "Prezentace",
    "Sort key": "Řadící klávesa",
    "Split line": "Rozdělit čáru",
    "Star this map": "Označit tuto mapu hvězdičkou",
    "Start a hole here": "Začít tady díru",
    "Start slideshow": "Spustit prezentaci",
    "Stop editing": "Přerušit úpravy",
    "Stop slideshow": "Zastavit prezentaci",
    "Street": "Ulice",
    "stroke": "linka",
    "Supported scheme": "Podporované schéma",
    "Supported variables that will be dynamically replaced": "Podporované proměnné, které budou automaticky nahrazeny",
    "Symbol": "Symbol",
    "Table": "Tabulka",
    "Text color for the cluster label": "Barva textu popisku shluku",
    "Text formatting": "Formátování textu",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Název vlastnosti, která se má použít jako popis funkce (např.: \"nom\"). Můžete také použít vlastnosti uvnitř hranatých závorek a použít více než jednu nebo je kombinovat se statickým obsahem (např.: \"&lcub;jméno&rcub; v &lcub;místo&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Název vlastnosti pro použití v popisku jedinečného identifikátoru objektu.",
    "The zoom and center have been modified.": "Přiblížení a střed mapy byly modifikovány",
    "TMS format": "formát TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Pro případ že vzdálený server neumožňuje cross domain (pomalejší)",
    "To zoom": "Maximální přiblížení",
    "Toggle edit mode (⇧+Click)": "Přepnout do editovacího módu (⇧+Klik)",
    "Toggle edit mode": "Přepnout režim úprav",
    "Transfer shape to edited feature": "Přenést tvar do editovaného objektu",
    "Transform to lines": "Převést na čáry",
    "Transform to polygon": "Převést na polygon",
    "Type a place name or coordinates": "Zadejte název místa nebo souřadnice",
    "Type char or paste emoji": "Zadejte znak nebo vložte emoji",
    "Type of layer": "Druh vrstvy",
    "Unable to detect format of file {filename}": "Nepodařilo se detekovat formát souboru {filename}",
    "Untitled layer": "Nepojmenovaná vrstva",
    "Untitled map": "Mapa bez názvu",
    "Update permissions and editors": "Nastavení přístupu a práva editace",
    "Update permissions": "Aktualizace oprávnění",
    "Update who can see and edit the map": "Aktualizujte, kdo může vidět a upravovat mapu.",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Použít současné hranice",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Použijte zástupný text s vlastnostmi objektů mezi složenými závorkami, např. &#123;name&#125; &mdash; budou dynamicky nahrazeny odpovídajícími hodnotami.",
    "User content credits": "Autorství uživatelského obsahu",
    "User interface options": "Nastavení ovládacích prvků mapy",
    "User location": "Poloha uživatele",
    "Verify remote URL": "Ověřit vzdálenou adresu URL",
    "Versions": "Verze",
    "View Fullscreen": "Otevřít přes celou obrazovku",
    "View": "Zobrazit",
    "Visibility: {status}": "Viditelnost: {status}",
    "weight": "šířka linky",
    "Where do we go from here?": "Co všechno teď můžete udělat?",
    "Whether to display or not polygons paths.": "Zda se mají či nemají zobrazovat cesty polygonů.",
    "Whether to fill polygons with color.": "Zda vyplnit polygony barvou.",
    "Who can edit \"{layer}\"": "Kdo může upravovat \"{layer}\"",
    "Who can edit": "Kdo může upravit",
    "Who can view": "Kdo může zobrazit",
    "width": "šířka",
    "Will be displayed in the bottom right corner of the map": "Bude zobrazeno s mapou napravo dole",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Bude zobrazeno v popisu mapy",
    "yes": "ano",
    "Zoom in": "Přiblížit",
    "Zoom level for automatic zooms": "Úroveň přiblížení pro automatické přiblížení",
    "Zoom out": "Oddálit",
    "Zoom to layer extent": "Přizpůsobit přiblížení vrstvě",
    "Zoom to the next": "Skočit na následující",
    "Zoom to the previous": "Skočit na předchozí",
    "Zoom to this feature": "Přiblížit na tento objekt",
    "{area}&#8239;acres": "{area} akry",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} chyb při importu: {message}",
    "{delay} seconds": "{delay} sekund",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} míle",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Upravit název mapy a popisek",
    "Map advanced properties": "Pokročilé vlastnosti mapy",
    "Edit map details": "Podrobnosti mapy",
    "Back to browser": "Zpět na prohlížeč",
    "Toggle size": "Přepnout velikost",
    "Display the caption control": "Zobrazit ovládání popisků",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "Z",
    "Until": "Dokud",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Příklad: klíč1,klíč2|Popisek 2, klíč3|Popisek 3|checkbox",
    "Edit in OpenStreetMap": "Upravit v OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Nelze určit sloupce zeměpisné šířky a délky.",
    "Back to layers": "Zpět na vrstvy",
    "Filters": "Filtry",
    "Comma separated list of properties to use when filtering features by text input": "Čárkami oddělený seznam vlastností pro filtrování objektů podle zadávání textu",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Čárkami oddělený seznam vlastností, které se mají použít pro filtry (např.: můjklíč,jinýklíč). Chcete-li ovládat štítek, přidejte jej za | (např.: můjklíč|Můj klíč,jinýklíč|Jiný klíč). Chcete-li ovládat typ vstupního pole, přidejte jej za další | (např.: můjklíč|Můj klíč|checkbox,jinýklíč|Jiný klíč|datetime). Povolené hodnoty pro typ vstupního pole jsou checkbox (výchozí), radio, number, date a datetime.",
    "Search keys": "Hledat klíče",
    "Filters keys": "Filtry klíčů",
    "Filter data": "Filtrovat data",
    "Search map features…": "Hledat objekty mapy…",
    "Reset all": "Obnovit vše",
    "Open browser": "Otevřete prohlížeč",
    "Open caption": "Otevřete popisky",
    "Your map has been created with an anonymous account!": "Vaše mapa byla vytvořena s anonymním účtem!",
    "Real-time collaboration": "Spolupráce v reálném čase",
    "Cannot parse data": "Nelze zpracovat data",
    "Start typing...": "Začněte psát...",
    "No result": "Žádný výsledek",
    "Data browser": "Prohlížeč dat",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Při zadání adresy URL může uMap zkopírovat vzdálená data do vrstvy nebo přidat tuto adresu URL jako vzdálený zdroj vrstvy. V takovém případě budou data vždy načtena z této adresy URL, a budou tedy aktuální, ale nebude možné je v aplikaci uMap upravovat.",
    "Overpass supported expressions": "Podporované výrazy Overpass",
    "key (eg. building)": "klíč (např. budova)",
    "!key (eg. !name)": "!klíč (např. !název)",
    "key=value (eg. building=yes)": "klíč=hodnota (např. budova=ano)",
    "key!=value (eg. building!=yes)": "klíč!=hodnota (např. budova!=ano)",
    "key~value (eg. name~Grisy)": "klíč~hodnota (např. název~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (např. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Více informací o Overpass syntax",
    "For more complex needs, see": "V případě složitějších potřeb viz",
    "Choose data": "Vyberte data",
    "Choose the format": "Zvolte formát",
    "Choose the layer": "Zvolte vrstvu",
    "Layer name": "Název vrstvy",
    "Choose import mode": "Zvolte režim importu",
    "Copy into the layer": "Zkopírujte do vrstvy",
    "Link to the layer as remote data": "Odkaz na vrstvu jako na vzdálená data",
    "Condition": "Podmínka",
    "key=value or key!=value": "klíč=hodnota nebo klíč!=hodnota",
    "Are you sure you want to delete this rule?": "Opravdu chcete toto pravidlo odstranit?",
    "empty rule": "prázdné pravidlo",
    "Conditional style rules": "Podmíněná pravidla stylu",
    "Add rule": "Přidat pravidlo",
    "Browser: data": "Prohlížeč: data",
    "Browser: layers": "Prohlížeč: vrstvy",
    "Browser: filters": "Prohlížeč: filtry",
    "Enable real-time collaboration": "Umožnit spolupráci v reálném čase",
    "✅ Copied!": "✅ Zkopírováno",
    "Choose a dataset": "Vyberte datovou sadu",
    "Choose this dataset": "Vyberte tuto datovou sadu",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: tematická data z OpenStreetMap",
    "Choose a theme": "Vyberte si téma",
    "Symplify all geometries to points": "Zjednodušte všechny geometrie na body",
    "Choose this data": "Zvolte tato data",
    "Search admin boundary": "Hledat hranici správce",
    "Please choose a theme and a boundary first.": "Nejprve si vyberte téma a hranice.",
    "Expression": "Výraz",
    "Geometry mode": "Režim geometrie",
    "Only geometry centers": "Pouze geometrické středy",
    "Search area": "Oblast hledání",
    "Type area name, or let empty to load data in current map view": "Zadejte název oblasti nebo nechte prázdný pro načtení dat v aktuálním zobrazení mapy.",
    "Data successfully imported!": "Data byla úspěšně importována!",
    "Clear data": "Vymazat data",
    "Remove layers": "Odstranit vrstvy",
    "Categorized": "Kategorizováno",
    "Alphabetical": "Abecední pořadí",
    "Category property": "Vlastnosti kategorie",
    "Color palette": "Barevná paleta",
    "Categories": "Kategorie",
    "Comma separated list of categories.": "Seznam kategorií oddělených čárkou.",
    "Categories mode": "Režim kategorií",
    "Remove filter for this column": "Odebrat filtr pro tento sloupec",
    "Add filter for this column": "Přidat filtr pro tento sloupec",
    "Rename this column": "Přejmenovat tento sloupec",
    "Delete this column": "Smazat tento sloupec",
    "Name “{name}” should not contain a dot.": "Název \"{name}\" by neměl obsahovat tečku.",
    "This name already exists: “{name}”": "Tento název již existuje: \"{name}\"",
    "Delete selected rows": "Smazat vybrané řádky",
    "Found {count} rows. Are you sure you want to delete all?": "Nalezeno {count} řádků. Určitě chcete smazat všechny?",
    "Expression is empty": "Výraz je prázdný",
    "OK": "OK",
    "Cancel": "Zrušit",
    "Attach map to a team": "Připojit mapu k týmu",
    "Display the polygon inverted": "Zobrazit polygon invertovaně",
    "Proportional circles": "Proporcionální kružnice",
    "Property name to compute circles": "Název vlastnosti pro výpočet kruhů",
    "Min circle radius": "Minimální poloměr kružnice",
    "Max circle radius": "Maximální poloměr kružnice",
    "Display the open browser control": "Zobrazit ovládací prvek otevřeného prohlížeče",
    "Copy as GeoJSON": "Zkopírovat jako GeoJSON",
    "Please zoom in to edit the geometry": "Chcete-li upravit geometrii, přibližte si ji",
    "New map": "Nová mapa",
    "My maps": "Moje mapy",
    "My teams": "Moje týmy",
    "My profile": "Můj profil",
    "Type new owner's username": "Zadejte uživatelské jméno nového vlastníka",
    "Type editor's username": "Zadejte uživatelské jméno editora",
    "Map": "Mapa",
    "Manage collaborators": "Spravovat spolupracovníky",
    "show/hide all layers": "zobrazit/skrýt všechny vrstvy",
    "zoom to data extent": "přiblížit na rozsah dat",
    "download visible data": "stáhnout viditelná data",
    "Import helpers": "Pomocníci pro import",
    "Import helpers will fill the URL field for you.": "Pomocníci pro import vyplní pole URL za vás.",
    "Wikipedia": "Wikipedie",
    "Save draft": "Uložit koncept",
    "No data has been found for import": "Nebyla nalezena žádná data pro import",
    "Successfully imported {count} feature(s)": "Počet úspěšně importovaných prvků: {count}",
    "Disconnected": "Odpojeno",
    "You must be logged in": "Musíte být přihlášen",
    "on hover": "při najetí",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Nelze načíst vzdálená data pro vrstvu \"{layer}\" s url \"{url}\".",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Nelze analyzovat vzdálená data pro vrstvu \"{layer}\" s url \"{url}\".",
    "Import failed: invalid data": "Import selhal: neplatná data",
    "Anonymous": "Anonymní",
    "created at {date}": "vytvořeno v {date}",
    "modified at {date}": "upraveno v {date}",
    "Default zoom": "Výchozí přiblížení",
    "Default latitude": "Výchozí zeměpisná šířka",
    "Default longitude": "Výchozí zeměpisná délka",
    "Edit map default view": "Upravit výchozí zobrazení mapy",
    "Use current center and zoom": "Použít aktuální střed a přiblížení",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("cs_CZ", locale)
L.setLocale("cs_CZ")
