const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# አንድ ፓውንድ ምልክት ለዋናው አርእስት",
    "## two hashes for second heading": "## ሁለት ፓውንድ ምልክቶች ለንዑስ አርእስቱ",
    "### three hashes for third heading": "### ሶስት ፓውንድ ምልክቶች ለሶስተኛው ደረጃ አርእስት",
    "**double star for bold**": "** ሁለት ኮኮብ ለማወፈር **",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "ስለ",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "ሌየር ጨምር",
    "Add a line to the current multi": "ላሁኑ ብዝሀ መስመር ጨምር",
    "Add a new property": "አዲስ ባህርይ ጨምር",
    "Add a polygon to the current multi": "ላሁኑ ብዝሀ ፖሊጎን ጨምር",
    "Add image URL": "Add image URL",
    "Advanced actions": "ተጨማሪ ተግባራት",
    "Advanced properties": "ተጨማሪ ባህርያት",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "ሁሉም ባህርያት መጥተዋል",
    "Allow interactions": "Allow interactions",
    "Allow scroll wheel zoom?": "በማውሱ መሀከለኛ ተሽከርካሪ ማጉላት ይፈቀድ?",
    "always": "always",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "እርግጠኛ ነዎት ይህንን ካርታ እና ሁሉንም የመረጃ ገጾች ማባዛት ይፈልጋሉ?",
    "Are you sure you want to delete this map?": "እርግጠኛ ነዎት ይህንን ካርታ መሰረዝ ይፈልጋሉ?",
    "Are you sure you want to delete this property on all the features?": "እርግጠኛ ነህ ይህንንባህርይ ከሁሉም ፊቸሮች ላይ መሰረዝ ትችላለህ",
    "Are you sure you want to restore this version?": "እርግጠኛ ነዎት ወደዚህኛው እትም መመለስ ይልጋሉ?",
    "Attach the map to my account": "Attach the map to my account",
    "attribution": "አትሪብዩሽን",
    "Auto": "አውቶ",
    "Automatic": ".",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "ኳስ",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "መረጃዎቹን አሥሥ",
    "by": "በ",
    "Cache proxied request": "Cache proxied request",
    "Caption": "ካፕሽን",
    "Center map on your location": "መገኛዎን የሚያሳየውን ካርታ ወደ መሀል ያድርጉ",
    "Change map background": "የካርታውን የጀርባ ገፅታ ይቀይሩ",
    "Change tilelayers": "የታይልሌየሩን",
    "Change": "Change",
    "Choose the data format": "የረጃውን ፎርማት ቀይር",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "አክብብ/ክብ",
    "clear": "clear",
    "Click last point to finish shape": "ቅርፁን ለማስጨረስ የመጨረሻውን ነጥብ ጠቅ ያድርጉ",
    "Click to add a marker": "መለያ ለመጨመር ጠቅ አድርግ",
    "Click to continue drawing": "መሳል ለመቀጠል ጠቅ አድርግ",
    "Click to edit": "ለማረም ጠቅ አድርግ",
    "Click to start drawing a line": "መስመር ለመሳል ጠቅ አድርግ",
    "Click to start drawing a polygon": "ፖሊጎን ለመሳል ጠቅ አድርግ",
    "Clone of {name}": "የ {name} ድቃይ",
    "Clone this feature": "Clone this feature",
    "Clone this map": "ይህንን ካርታ አባዛ",
    "Clone": "አዳቅል",
    "Close": "ዝጋ",
    "Clustered": "ክለስተርድ",
    "Clustering radius": "ክለስተሪንግ ራዲየስ",
    "collapsed": "collapsed",
    "color": "ከለር",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "በኮማ፣ታብ፣ግማሽኮለን የተከፋፈሉ ውጤቶች። SRSWG84 ተመላክቷል። የነጥብ ጂኦሜትሪዎች ብቻ መጥተዋል። የማምጣት ሂደቱ የኮለምን ሄደሮችን በማሰስ «ላቲትዩድ» እና «ሎንጊትዩድ» የሚሉትን ቃላት መኖር ከመጀመሪያው በመነሳት ያጣራል። ሁሉም ኮለምኖች እንደባህርይ መጥተዋል።",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "መስመሩን ቀጥል",
    "Coordinates": "ኮርዲኔቶች",
    "copy": "copy",
    "Credits": "ክሬዲቶች",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "ከዲፎልት የካርታ እይታው ፋንታ የአሁኑ እይታ?",
    "Custom background": "የተስተካከለ ጀርባ",
    "Custom overlay": "Custom overlay",
    "dash array": "ዳሽ አሬይ",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "Default interaction options",
    "Default properties": "ዲፎልት ባህርያት",
    "Default shape properties": "Default shape properties",
    "Default view": "Default view",
    "Default zoom level": "Default zoom level",
    "Default": "ዋና ምርጫ (ዲፎልት)",
    "Default: name": "ዲፎልት፡ ስም",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "define",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Delete layer",
    "Delete this feature": "ይህንን ፊቸር ሰርዝ",
    "Delete this shape": "ይህንን ቅርፅ ሰርዝ",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "ሰርዝ",
    "description": "መገለጫ",
    "Direct link": "Direct link",
    "Directions from here": "ከዚህ የሚነሱ አቅጣጫዎች",
    "Display label": "Display label",
    "Display measure": "Display measure",
    "display name": "ስሙን አሳይ",
    "Display on load": "በመጫን ላይ እያለ አሳይ",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "የካፕሽን ባሩን ማሳየት ትፈልጋለህ?",
    "Do you want to display a minimap?": "ትንሿን ካርታ ማሳየት ይፈልጋሉ?",
    "Do you want to display a panel on load?": "ፓኔሉ በመጫን ላይ እያለ ማሳየት ትፈልጋለህ?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "ፖፕ አፕ ፉተሩን ማሳየት ይፈልጋሉ?",
    "Do you want to display the scale control?": "የመጠን መቆጣጠሪያውን ማሳየት ይፈልጋሉ?",
    "Do you want to display the «more» control?": "የ «ተጨማሪ» መቆጣጠሪያውን ማሳየት ትፈልጋለህ",
    "Download": "Download",
    "Drag to reorder": "Drag to reorder",
    "Draw a marker": "መለያ ሳል",
    "Draw a polygon": "ፖሊጎን ሳል",
    "Draw a polyline": "ባለነጠላ መስመር ሳል",
    "Drawing": "Drawing",
    "Drop": "ጣል",
    "Dynamic properties": "ዳይናሚክ ባህርያት",
    "Dynamic": "ዳይናሚክ",
    "Edit feature's layer": "የፊቸሩን ሌይር አርም",
    "Edit properties in a table": "በሰንጠረዡ ውስጥ ያሉትን ባህርያት አርም",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "ይህንን ፊቸር አርም",
    "Edit": "አርም",
    "Embed and link options": "Embed and link options",
    "Embed the map": "ካርታውን አካትት",
    "Emoji & Character": "Emoji & Character",
    "Empty": "ባዶ",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "በታይልሌየሩ የድረ-ገፅ መገኛ ላይ ስህተት ተፈጥሯል",
    "Exit Fullscreen": "Exit Fullscreen",
    "expanded": "expanded",
    "Extract shape to separate feature": "ፊቸሩን ለመለየት ቅርፁን ነጥለህ አውጣ",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "ከለር ሙላ",
    "fill opacity": "ኦፓሲቲውን ሙላ",
    "fill": "ሙላ",
    "Fit all data": "Fit all data",
    "Format": "ፎርማት",
    "From zoom": "ከዙም",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (ሊንክ ብቻ)",
    "GeoRSS (title + image)": "GeoRSS (መጠሪያ + ምስል)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "ወደ «{feature}» ተመለስ",
    "Heatmap intensity property": "የሙቀት ካርታ ኢንቴንሲቲ ባህርይ",
    "Heatmap radius": "የሙቀት ካርታ ራዲየስ",
    "Heatmap": "የሙቀት ካርታ",
    "height": "ቁመት",
    "Help": "እርዳታ",
    "hidden": "hidden",
    "Hide controls": "መቆጣጠሪያዎቹን ደብቅ",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "በእያንዳንዱ የዙም መጠን ፖሊላይኑን ምን ያህል ያቃልል (ብዙ = ጥሩ አገልግሎት እና ጥሩ መልክ፣ ትንሽ = ይበልጥ ትክክለኛ)",
    "icon opacity": "icon opacity",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "መረጃ አምጣ",
    "Import in a new layer": "አዲስ ሌየር አምጣ",
    "Imports all umap data, including layers and settings.": "ሌየር እና ሁኔታዎቹን ጨምሮ ሁሉንም የዩማፕ መረጃ ያመጣል",
    "Include full screen link?": "ሙሉ ስክሪን ሊክን ያካትት?",
    "Inherit": "ውረስ",
    "inherit": "ውረስ",
    "Interaction options": "Interaction options",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "ያልተፈቀደ የዩማፕ መረጃ በ {filename} ውስጥ",
    "Invalid umap data": "ያልተፈቀደ የዩማፕ መረጃ",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "በወቅቱ የሚታየውን ሌየር አቆይ",
    "kilometers": "kilometers",
    "km": "km",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "Latest feature": "Latest feature",
    "Latitude": "ላቲትዩድ",
    "Layer properties": "የሌየር ባህርያት",
    "Layer": "ሌየር",
    "Licence": "ፈቃድ",
    "licence": "ፈቃድ",
    "Limit bounds": "መድረሻዎቹን ምረጥ",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link to…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "ክሬዲቶች በመጫን ላይ",
    "Longitude": "ሎንጊትዩድ",
    "Make main shape": "ዋና ቅርፅ አድርግ",
    "Manage layers": "Manage layers",
    "Manual": "Manual",
    "Map background credits": "የካርታ የጀርባ ክሬዲትስ",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "ካርታው ተቀምጧል/ድኗል",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "የካርታ ይዘት በሚከተለው ፈቃድ አማካኝነት ታትሟል",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "max East": "በምስራቅ ከፍተናው",
    "max North": "በደቡብ ከፍተኛው",
    "max South": "በሰሜን ከፍተኛው",
    "max West": "በምዕራብ ከፍተኛው",
    "max zoom": "የመጨረሻው ዙም",
    "Measure distances": "Measure distances",
    "Merge lines": "መስመሮችን ቀላቅል",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "ትንሹ ዙም",
    "More controls": "ተጨማሪ መቆጣጠሪያዎች",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "name": "ስም",
    "nautical miles": "nautical miles",
    "never": "never",
    "new window": "new window",
    "next": "ቀጥሎ",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "ምንም ፈቃድ አልተሰጠም",
    "No results": "No results",
    "no": "አይደለም",
    "No.": "No.",
    "None": "ምንም",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "ኦፓሲቲ",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Open link in…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "ለOpernStreetMap ይበልጥ ትክክል ይሆነ መረጃ ለመስጠ የካርታውን ኤክስቴንት በካርታ ማረሚያ ክፈት",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "ለሙቀት ካርታው ባህርይ አማራጭ ኢንቴንሲቲ",
    "Optional. Same as color if not set.": "አማራጭ፣ ካልተመረጠለት እንደቀለሙ የሚሆን",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "የራዲየስ ክለስተሪንግ አልፈህ ሂድ (ዲፎልት 80)",
    "Override heatmap radius (default 25)": "የሙቀት ካርታውን ራዲየስ አልፈህ ሂድ (ዲፎልት 25)",
    "parent window": "parent window",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "እባክዎ ፈቃዱ እስርዎ ሊጠቀሙ ካሉበት አገልግሎት ጋር መጣጣሙን ያረጋግጡ",
    "Please choose a format": "እባክዎ ፎርማት ይምረጡ",
    "Please enter the name of the property": "እባክዎ የባህርይውን ስም ያስገቡ",
    "Please enter the new name of this property": "እባክዎን አዲሱን የባህርይውን ስም ያስገቡ",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "የፖፕ-አፕ ኮንቴንት ተምሳሌ",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "ቀድሞ",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "ባህርያት መጥተዋል",
    "Provide an URL here": "የድረገፁን መገኛ አድራሻ ያስገቡ",
    "Proxy request": "የፕሮክሲ ጥያቄ",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "ሪሞት ዳታ",
    "Remove shape from the multi": "ከብዝሀው ላይ ቅርፁን አስወግድ",
    "Replace layer content": "Replace layer content",
    "Restore this version": "ይህንን እትም መልስ",
    "Save current edits": "የአሁኑን እርማቶች አስቀምጥ/አድን",
    "Save map": "Save map",
    "Save": "አድን/አስቀምጥ",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Search location",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "ሙሉውን ስክሪን ተመልከት",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Shape properties",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "አጭር ክሬዲት",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "ሌየሩን አሳይ/ደብቅ",
    "Side panel": "የጎን ፓኔል",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Simplify",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "ስላይድሾው",
    "Sort key": "Sort key",
    "Split line": "መስመሩን ክፈል",
    "Star this map": "Star this map",
    "Start a hole here": "እዚህ ጋር ቀዳዳ ጀምር",
    "Start slideshow": "ስላይድሾውን አስጀምር",
    "Stop editing": "ማረም አቁም",
    "Stop slideshow": "ስላይድሾውን አስቁም",
    "Street": "Street",
    "stroke": "ሳል/ጫር",
    "Supported scheme": "የሚደገፉ ስኪሞች",
    "Supported variables that will be dynamically replaced": "ዳይናሚካሊ የሚቀየሩ የሚደገፉ ቫርያብሎች",
    "Symbol": "Symbol",
    "Table": "ሰንጠረዥ",
    "Text color for the cluster label": "የክላስተሩን ሌብ ፅሑፍ ከለር",
    "Text formatting": "ፅሁፍ ማስተካከያ",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "ቲ.ኤም.ኤስ. ፎርማት",
    "To use if remote server doesn't allow cross domain (slower)": "ሪሞት ሰርቨሩ የዶሜይን ልውውጥን የማይፈቅድ ከሆነ ይህን ለመጠቀም (አዝጋሚ)",
    "To zoom": "ለማጉላት",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "ቅርፁን ወደ ታረመ ፊቸር አስተላልፍ",
    "Transform to lines": "ወደመስመር ቀይር",
    "Transform to polygon": "ወደፖሊጎን ቀይር",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "የሌየሩ ዓይነት",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "ያልተሰየመ ሌየር",
    "Untitled map": "ያለተሰየመ ካርታ",
    "Update permissions and editors": "ፍቃዶችን እና አራሚዎችን አሻሽል",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "የድረ-ገፅ መገኛ",
    "URL": "URL",
    "Use current bounds": "የአሁንኖቹን መደረሻዎች ተጠቀም",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "በቅንፎች መሀከል የፊቸር ባህርያት ያላቸው ቦታያዦችን ተጠቀም፣ ለምሳሌ &#123;name&#125; ዳይናሚካሊ በተቀራራቢ ዋጋችወ ይተካሉ",
    "User content credits": "የይዘቱን ክሬዲቶች ተጠቀም",
    "User interface options": "የኢንተርፌስ ምርጫዎች",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "እትሞች",
    "View Fullscreen": "View Fullscreen",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "ክብደት",
    "Where do we go from here?": "ከዚህ ቀጥሎ ወደየት ነው የምንሄደው?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "width": "ጎን",
    "Will be displayed in the bottom right corner of the map": "ከታች በቀኝ ኮርነሩ ላይ ይታያል",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "በካርታው ካፕሽን ላይ እንዲታይ ይደረጋል",
    "yes": "አዎን",
    "Zoom in": "አጉላ",
    "Zoom level for automatic zooms": "አውቶማቲክ ዙሞች የሚጎሉበት መጠን",
    "Zoom out": "አርቅ",
    "Zoom to layer extent": "የሌየሩ ኤክስቴንት ድረስ አጉላ",
    "Zoom to the next": "ወደ ሚቀጥለው አጉላ",
    "Zoom to the previous": "ቀደም ወዳለው አጉላ",
    "Zoom to this feature": "ፊቸሩ ድረስ አጉላ",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("am_ET", locale)
L.setLocale("am_ET")
