const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# en fyrkant för huvudrubrik",
    "## two hashes for second heading": "## två fyrkanter för andra rubrik",
    "### three hashes for third heading": "### tre fyrkanter för tredje rubrik",
    "**double star for bold**": "**dubbla stjärntecken för fetstil**",
    "*single star for italic*": "*en asterisk för kursivt*",
    "--- for a horizontal rule": "--- för en vågrät linje",
    "1 day": "1 dag",
    "1 hour": "1 timme",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommaseparerad lista med nummer som definierar mönstret för den streckade linjen. Ex: \"5, 10, 15\"",
    "About": "Om kartan",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Aktivera bildspelsläge",
    "Add a layer": "Lägg till lager",
    "Add a line to the current multi": "Lägg till en linje till aktuell multi",
    "Add a new property": "Lägg till en ny egenskap",
    "Add a polygon to the current multi": "Lägg till en polygon till aktuell multi",
    "Add image URL": "Add image URL",
    "Advanced actions": "Avancerade åtgärder",
    "Advanced properties": "Avancerade egenskaper",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Alla attribut importeras.",
    "Allow interactions": "Tillåt interaktion",
    "Allow scroll wheel zoom?": "Tillåt zoom med musens rullhjul?",
    "always": "alltid",
    "Animated transitions": "Animerade övergångar",
    "Are you sure you want to clone this map and all its datalayers?": "Är du säker på att du vill skapa en kopia av kartan och alla datalager?",
    "Are you sure you want to delete this map?": "Är du säker på att du vill radera denna karta?",
    "Are you sure you want to delete this property on all the features?": "Är du säker på att du vill radera denna egenskap för alla objekt?",
    "Are you sure you want to restore this version?": "Är du säker på att du vill återställa till den här versionen?",
    "Attach the map to my account": "Koppla kartan till mitt konto",
    "attribution": "attribution",
    "Auto": "Automatiskt",
    "Automatic": "Automatisk",
    "Autostart when map is loaded": "Starta automatiskt när kartan lästs in.",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Knappnål",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Bläddra i datat",
    "by": "av",
    "Cache proxied request": "Cachelagra proxyförfrågan",
    "Caption": "Sidfotsfält",
    "Center map on your location": "Centrera kartan till din plats",
    "Change map background": "Ändra kartbakgrund",
    "Change tilelayers": "Byt bakgrundskarta",
    "Change": "Change",
    "Choose the data format": "Välj dataformat",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Cirkel",
    "clear": "återställ",
    "Click last point to finish shape": "Klicka på sista punkten för att slutföra formen",
    "Click to add a marker": "Klicka för att lägga till en markör",
    "Click to continue drawing": "Klicka för att fortsätta rita",
    "Click to edit": "Klicka för att redigera",
    "Click to start drawing a line": "Klicka för att börja rita en linje",
    "Click to start drawing a polygon": "Klicka för att börja rita en polygon",
    "Clone of {name}": "Kopia av {name}",
    "Clone this feature": "Kopiera detta objekt",
    "Clone this map": "Skapa en kopia av kartan",
    "Clone": "Duplicera",
    "Close": "Stäng",
    "Clustered": "Kluster",
    "Clustering radius": "Klusterradie",
    "collapsed": "minimerad",
    "color": "färg",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabb eller semikolon separerade värden. SRS WGS84 är underförstått. Bara punktgeometrier importeras. Importen letar kolumnrubriker som startar med «lat» eller «lon», ej skiftlägeskänslig. Övriga kolumner importeras som attribut.",
    "Congratulations, your map has been created!": "Grattis, din karta har skapats!",
    "Continue line": "Fortsätt linjen",
    "Coordinates": "Koordinater",
    "copy": "copy",
    "Credits": "Upphov och erkännanden",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Nuvarande vy istället för den förinställda vyn?",
    "Custom background": "Anpassad bakgrund",
    "Custom overlay": "Custom overlay",
    "dash array": "streckad linje-stil",
    "Data is browsable": "Data är tillgängligt för bläddring",
    "Datalayers": "Datalayers",
    "Default interaction options": "Förinställda alternativ för interaktion",
    "Default properties": "Standardegenskaper",
    "Default shape properties": "Förinställda formategenskaper",
    "Default view": "Default view",
    "Default zoom level": "Förvald zoomnivå",
    "Default": "Förvalt värde",
    "Default: name": "Namn förvalt",
    "Define link to open in a new window on polygon click.": "Sätt länk att öppna i ett nytt fönster vid klick.",
    "define": "anpassa",
    "Delay between two transitions when in play mode": "Tid mellan övergångar i uppspelningsläge",
    "Delete layer": "Radera lager",
    "Delete this feature": "Radera objektet",
    "Delete this shape": "Radera figuren",
    "Delete this vertex (Alt+Click)": "Radera noden (Alt+klick)",
    "Delete": "Radera",
    "description": "beskrivning",
    "Direct link": "Direktlänk",
    "Directions from here": "Vägbeskrivning härifrån",
    "Display label": "Visa etikett",
    "Display measure": "Visa mått",
    "display name": "namn",
    "Display on load": "Visa vid uppstart",
    "Display the control to open OpenStreetMap editor": "Visa knapp för att öppna OpenStreetMap redigerare",
    "Display the embed control": "Visa verktyg för att bädda in och dela",
    "Display the fullscreen control": "Visa verktyg för fullskärm",
    "Display the locate control": "Visa lokaliseringsverktyg",
    "Display the measure control": "Visa mätverktyg",
    "Display the search control": "Visa sökverktyg",
    "Display the tile layers control": "Visa verktyg för bakgrundskarta (tiles)",
    "Display the zoom control": "Visa zoomverktyg",
    "Do you want to display a caption bar?": "Vill du visa ett sidfotsfält?",
    "Do you want to display a minimap?": "Vill du visa en minikarta?",
    "Do you want to display a panel on load?": "Vill du visa en panel vid uppstart?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Vill du visa en sidfot-popup?",
    "Do you want to display the scale control?": "Vill du visa skalstocken?",
    "Do you want to display the «more» control?": "Vill du visa panelen med \"Fler verktyg\"?",
    "Download": "Ladda ned",
    "Drag to reorder": "Dra för att sortera om",
    "Draw a marker": "Rita en markör",
    "Draw a polygon": "Rita en polygon",
    "Draw a polyline": "Rita en multilinje",
    "Drawing": "Drawing",
    "Drop": "Dropp-nål",
    "Dynamic properties": "Dynamiska egenskaper",
    "Dynamic": "Dynamisk",
    "Edit feature's layer": "Redigera objektets lager",
    "Edit properties in a table": "Redigera attribut i en tabell",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Redigera objektet",
    "Edit": "Redigera",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Bädda in kartan",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Töm",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Fel i webbadressen för bakgrundskartan (tile-lagret)",
    "Exit Fullscreen": "Lämna helskärmsläge",
    "expanded": "utökad",
    "Extract shape to separate feature": "Extrahera figuren till separat objekt",
    "Feature identifier key": "Unik nyckel för objekt",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Hämta data varje gång kartvisningen ändras.",
    "fill color": "fyllnadsfärg",
    "fill opacity": "fyllsynlighet",
    "fill": "fyll",
    "Fit all data": "Fit all data",
    "Format": "Format",
    "From zoom": "Från zoom",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (enbart länk)",
    "GeoRSS (title + image)": "GeoRSS (titel + bild)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Gå till «{feature}»",
    "Heatmap intensity property": "Värmekartans intensitet",
    "Heatmap radius": "Värmekartans radie",
    "Heatmap": "Värmekarta",
    "height": "höjd",
    "Help": "Hjälp",
    "hidden": "dold",
    "Hide controls": "Dölj verktygsfälten",
    "Home": "Hem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hur mycket ska polygoner och multilinjer förenklas vid olika zoom-nivåer? (Mer = bättre prestanda och mjukare utseende, Mindre = mer exakt)",
    "icon opacity": "Ikonsynlighet",
    "Icon shape": "Ikonform",
    "Icon symbol": "Ikonsymbol",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "IFrame (inbäddad html-ram)",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Importera data",
    "Import in a new layer": "Importera till ett nytt lager",
    "Imports all umap data, including layers and settings.": "Importerar allt uMap data, inklusive lager och inställningar.",
    "Include full screen link?": "Inkludera länk till fullskärmssida?",
    "Inherit": "Ärv",
    "inherit": "ärv",
    "Interaction options": "Alternativ för interaktion",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Ogiltigt uMap-data i {filename}",
    "Invalid umap data": "Ogiltigt uMap-data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Bevara nuvarande synliga lager",
    "kilometers": "kilometer",
    "km": "km",
    "Label direction": "Riktning för etikett",
    "Label key": "Etikettnyckel",
    "Labels are clickable": "Klickbara etiketter",
    "Latest feature": "Latest feature",
    "Latitude": "Latitud",
    "Layer properties": "Lageregenskaper",
    "Layer": "Lager",
    "Licence": "Licens",
    "licence": "licens",
    "Limit bounds": "Begränsa visningsområdet",
    "Link to view the map": "Link to view the map",
    "Link to…": "Länk till…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Upphov och erkännanden (sidfotsfält)",
    "Longitude": "Longitud",
    "Make main shape": "Gör huvudformen",
    "Manage layers": "Hantera lager",
    "Manual": "Manual",
    "Map background credits": "Bakgrundskartans upphov och erkännanden",
    "Map has been attached to your account": "Kartan har kopplats till ditt konto.",
    "Map has been saved!": "Kartan har sparats!",
    "Map has been starred": "Kartan har stjärnmärkts",
    "Map has been unstarred": "Stjärnmärkningen har tagits bort ",
    "Map user content has been published under licence": "Kartan användarinnehåll har publicerats under licens",
    "Map's editors": "Kartans redaktörer",
    "Map's owner": "Kartans ägare",
    "max East": "max Öst",
    "max North": "max Nord",
    "max South": "max Syd",
    "max West": "max Väst",
    "max zoom": "maxgräns zoom",
    "Measure distances": "Mät avstånd",
    "Merge lines": "Sammanfoga linjer",
    "mi": "miles",
    "miles": "engelska mil",
    "min zoom": "minimigräns zoom",
    "More controls": "Fler verktyg",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Giltigt CSS värde krävs (ex: DarkBlue eller #123456)",
    "name": "namn",
    "nautical miles": "nautiska mil",
    "never": "aldrig",
    "new window": "nytt fönster",
    "next": "nästa",
    "NM": "M",
    "No cache": "Ingen cache",
    "No licence has been set": "Ingen licens har valts.",
    "No results": "Inga träffar tyvärr. Har du stavat rätt?",
    "no": "nej",
    "No.": "No.",
    "None": "Ingen",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Under",
    "On the left": "Till vänster",
    "On the right": "Till höger",
    "On the top": "Ovanför",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "synlighet",
    "Opacity": "Synlighet",
    "Open current feature on load": "Öppna nuvarande objekt vid uppstart",
    "Open link in…": "Öppna länk med...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Öppna detta kartområde i en redigerare för att bidra med mer och bättre data till OpenStreetMap.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valfritt intensitetsläge för värmekartan",
    "Optional. Same as color if not set.": "Valfritt. Annars samma som färg ovan.",
    "Optional.": "Valfri.",
    "Override clustering radius (default 80)": "Åsidosätt kluster radie (80 förvalt)",
    "Override heatmap radius (default 25)": "Åsidosätt värmekartans radie (25 förvalt)",
    "parent window": "föräldrafönster",
    "Paste your data here": "Klistra in data här",
    "Permalink": "Permanent länk",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Säkerställ att din användning av datat överensstämmer med dess licens eller upphovsrätt.",
    "Please choose a format": "Välj ett format",
    "Please enter the name of the property": "Ange namnet på egenskapen",
    "Please enter the new name of this property": "Ange det nya namnet för den här egenskapen",
    "Please save the map first": "Spara kartan först, tack &#128521;",
    "Popup (large)": "Popup (stor)",
    "Popup content style": "Innehållsstil för popupfönster",
    "Popup content template": "Mall för popup-innehåll",
    "Popup shape": "Popup format",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "föregående",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Attribut som importeras:",
    "Provide an URL here": "Ange en webbadress",
    "Proxy request": "Proxyförfrågan",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Fjärrdata",
    "Remove shape from the multi": "Radera figuren från aktuell multi",
    "Replace layer content": "Ersätt lagrets innehåll",
    "Restore this version": "Återställ denna version",
    "Save current edits": "Spara nuvarande ändringar",
    "Save map": "Save map",
    "Save": "Spara",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Sök plats",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Öppna i fullskärm",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Slå av för att dölja lagret från bilspelsvisning, databläddrare, popup-navigering etc",
    "settings": "settings",
    "Shape properties": "Formategenskaper",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Upphov och erkännanden (kort)",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Visa/dölj lager",
    "Side panel": "Sidopanel",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Förenkla",
    "Skipping unknown geometry.type: {type}": "Okänd geometrityp ignoreras: {type}",
    "Slideshow": "Bildspelsläge",
    "Sort key": "Sorteringsnyckel",
    "Split line": "Dela upp linje",
    "Star this map": "Stjärnmärk kartan",
    "Start a hole here": "Infoga ett hål här",
    "Start slideshow": "Starta bildspel",
    "Stop editing": "Avsluta redigering",
    "Stop slideshow": "Stoppa bildspel",
    "Street": "Street",
    "stroke": "streck",
    "Supported scheme": "Schema som stöds",
    "Supported variables that will be dynamically replaced": "Variabler som stöds att ersättas dynamiskt",
    "Symbol": "Symbol",
    "Table": "Tabell",
    "Text color for the cluster label": "Textfärg för klusteretiketten",
    "Text formatting": "Textformatering",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Egenskapen att använda som unik nyckel för objekten (ex: \"id\")",
    "The zoom and center have been modified.": "Zoom och centrering har ändrats.",
    "TMS format": "TMS format",
    "To use if remote server doesn't allow cross domain (slower)": "Att använda om fjärrservern inte tillåter gränsöverskridande domäner (långsammare)",
    "To zoom": "Till zoom",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Överför format till redigerat objekt",
    "Transform to lines": "Transformera till linjer",
    "Transform to polygon": "Transformera till polygon",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Lagertyp",
    "Unable to detect format of file {filename}": "Misslyckades att känna igen filformatet på filen {filename}",
    "Untitled layer": "Namnlöst lager",
    "Untitled map": "Namnlös karta",
    "Update permissions and editors": "Uppdatera behörigheter och redaktörer",
    "Update permissions": "Uppdatera behörigheter",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Använd nuvarande visningsgränser",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Använd platshållare med objektattribut i klammerparenteser, ex. &#123;namn&#125;. De ersätts dynamiskt med objektets motsvarande värde.",
    "User content credits": "Användarinnehållets upphov och erkännanden",
    "User interface options": "Alternativ för användargränssnitt",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versioner",
    "View Fullscreen": "Visa fullskärm",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "tjocklek",
    "Where do we go from here?": "Hela världen ligger öppen. Sluta aldrig lära, utforska och dela med dig. Vart tar vi vägen idag?",
    "Whether to display or not polygons paths.": "Om polygonens konturlinje ska ritas ut eller inte.",
    "Whether to fill polygons with color.": "Om polygonens yta ska fyllas med färg.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Vem kan redigera",
    "Who can view": "Vem kan visa",
    "width": "bredd",
    "Will be displayed in the bottom right corner of the map": "Visas i nedre högra hörnet av kartan",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Visas i sidfotsfältet under kartan",
    "yes": "ja",
    "Zoom in": "Zooma in",
    "Zoom level for automatic zooms": "Zoomnivå för automatisk zoom",
    "Zoom out": "Zooma ut",
    "Zoom to layer extent": "Zooma till lagrets omfång",
    "Zoom to the next": "Panorera till nästa",
    "Zoom to the previous": "Panorera till föregående",
    "Zoom to this feature": "Zooma till detta objekt",
    "{area}&#8239;acres": "{area} acre (ung. tunnland)",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} kvadrat-mile",
    "{area}&#8239;yd&sup2;": "{area} kvadrat-yard",
    "{count} errors during import: {message}": "{count} fel under importen: {message}",
    "{delay} seconds": "{delay} sekunder",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} engelska mil",
    "{distance}&#8239;NM": "{distance} M",
    "{distance}&#8239;yd": "{distance} yard",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("sv", locale)
L.setLocale("sv")
