{% load umap_tags i18n static %}

<!DOCTYPE html>
<html {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
  <head>
    <title>
      {% block head_title %}
        {{ SITE_NAME }} - {{ SITE_DESCRIPTION }}
      {% endblock head_title %}
    </title>
    <meta charset="utf-8">
    <meta name="description"
          content="{% trans "uMap lets you create maps with OpenStreetMap layers in a minute and embed them in your site." %}">
    <meta name="keywords" content="map, umap">
    {% block extra_head %}
      {% include "umap/header.html" %}
    {% endblock extra_head %}
    <meta name="viewport"
          content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
    {# See https://evilmartians.com/chronicles/how-to-favicon-in-2021-six-files-that-fit-most-needs #}
    {% autoescape off %}
    <link rel="icon"
          href="{% static 'umap/favicons/favicon.ico' %}"
          sizes="32x32">
    <link rel="icon"
          href="{% static 'umap/favicons/icon.svg' %}"
          type="image/svg+xml">
    <link rel="apple-touch-icon"
          href="{% static 'umap/favicons/apple-touch-icon.png' %}">
    <!-- 180×180 -->
    <link rel="manifest" href="/manifest.webmanifest">
    {% endautoescape %}
  </head>
  <body class="{% block body_class %}{% endblock body_class %}">
    {% block header %}
    {% endblock header %}
    {% block content %}
    {% endblock content %}
    {% block bottom_js %}
    {% endblock bottom_js %}
    {% block footer %}
      {% include "umap/footer.html" %}
    {% endblock footer %}
  </body>
</html>
