const locale = {
    "(area: {measure})": "(surface: {measure})",
    "(length: {measure})": "(longueur: {measure})",
    "# one hash for main heading": "# un dièse pour titre 1",
    "## two hashes for second heading": "## deux dièses pour titre 2",
    "### three hashes for third heading": "### trois dièses pour titre 3",
    "**double star for bold**": "**double astérisque pour gras**",
    "*single star for italic*": "*simple astérisque pour italique*",
    "--- for a horizontal rule": "--- pour un séparateur horizontal",
    "1 day": "1 jour",
    "1 hour": "1 heure",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Liste de nombres séparés par une virgule, définissant les tirets et espaces. Ex.: \"5, 10, 15\".",
    "About": "À propos",
    "Action not allowed :(": "Action non autorisée :(",
    "Activate slideshow mode": "Activer le mode diaporama",
    "Add a layer": "Ajouter un calque",
    "Add a line to the current multi": "Ajouter une ligne au groupe courant",
    "Add a new property": "Ajouter une propriété",
    "Add a polygon to the current multi": "Ajouter un polygon au groupe courant",
    "Add image URL": "URL d'une image",
    "Advanced actions": "Actions avancées",
    "Advanced properties": "Propriétés avancées",
    "All data and settings of the map": "Toutes les données et les propriétés de la carte",
    "All properties are imported.": "Toutes les propriétés sont importées.",
    "Allow interactions": "Autoriser les interactions",
    "Allow scroll wheel zoom?": "Autoriser le zoom avec la molette ?",
    "always": "toujours",
    "Animated transitions": "Transitions animées",
    "Are you sure you want to clone this map and all its datalayers?": "Êtes-vous sûr de vouloir cloner cette carte et ses calques de données?",
    "Are you sure you want to delete this map?": "Êtes-vous sûr de vouloir supprimer cette carte?",
    "Are you sure you want to delete this property on all the features?": "Supprimer la propriété sur tous les éléments ?",
    "Are you sure you want to restore this version?": "Êtes-vous sûr de vouloir restaurer cette version ?",
    "Attach the map to my account": "Lier cette carte à mon compte",
    "attribution": "attribution",
    "Auto": "Auto",
    "Automatic": "Automatique",
    "Autostart when map is loaded": "Lancer au chargement de la carte",
    "Back to preview": "Voir l'aperçu",
    "Background overlay url": "URL de fond transparent",
    "Ball": "Épingle",
    "Bring feature to center": "Centrer la carte sur cet élément",
    "Browse data": "Visualiser les données",
    "by": "par",
    "Cache proxied request": "Cacher la requête avec proxy",
    "Caption": "Légende",
    "Center map on your location": "Centrer la carte sur votre position",
    "Change map background": "Changer le fond de carte",
    "Change tilelayers": "Changer le fond de carte",
    "Change": "Modifier",
    "Choose the data format": "Choisir le format des données",
    "Choropleth breakpoints": "Seuils choropleth",
    "Choropleth classes": "Classes choropleth",
    "Choropleth color palette": "Palettes de couleurs choropleth",
    "Choropleth mode": "Mode choropleth",
    "Choropleth property value": "Propriété choropleth",
    "Choropleth": "Choroplèthe",
    "Circle": "Cercle",
    "clear": "effacer",
    "Click last point to finish shape": "Cliquer sur le dernier point pour finir le tracé",
    "Click to add a marker": "Cliquer pour ajouter le marqueur",
    "Click to continue drawing": "Cliquer pour continuer le tracé",
    "Click to edit": "Cliquer pour modifier",
    "Click to start drawing a line": "Cliquer pour commencer une ligne",
    "Click to start drawing a polygon": "Cliquer pour commencer un polygone",
    "Clone of {name}": "Clone de {name}",
    "Clone this feature": "Dupliquer",
    "Clone this map": "Cloner cette carte",
    "Clone": "Cloner",
    "Close": "Fermer",
    "Clustered": "Avec cluster",
    "Clustering radius": "Rayon du cluster",
    "collapsed": "fermé",
    "color": "Couleur",
    "Comma separated list of numbers, including min and max values.": "Liste de nombres séparés par des virgules, y compris les valeurs minimale et maximale.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Liste de propriétés séparées par une virgule pour trier les éléments. Pour trier en descendant, ajouter un signe moins (-) devant. Ex.: maclé,-autreclé.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Virgule, tabulation ou point-virgule pour séparer des valeurs. SRS WGS84 est implicite. Seuls les points géométriques sont importés. L'importation se référera au titre dans les entêtes de colonnes de «lat» et «lon» au début de l'en-tête, et est insensible à la casse. Toutes les autres colonnes sont importées en tant que propriétés.",
    "Congratulations, your map has been created!": "Félicitations, votre carte a bien été créée !",
    "Continue line": "Continuer la ligne",
    "Coordinates": "Coordonnées",
    "copy": "copier",
    "Credits": "Crédits",
    "Current map view": "Lister seulement les éléments visibles",
    "Current view instead of default map view?": "Vue courante plutôt que la vue par défaut ?",
    "Custom background": "Fond de carte personnalisé",
    "Custom overlay": "Fond transparent",
    "dash array": "traitillé",
    "Data is browsable": "Données naviguables",
    "Datalayers": "Calques",
    "Default interaction options": "Options d'interaction par défaut",
    "Default properties": "Propriétés par défaut",
    "Default shape properties": "Propriétés de forme par défaut",
    "Default view": "Vue par défaut",
    "Default zoom level": "Niveau de zoom par défaut",
    "Default": "Par défaut",
    "Default: name": "Par défaut : name",
    "Define link to open in a new window on polygon click.": "Définit un lien à ouvrir dans une nouvelle fenêtre au clic sur le polygone.",
    "define": "définir",
    "Delay between two transitions when in play mode": "Délai entre les transitions en mode lecture",
    "Delete layer": "Supprimer le calque",
    "Delete this feature": "Supprimer cet élément",
    "Delete this shape": "Supprimer ce tracé",
    "Delete this vertex (Alt+Click)": "Supprimer ce point (Alt+Clic)",
    "Delete": "Supprimer",
    "description": "description",
    "Direct link": "Lien",
    "Directions from here": "Itinéraire à partir de ce lieu",
    "Display label": "Afficher une étiquette",
    "Display measure": "Afficher les dimensions",
    "display name": "nom",
    "Display on load": "Afficher au chargement",
    "Display the control to open OpenStreetMap editor": "Afficher le bouton pour ouvrir l'éditeur d'OpenStreetMap",
    "Display the embed control": "Afficher le bouton de partage",
    "Display the fullscreen control": "Afficher le bouton de plein écran",
    "Display the locate control": "Afficher le bouton de localisation",
    "Display the measure control": "Afficher le bouton de mesures",
    "Display the search control": "Afficher le bouton de recherche",
    "Display the tile layers control": "Afficher le bouton permettant de changer le fond de carte",
    "Display the zoom control": "Afficher les boutons de zoom",
    "Do you want to display a caption bar?": "Voulez-vous afficher une barre de légende",
    "Do you want to display a minimap?": "Voulez-vous afficher une mini carte de situation ?",
    "Do you want to display a panel on load?": "Voulez-vous afficher un panneau latéral au chargement ?",
    "Do you want to display caption menus?": "Afficher les menus dans la légende ?",
    "Do you want to display popup footer?": "Voulez-vous afficher les boutons de navigation en bas des popups ?",
    "Do you want to display the scale control?": "Voulez-vous afficher l'échelle de la carte ?",
    "Do you want to display the «more» control?": "Voulez-vous afficher le bouton « Plus » ?",
    "Download": "Télécharger",
    "Drag to reorder": "Glisser pour réordonner",
    "Draw a marker": "Ajouter un marqueur",
    "Draw a polygon": "Dessiner un polygone",
    "Draw a polyline": "Dessiner une ligne",
    "Drawing": "Modification",
    "Drop": "Goutte",
    "Dynamic properties": "Propriétés dynamiques",
    "Dynamic": "Dynamique",
    "Edit feature's layer": "Éditer le calque de l'élément",
    "Edit properties in a table": "Éditer dans un tableau",
    "Edit the title of the map": "Modifier le titre de la carte",
    "Edit this feature": "Éditer cet élément",
    "Edit": "Éditer",
    "Embed and link options": "Intégration et partage",
    "Embed the map": "Intégrer la carte dans une iframe",
    "Emoji & Character": "Emoji & texte",
    "Empty": "Vider",
    "Equidistant": "Équidistant",
    "Error in the overlay URL": "URL du fond de carte invalide",
    "Error in the tilelayer URL": "Erreur dans l'URL du fond de carte",
    "Exit Fullscreen": "Quitter le plein écran",
    "expanded": "ouvert",
    "Extract shape to separate feature": "Extraire la forme",
    "Feature identifier key": "Clé unique d'un élément",
    "Feature properties": "Propriétés de l'élément",
    "Fetch data each time map view changes.": "Récupère les données à chaque fois que la vue de la carte change.",
    "fill color": "couleur de remplissage",
    "fill opacity": "opacité du remplissage",
    "fill": "remplissage",
    "Fit all data": "Zoom sur les données",
    "Format": "Format",
    "From zoom": "À partir du zoom",
    "full backup": "sauvegarde complète",
    "Generic": "Générique",
    "GeoRSS (only link)": "GeoRSS (lien seul)",
    "GeoRSS (title + image)": "GeoRSS (titre + image)",
    "Go to \"{coords}\"": "Aller à \"{coords}\"",
    "Go to the homepage": "Retour à la page d'accueil",
    "Go to «{feature}»": "Naviguer jusqu'à «{feature}»",
    "Heatmap intensity property": "Propriété pour l'intensité de la heatmap",
    "Heatmap radius": "Rayon de heatmap",
    "Heatmap": "Heatmap",
    "height": "hauteur",
    "Help": "Aide",
    "hidden": "caché",
    "Hide controls": "Masquer les outils",
    "Home": "Accueil",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Valeur de simplification des lignes pour chaque niveau de zoom (grand nombre = meilleure performance, petit nombre = plus précis)",
    "icon opacity": "Opacité de l'icône",
    "Icon shape": "Forme de l'icône",
    "Icon symbol": "Image de l'icône",
    "If false, the polygon or line will act as a part of the underlying map.": "Désactiver pour que le polygone ou la ligne ne réagisse plus aux interactions.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe avec hauteur (en pixels) : {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe avec hauteur et largeur (en px) : {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe : {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image avec largeur (en pixels) : {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image : {{https://image.url.com}}",
    "Import data": "Importer des données",
    "Import in a new layer": "Importer dans un nouveau calque",
    "Imports all umap data, including layers and settings.": "Importer toutes les données de la carte, y compris les calques et les propriétés",
    "Include full screen link?": "Inclure le lien \"plein écran\" ?",
    "Inherit": "Hériter",
    "inherit": "hériter",
    "Interaction options": "Options d'interaction",
    "Invalid latitude or longitude": "Latitude ou longitude invalide",
    "Invalid umap data in {filename}": "Les données du fichier {filename} ne sont pas valides comme format uMap",
    "Invalid umap data": "Données uMap invalides",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-moyennes",
    "Keep current visible layers": "Garder les calques visibles actuellement",
    "kilometers": "kilomètres",
    "km": "km",
    "Label direction": "Direction de l'étiquette",
    "Label key": "Clé pour le libellé",
    "Labels are clickable": "Étiquette cliquable",
    "Latest feature": "Dernier élément",
    "Latitude": "Latitude",
    "Layer properties": "Propriétés du calque",
    "Layer": "Calque",
    "Licence": "Licence",
    "licence": "licence",
    "Limit bounds": "Limites géographiques",
    "Link to view the map": "Lien vers la carte",
    "Link to…": "Lien vers…",
    "Link with text: [[https://example.com|text of the link]]": "Lien avec texte : [[https://example.com|titre du lien]]",
    "Long credits": "Crédit",
    "Longitude": "Longitude",
    "Make main shape": "Tracé principal",
    "Manage layers": "Gérer les calques",
    "Manual": "Manuel",
    "Map background credits": "Crédits pour le fond de carte",
    "Map has been attached to your account": "La  carte est maintenant liée à votre compte",
    "Map has been saved!": "La carte a été sauvegardée !",
    "Map has been starred": "La carte a été ajoutée aux favoris",
    "Map has been unstarred": "La carte a été retirée des favoris",
    "Map user content has been published under licence": "Les contenus sur la carte ont été publiés avec la licence",
    "Map's editors": "Éditeurs de la carte",
    "Map's owner": "Propriétaire de la carte",
    "max East": "limite est",
    "max North": "limite nord",
    "max South": "limite sud",
    "max West": "limite ouest",
    "max zoom": "zoom max",
    "Measure distances": "Mesurer les distances",
    "Merge lines": "Fusionner les lignes",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "zoom min",
    "More controls": "Plus d'outils",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Doit être une valeur CSS valide (ex. : DarkBlue ou #123456)",
    "name": "nom",
    "nautical miles": "miles nautiques",
    "never": "jamais",
    "new window": "nouvelle fenêtre",
    "next": "suivant",
    "NM": "NM",
    "No cache": "Pas de cache",
    "No licence has been set": "Aucune licence définie",
    "No results": "Aucun résultat",
    "no": "non",
    "No.": "Non.",
    "None": "Aucun",
    "Number of desired classes (default 5)": "Nombre désiré de classes (par défaut 5)",
    "On the bottom": "Bas",
    "On the left": "Gauche",
    "On the right": "Droite",
    "On the top": "Haut",
    "Only visible layers' data": "Seules les données des calques visibles",
    "opacity": "opacité",
    "Opacity": "Transparence",
    "Open current feature on load": "Ouvrir l'élément courant au chargement",
    "Open link in…": "Ouvrir le lien dans…",
    "Open share & download panel": "Ouvrir le panneau de partage",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ouvrir cette carte dans un éditeur OpenStreetMap pour améliorer les données",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propriété optionnelle à utiliser pour calculer l'intensité de la heatmap",
    "Optional. Same as color if not set.": "Optionnel. La couleur principale sera utilisée si laissé vide.",
    "Optional.": "Facultatif",
    "Override clustering radius (default 80)": "Valeur de rayon personnalisée pour le cluster (par défaut : 80)",
    "Override heatmap radius (default 25)": "Valeur de rayon personnalisée pour la heatmap (par défaut : 25)",
    "parent window": "fenêtre parente",
    "Paste your data here": "Collez vos données ici",
    "Permalink": "Permalien",
    "Permanent credits background": "Afficher un fond pour le crédit permanent",
    "Permanent credits": "Crédits permanents",
    "Please be sure the licence is compliant with your use.": "Pensez à vérifier que la licence de ces données vous autorise à les utiliser.",
    "Please choose a format": "Merci de choisir un format",
    "Please enter the name of the property": "Merci d'entrer le nom de la propriété",
    "Please enter the new name of this property": "Veuillez entrer le nouveau nom de la propriété",
    "Please save the map first": "Vous devez d'abord enregistrer la carte",
    "Popup (large)": "Popup (grande)",
    "Popup content style": "Gabarit prédéfini de popup",
    "Popup content template": "Gabarit manuel de popup",
    "Popup shape": "Forme de popup",
    "Popup": "Popup",
    "Powered by uMap": "Propulsé par uMap",
    "previous": "précédent",
    "Problem in the response": "Problème dans la réponse du serveur",
    "Properties imported:": "Propriétés importées :",
    "Provide an URL here": "Renseigner une URL",
    "Proxy request": "Avec proxy",
    "Quantiles": "Quantiles",
    "Recent": "Récents",
    "Remote data": "Données distantes",
    "Remove shape from the multi": "Supprimer ce tracé du groupe",
    "Replace layer content": "Remplacer le contenu du calque",
    "Restore this version": "Restaurer cette version",
    "Save current edits": "Enregistrer les changements courants",
    "Save map": "Enregistrer la carte",
    "Save": "Enregistrer",
    "Saved center and zoom": "Centre et zoom enregistrés",
    "Search location": "Chercher un lieu",
    "Search": "Chercher",
    "Secret edit link:": "Lien d'édition secret :",
    "See full screen": "Voir en plein écran",
    "See on OpenStreetMap": "Voir sur OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Désactiver pour masquer ce calque du diaporama, du navigateur de données…",
    "settings": "paramètres",
    "Shape properties": "Propriétés de la forme",
    "Share and download": "Partager et télécharger",
    "Share this link to open a customized map view": "Partager ce lien pour avoir une vue personnalisée",
    "Short credits": "Crédit court",
    "Short link": "Lien court",
    "Show this layer in the caption": "Montrer ce calque dans la légende",
    "Show/hide layer": "Montrer/masquer un calque",
    "Side panel": "Panneau latéral",
    "Simple link: [[https://example.com]]": "Lien simple : [[https://example.com]]",
    "Simplify": "Simplifier",
    "Skipping unknown geometry.type: {type}": "Type de géométrie inconnu ignoré : {type}",
    "Slideshow": "Diaporama",
    "Sort key": "Clé de tri",
    "Split line": "Scinder la ligne",
    "Star this map": "Mettre la carte en favori",
    "Start a hole here": "Ajouter un tracé intérieur",
    "Start slideshow": "Commencer",
    "Stop editing": "Quitter le mode édition",
    "Stop slideshow": "Arrêter",
    "Street": "Rue",
    "stroke": "trait",
    "Supported scheme": "Schéma supporté",
    "Supported variables that will be dynamically replaced": "Variables qui seront automatiquement remplacées",
    "Symbol": "Symbole",
    "Table": "Tableau",
    "Text color for the cluster label": "Couleur du texte du cluster",
    "Text formatting": "Mise en forme du texte",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Nom de la propriété utilisée pour le libellé (ex.: \"nom\"). Il est possible d'utiliser des propriétés entre accolades pour en utiliser plusieurs ou ajouter du texte (ex.: \"&lcub;nom&rcub; à &lcub;lieu&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Nom de la propriété utilisée pour identifier un élément de façon unique",
    "The zoom and center have been modified.": "Le niveau de zoom et le centre ont été modifiés.",
    "TMS format": "format de type TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Cocher si le serveur distant n'autorise pas le cross domain (plus lent)",
    "To zoom": "Jusqu'au zoom",
    "Toggle edit mode (⇧+Click)": "Alterner le mode édition (⇧+clic)",
    "Toggle edit mode": "Activer/désactiver le mode édition",
    "Transfer shape to edited feature": "Adjoindre le tracé au groupe courant",
    "Transform to lines": "Transformer en lignes",
    "Transform to polygon": "Transformer en polygone",
    "Type a place name or coordinates": "Entrer un lieu ou des coordonnées",
    "Type char or paste emoji": "Taper un caractère ou un émoji",
    "Type of layer": "Type de calque",
    "Unable to detect format of file {filename}": "Impossible de détecter le format du fichier {filename}",
    "Untitled layer": "Calque sans nom",
    "Untitled map": "Carte sans nom",
    "Update permissions and editors": "Changer les permissions et les éditeurs",
    "Update permissions": "Mettre à jour les permissions",
    "Update who can see and edit the map": "Définir qui peut voir et modifier la carte",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Utiliser la vue courante",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilisez des variables avec les noms de propriétés de vos éléments entre accolades, ex.  &#123;name&#125;, elles seront remplacées dynamiquement par les valeurs correspondantes.",
    "User content credits": "Crédit pour le contenu utilisateur",
    "User interface options": "Options d'interface",
    "User location": "Localisation de l'utilisateur",
    "Verify remote URL": "Vérifier l'URL",
    "Versions": "Versions",
    "View Fullscreen": "Voir en plein écran",
    "View": "Aperçu",
    "Visibility: {status}": "Visibilité : {status}",
    "weight": "épaisseur",
    "Where do we go from here?": "C'est par où pour aller plus loin?",
    "Whether to display or not polygons paths.": "Afficher les contours des polygones.",
    "Whether to fill polygons with color.": "Remplir les polygones avec de la couleur.",
    "Who can edit \"{layer}\"": "Qui peut modifier « {layer} »",
    "Who can edit": "Qui peut modifier",
    "Who can view": "Qui peut voir",
    "width": "largeur",
    "Will be displayed in the bottom right corner of the map": "S'affiche dans le coin en bas à droite de la carte",
    "Will be permanently visible in the bottom left corner of the map": "Afficher en permanence au coin en bas à gauche de la carte",
    "Will be visible in the caption of the map": "Sera visible dans la légende de la carte",
    "yes": "oui",
    "Zoom in": "Zoomer",
    "Zoom level for automatic zooms": "Niveau de zoom automatique",
    "Zoom out": "Dézoomer",
    "Zoom to layer extent": "Zoomer jusqu'à voir les données du calque",
    "Zoom to the next": "Suivant",
    "Zoom to the previous": "Précédent",
    "Zoom to this feature": "Zoomer sur cet élément",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} erreurs pendant l'import : {message}",
    "{delay} seconds": "{delay} secondes",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} MN",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Modifier le nom et la légende",
    "Map advanced properties": "Propriétés avancées de la carte",
    "Edit map details": "Modifier les propriétés de la carte",
    "Back to browser": "Retour au navigateur",
    "Toggle size": "Basculer la hauteur",
    "Display the caption control": "Afficher le bouton d'ouverture de la légende",
    "<empty value>": "<vide>",
    "Min": "Min",
    "Max": "Max",
    "From": "De",
    "Until": "À",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Exemple : cle1,cle2|Label 2,Label 3|checkbox",
    "Edit in OpenStreetMap": "Modifier dans OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Impossible de détecter les colonnes latitude et longitude.",
    "Back to layers": "Voir les calques",
    "Filters": "Filtres",
    "Comma separated list of properties to use when filtering features by text input": "Liste de propriétés utilisées lors de la recherche texte d'éléments de la carte (séparées par des virgules)",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Liste de propriétés séparées par des virgules, à utiliser pour le calcul des filtres par catégories (ex. : macle,autrecle). Il est possible de préciser le libellé de la facette après un | (ex. : macle|Ma Clé,autrecle|Mon Autre Clé). Il est aussi possible de définir le type de champ utilisé, en utilisant un autre | (ex. : macle|Ma clé|checkbox,autrecle|Autre clé|datetime). Les types pris en charge sont : checkbox (par défaut), radio, number, date et datetime.",
    "Search keys": "Clés pour la recherche",
    "Filters keys": "Clés pour les filtres",
    "Filter data": "Filtrer les données",
    "Search map features…": "Chercher des éléments de la carte",
    "Reset all": "Tout réinitialiser",
    "Open browser": "Explorateur",
    "Open caption": "Légende",
    "Your map has been created with an anonymous account!": "La carte a été créée avec un compte anonyme !",
    "Real-time collaboration": "Collaboration temps réel",
    "Cannot parse data": "Données invalides",
    "Start typing...": "Taper…",
    "No result": "Aucun résultat",
    "Data browser": "Explorateur de données",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "À partir d'une URL, uMap peut soit copier les données dans un calque, soit ajouter cette URL comme source de données distantes. Dans ce cas, les données sont téléchargées depuis cette URL à chaque chargement de la carte, et donc sont toujours à jour, mais il n'est alors pas possible de les modifier dans uMap.",
    "Overpass supported expressions": "Expressions pour les requêtes Overpass",
    "key (eg. building)": "clé (ex. building)",
    "!key (eg. !name)": "!clé (ex. !name)",
    "key=value (eg. building=yes)": "clé=valeur (ex. building=yes)",
    "key!=value (eg. building!=yes)": "clé!=valeur (ex. building!=yes)",
    "key~value (eg. name~Grisy)": "clé~valeur (ex. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"valeur|valeur2\" (ex. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Plus d'infos sur la syntaxe Overpass",
    "For more complex needs, see": "Pour les besoins plus avancés:",
    "Choose data": "Choisir les données",
    "Choose the format": "Choisir le format",
    "Choose the layer": "Choisir le calque",
    "Layer name": "Nom du calque",
    "Choose import mode": "Choisir le mode d'import",
    "Copy into the layer": "Copier dans le calque",
    "Link to the layer as remote data": "Associer au calque comme données distantes",
    "Condition": "Condition",
    "key=value or key!=value": "clé=valeur ou clé!=valeur",
    "Are you sure you want to delete this rule?": "Confirmez-vous la suppression de cette règle ?",
    "empty rule": "règle vide",
    "Conditional style rules": "Règles de formatage conditionnelles",
    "Add rule": "Ajouter une règle",
    "Browser: data": "Explorateur : données",
    "Browser: layers": "Explorateur : calques",
    "Browser: filters": "Explorateur : filtres",
    "Enable real-time collaboration": "Activer la collaboration temps réel",
    "✅ Copied!": "✅ Copié !",
    "Choose a dataset": "Choisir un jeu de données",
    "Choose this dataset": "Choisir ce jeu de données",
    "GeoDataMine: thematic data from OpenStreetMap": "GéoDataMine : données thématiques à partir d'OpenStreetMap",
    "Choose a theme": "Choisir un thème",
    "Symplify all geometries to points": "Simplifier les géométries en points",
    "Choose this data": "Choisir ces données",
    "Search admin boundary": "Chercher une limite administrative",
    "Please choose a theme and a boundary first.": "Merci de choisir un thème et une limite administrative.",
    "Expression": "Expression",
    "Geometry mode": "Type de géométries",
    "Only geometry centers": "Seulement les centres",
    "Search area": "Chercher un coin",
    "Type area name, or let empty to load data in current map view": "Entrer le nom d'un périmètre géographique, ou laisser vide pour utiliser la vue courante de la carte",
    "Data successfully imported!": "Les données ont été importées!",
    "Clear data": "Effacer les données",
    "Remove layers": "Supprimer les calques",
    "Categorized": "Par catégories",
    "Alphabetical": "Alphabétique",
    "Category property": "Propriété",
    "Color palette": "Palette de couleurs",
    "Categories": "Catégories",
    "Comma separated list of categories.": "Liste de catégories séparées par une virgule.",
    "Categories mode": "Mode",
    "Remove filter for this column": "Supprimer le filtre pour cette colonne",
    "Add filter for this column": "Ajouter un filtre pour cette colonne",
    "Rename this column": "Renommer cette colonne",
    "Delete this column": "Supprimer cette colonne",
    "Name “{name}” should not contain a dot.": "Le nom «{name}» ne doit pas contenir de point.",
    "This name already exists: “{name}”": "Ce nom existe déjà: «{name}».",
    "Delete selected rows": "Supprimer les lignes sélectionnées",
    "Found {count} rows. Are you sure you want to delete all?": "{count} lignes trouvées. Êtes-vous sûr de vouloir toutes les supprimer ?",
    "Expression is empty": "L'expression est vide",
    "OK": "OK",
    "Cancel": "Annuler",
    "Attach map to a team": "Associer la carte à une équipe",
    "Display the polygon inverted": "Afficher le polygon en négatif",
    "Proportional circles": "Cercles proportionnels",
    "Property name to compute circles": "Nom de la propriété pour calculer les cercles",
    "Min circle radius": "Rayon minimum",
    "Max circle radius": "Rayon maximum",
    "Display the open browser control": "Afficher le bouton d'ouverture de l'explorateur",
    "Copy as GeoJSON": "Copier le GeoJSON",
    "Please zoom in to edit the geometry": "Zoomer pour éditer la géométrie",
    "New map": "Nouvelle carte",
    "My maps": "Mes cartes",
    "My teams": "Mes équipes",
    "My profile": "Mon profil",
    "Type new owner's username": "Nom d'utilisateur du nouveau propriétaire",
    "Type editor's username": "Nom d'utilisateur de l'éditeur",
    "Map": "Carte",
    "Manage collaborators": "Gérer les collaborateurs",
    "show/hide all layers": "montrer/masquer les calques",
    "zoom to data extent": "zoomer sur les données",
    "download visible data": "télécharger les données affichées",
    "Import helpers": "Assistants d'import",
    "Import helpers will fill the URL field for you.": "Les assistants d'import vont renseigner le champ URL pour vous.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Enregistrer le brouillon",
    "No data has been found for import": "Aucunes données à importer",
    "Successfully imported {count} feature(s)": "{count} élément(s) ajouté(s) à la carte",
    "Disconnected": "Déconnecté",
    "You must be logged in": "Authentification requise",
    "on hover": "au survol",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Impossible de charger les données du calque \"{layer}\" à partir de l'URL \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Impossible de lire les données du calque \"{layer}\" à partir de l'URL \"{url}\"",
    "Import failed: invalid data": "Échec de l'import: les données sont invalides",
    "Anonymous": "Anonyme",
    "created at {date}": "créée le {date}",
    "modified at {date}": "modifiée le {date}",
    "Default zoom": "Zoom par défaut",
    "Default latitude": "Latitude par défaut",
    "Default longitude": "Longitude par défaut",
    "Edit map default view": "Régler la vue par défaut de la carte",
    "Use current center and zoom": "Utiliser le centre et le zoom actuels",
    "Layer permalink": "Permalien du calque",
    "Back to home": "Retour à l'accueil",
    "Home logo": "Logo uMap",
    "Add this geometry to my map": "Ajouter cette géométrie à ma carte",
    "Add this place to my map": "Ajouter ce lieu à ma carte",
    "Cancel last edit": "Annuler la dernière modification",
    "Redo last edit": "Rejouer la dernière modification",
    "Links": "Liens",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Catégories",
    "Geocode": "Géocoder"
}
L.registerLocale("fr", locale)
L.setLocale("fr")
