const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# yksi risuaita tekee päätason otsikon",
    "## two hashes for second heading": "## kaksi risuaitaa tekee kakkostason otsikon",
    "### three hashes for third heading": "### kolme risuaitaa tekee kolmostason otsikon",
    "**double star for bold**": "**tuplatähti lihavoi**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Tietoja",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Lisää kerros",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Lisää uusi ominaisuus",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Advanced actions": "Lisätoiminnot",
    "Advanced properties": "Lisäominaisuudet",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Kaikki omainaisuudet tuodaan.",
    "Allow interactions": "Allow interactions",
    "Allow scroll wheel zoom?": "Salli zoomaus hiiren rullalla?",
    "always": "aina",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Oletko varma että haluat kloonata tämän kartan ja kaikki sen data-kerrokset?",
    "Are you sure you want to delete this map?": "Oletko ihan täysin varma, että haluat poistaa tämän kartan? Poistettua karttaa ei voi palauttaa.",
    "Are you sure you want to delete this property on all the features?": "Oletko varma että haluat poistaa tämän ominaisuuden kaikista piirteistä?",
    "Are you sure you want to restore this version?": "Oletko varma että haluat palauttaa tämän version?",
    "Attach the map to my account": "Attach the map to my account",
    "attribution": "Viittaukset tausta-aineiston lisenssiin",
    "Auto": "Automaattinen",
    "Automatic": "Automaattinen",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Pallo",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Selaa tietoja",
    "by": "taholta",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Kuvateksti",
    "Center map on your location": "Keskitä kartta sijaintiisi",
    "Change map background": "Vaihda taustakarttaa",
    "Change tilelayers": "Muuta karttavaihtoehtoja",
    "Change": "Change",
    "Choose the data format": "Valitse päivämäärän muoto",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Ympyrä",
    "clear": "clear",
    "Click last point to finish shape": "Klikkaa viimeistä pistettä täydentääksesi muodon",
    "Click to add a marker": "Klikkaa lisätäksesi karttamerkki",
    "Click to continue drawing": "Klikkaa jatkaaksesi piirtämistä",
    "Click to edit": "Klikkaa muokataksesi",
    "Click to start drawing a line": "Klikkaa aloittaaksesi viivan piirtäminen",
    "Click to start drawing a polygon": "Klikkaa aloittaaksesi monikulmion piirtäminen",
    "Clone of {name}": "{name}n klooni",
    "Clone this feature": "Kloonaa tämä piirre",
    "Clone this map": "Kloonaa tämä kartta",
    "Clone": "Kloonaa",
    "Close": "Sulje",
    "Clustered": "Klusteroituna",
    "Clustering radius": "Klusterointisäde",
    "collapsed": "collapsed",
    "color": "väri",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Pilkku-, tabulaattori- tai puolipiste-erotettuja arvoja. Koordinaattijärjestemänä WGS84. Vain pistegeometriat tuodaan uMapiin. Tietue-tuonti etsii «lat»- ja «lon»-alkavia sarakeotsikoita. Kaikki muut sarakkeet tuodaan ominaisuustietoina.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Jatka viivaa",
    "Coordinates": "Koordinaatit",
    "copy": "copy",
    "Credits": "Tunnustukset",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Nykyinen näkymä oletuskarttanäkymän asemesta?",
    "Custom background": "Räätälöity tausta",
    "Custom overlay": "Custom overlay",
    "dash array": "katkoviivatyyppilista",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "Default interaction options",
    "Default properties": "Oletusasetukset",
    "Default shape properties": "Default shape properties",
    "Default view": "Default view",
    "Default zoom level": "Default zoom level",
    "Default": "Oletusarvo",
    "Default: name": "Oletus: nimi",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "määritä",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Poista kerros",
    "Delete this feature": "Poista tämä piirre",
    "Delete this shape": "Poista tämä muoto",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "Poista",
    "description": "kuvaus",
    "Direct link": "Direct link",
    "Directions from here": "Ohjeet täältä",
    "Display label": "Display label",
    "Display measure": "Display measure",
    "display name": "näytettävä nimi",
    "Display on load": "Näytä ladattaessa",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Haluatko näyttää otsikkopalkin?",
    "Do you want to display a minimap?": "Haluatko aktivoida minikartan?",
    "Do you want to display a panel on load?": "Haluatko näyttää paneelin ladattaessa?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Haluatko näyttää ponnahdusikkunan alatunnisteen?",
    "Do you want to display the scale control?": "Näytetäänkö mittakaavaohjain?",
    "Do you want to display the «more» control?": "Haluatko näyttää «lisää»-ohjaimen?",
    "Download": "Download",
    "Drag to reorder": "Drag to reorder",
    "Draw a marker": "Piirrä karttamerkki",
    "Draw a polygon": "Piirrä monikulmio",
    "Draw a polyline": "Piirrä monisegmenttinen viiva",
    "Drawing": "Drawing",
    "Drop": "Pisara",
    "Dynamic properties": "Dynaamiset ominaisuudet",
    "Dynamic": "Dynaaminen",
    "Edit feature's layer": "Muokkaa piirteen kerrosta",
    "Edit properties in a table": "Muokkaa ominaisuuksia taulukossa",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Muokkaa tätä piirrettä",
    "Edit": "Muokkaa",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Liitä kartta",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Tyhjä",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Virhe karttalaattojen URL:ssä",
    "Exit Fullscreen": "Exit Fullscreen",
    "expanded": "laajennettu",
    "Extract shape to separate feature": "Irroita muoto erilliseksi piirteeksi.",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "täyteväri",
    "fill opacity": "täytön läpinäkyvyys",
    "fill": "täyttö",
    "Fit all data": "Fit all data",
    "Format": "Formaatti",
    "From zoom": "Zoomaustasolta",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (vain linkki)",
    "GeoRSS (title + image)": "GeoRSS (otsikko + kuva)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Mene piirteeseen «{feature}»",
    "Heatmap intensity property": "Lämpökartan vahvuusominaisuus",
    "Heatmap radius": "Lämpökartan säde",
    "Heatmap": "Lämpökartta",
    "height": "korkeus",
    "Help": "Apua",
    "hidden": "piilotettu",
    "Hide controls": "Piilota ohjaimet",
    "Home": "Alku",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Kuinka paljon viivaa yleistetäänkullakin zoomaustasolla (enemmän = parempi suorituskyky, vähemmän = suurempi tarkkuus)",
    "icon opacity": "icon opacity",
    "Icon shape": "Ikonin muoto",
    "Icon symbol": "Ikonin symboli",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Tuo tietoja",
    "Import in a new layer": "Tuo uuteen kerrokseen",
    "Imports all umap data, including layers and settings.": "Tuo kaikki karttatiedot, mukaan lukien datatasot ja asetukset.",
    "Include full screen link?": "Sisällytä koko näyttö -linkki?",
    "Inherit": "Peri",
    "inherit": "peri",
    "Interaction options": "Interaction options",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Virheellistä uMap-dataa {filename}:ssa",
    "Invalid umap data": "Virheellistä uMap-dataa",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Pidä nyt näkyvät datakerrokset",
    "kilometers": "kilometers",
    "km": "km",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "Latest feature": "Latest feature",
    "Latitude": "Leveysaste",
    "Layer properties": "Datakerroksen ominaisuudet",
    "Layer": "Kerros",
    "Licence": "Lisenssi",
    "licence": "lisenssi",
    "Limit bounds": "Alueen rajaus",
    "Link to view the map": "Link to view the map",
    "Link to…": "Linkitä kohteeseen...",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Pitkät tekijätiedot",
    "Longitude": "Pituusaste",
    "Make main shape": "Luo päämuoto",
    "Manage layers": "Hallitse kerroksia",
    "Manual": "Manual",
    "Map background credits": "Taustakartan tekijämerkinnät",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Kartta on tallennettu!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Kartan käyttäjien luomat tiedot on julkaistu lisenssillä",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "max East": "itäraja",
    "max North": "pohjoisraja",
    "max South": "eteläraja",
    "max West": "länsiraja",
    "max zoom": "suurin zoomaustaso",
    "Measure distances": "Measure distances",
    "Merge lines": "Yhdistä rivit",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "pienin zoomaustaso",
    "More controls": "Lisää ohjaimia",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "name": "nimi",
    "nautical miles": "nautical miles",
    "never": "ei koskaan",
    "new window": "uusi ikkuna",
    "next": "seuraava",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "Lisenssiä ei ole määritetty",
    "No results": "Ei tuloksia",
    "no": "ei",
    "No.": "No.",
    "None": "Ei mitään",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Alhaalla",
    "On the left": "Vasemmalla",
    "On the right": "Oikealla",
    "On the top": "Ylhäällä",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "läpikuultavuus",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Open link in…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Avaa rajauksen mukainen alue editorissa parantaaksesi OpenStreetMapin tietosisältöä.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valinnainen lämpökartan vahvuusominaisuus",
    "Optional. Same as color if not set.": "Valinnainen. Sama kuin väri jos ei asetettu.",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "Ohita klusterointisäde (oletus on 80)",
    "Override heatmap radius (default 25)": "Ohita lämpökartan säde (oletus on 25)",
    "parent window": "parent window",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Huomioithan että valitsemasi lisenssi on yhteensopiva käyttösi kanssa.",
    "Please choose a format": "Valitse formaatti",
    "Please enter the name of the property": "Kirjoita ominaisuuden nimi",
    "Please enter the new name of this property": "Kirjoita ominaisuuden uusi nimi",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "Ponnahdusikkunan sisällön sapluuna",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "edellinen",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Tuodut ominaisuudet:",
    "Provide an URL here": "Syötä verkko-osoite tänne",
    "Proxy request": "Välityspalvelinpyyntö",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Etä-tiedot",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Korvaa kerroksen sisältö",
    "Restore this version": "Palauta tämä versio",
    "Save current edits": "Tallenna tämänhetkiset muokkaukset",
    "Save map": "Save map",
    "Save": "Tallenna",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Search location",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Katso koko näytöllä",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Piirteen ominaisuudet",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Lyhyet tekijätiedot",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Näytä/piilota kerros",
    "Side panel": "Sivupaneeli",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Yksinkertaista",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "Kuvaesitys",
    "Sort key": "Sort key",
    "Split line": "Pilko/katkaise viiva",
    "Star this map": "Star this map",
    "Start a hole here": "Aloita reikä tässä",
    "Start slideshow": "Aloita kuvaesitys",
    "Stop editing": "Lopeta muokkaus",
    "Stop slideshow": "Lopeta kuvaesitys",
    "Street": "Street",
    "stroke": "sivallus",
    "Supported scheme": "Tuettu muoto",
    "Supported variables that will be dynamically replaced": "Tuetut muuttujat, jotka korvataan dynaamisesti",
    "Symbol": "Symbol",
    "Table": "Taulukko",
    "Text color for the cluster label": "Tekstin väri klusterietiketissä",
    "Text formatting": "Tekstin muotoilu",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS-formaatti",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Zoomaukseen",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Siirrä muoto muokatuksi piirteeksi.",
    "Transform to lines": "Muunna viivoiksi",
    "Transform to polygon": "Muunna monikulmioksi",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Datakerroksen tyyppi",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Nimeämätön kerros",
    "Untitled map": "Nimeämätön kartta",
    "Update permissions and editors": "Päivitä oikeudet ja editori",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Käytä nykyistä rajausta",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Käyttäjien luoman tiedon tuottajat:",
    "User interface options": "Käyttäjän käyttöliittymäoptiot",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versiot",
    "View Fullscreen": "View Fullscreen",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "paksuus",
    "Where do we go from here?": "Minnekäs sitten?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "width": "leveys",
    "Will be displayed in the bottom right corner of the map": "Näytetään kartan oikeassa alakulmassa",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Näytetään kartan kuvatekstinä",
    "yes": "kyllä",
    "Zoom in": "Lähennä",
    "Zoom level for automatic zooms": "Zoomaustaso automaattisessa zoomauksessa",
    "Zoom out": "Loitonna",
    "Zoom to layer extent": "Zoomaa tason laajuuteen",
    "Zoom to the next": "Kohdenna seuraavaan",
    "Zoom to the previous": "Kohdenna edelliseen",
    "Zoom to this feature": "Kohdenna tähän piirteeseen",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("fi", locale)
L.setLocale("fi")
