# Generated by Django 5.1.2 on 2024-11-15 11:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0022_add_team"),
    ]

    operations = [
        migrations.AlterField(
            model_name="datalayer",
            name="uuid",
            field=models.UUIDField(
                editable=False, primary_key=True, serialize=False, unique=True
            ),
        ),
    ]
