const locale = {
    "(area: {measure})": "(περιοχή: {μέτρηση})",
    "(length: {measure})": "(μήκος: {μέτρηση})",
    "# one hash for main heading": "# ένα hash για επικεφαλίδα πρώτου επιπέδου",
    "## two hashes for second heading": "## δύο  hash για επικεφαλίδα δευτέρου επιπέδου",
    "### three hashes for third heading": "### τρία hash για επικεφαλίδα τρίτου επιπέδου",
    "**double star for bold**": "**διπλό αστερίσκο για έντονα**",
    "*single star for italic*": "*μονό αστερίσκο για πλάγια*",
    "--- for a horizontal rule": "--- για οριζόντιο χάρακα",
    "1 day": "1 μέρα",
    "1 hour": "1 ώρα",
    "5 min": "5 λεπτά",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Μια λίστα αριθμών διαχωρισμένων με κόμμα που καθορίζει το μοτίβο της παύλας. Π.χ.: \"5, 10, 15\".",
    "About": "Σχετικά",
    "Action not allowed :(": "Μη επιτρεπόμενη ενέργεια :(",
    "Activate slideshow mode": "Ενεργοποίηση λειτουργίας παρουσίασης",
    "Add a layer": "Προσθήκη επιπέδου",
    "Add a line to the current multi": "Προσθήκη γραμμής στο παρόν πολυδεδομένο",
    "Add a new property": "Προσθήκη νέας ιδιότητας",
    "Add a polygon to the current multi": "Προσθήκη πολυγώνου στο παρόν πολυδεδομένο",
    "Add image URL": "Προσθήκη URL εικόνας",
    "Advanced actions": "Εξειδικευμένες ενέργειες",
    "Advanced properties": "Εξειδικευμένες ιδιότητες",
    "All data and settings of the map": "Όλα τα δεδομένα και ρυθμίσεις του χάρτη",
    "All properties are imported.": "Όλες οι ιδιότητες έχουν εισαχθεί",
    "Allow interactions": "Επιτρέπονται αλληλεπιδράσεις",
    "Allow scroll wheel zoom?": "Επιτρέπεται κύλιση εστίασης",
    "always": "πάντα",
    "Animated transitions": "Κινούμενες μεταβάσεις",
    "Are you sure you want to clone this map and all its datalayers?": "Θέλετε σίγουρα να κλωνοποιηθεί αυτός ο χάρτης και όλα τα επίπεδα δεδομένων του;",
    "Are you sure you want to delete this map?": "Θέλετε σίγουρα να διαγραφεί αυτός ο χάρτης;",
    "Are you sure you want to delete this property on all the features?": "Θέλετε σίγουρα να διαγραφεί αυτή η ιδιότητα από όλα τα στοιχεία;",
    "Are you sure you want to restore this version?": "Θέλετε σίγουρα να γίνει επαναφορά αυτής της έκδοσης;",
    "Attach the map to my account": "Σύνδεση του χάρτη με τον λογαριασμό μου",
    "attribution": "Αναφορά",
    "Auto": "Αυτόματα",
    "Automatic": "Αυτόματα",
    "Autostart when map is loaded": "Αυτόματη έναρξη με την φόρτωση του χάρτη",
    "Back to preview": "Επιστροφή στην προεπισκόπηση",
    "Background overlay url": "Διεύθυνση URL επικάλυψης φόντου",
    "Ball": "Καρφίτσα",
    "Bring feature to center": "Κεντράρισμα του χαρακτηριστικού",
    "Browse data": "Περιήγηση δεδομένων",
    "by": "από",
    "Cache proxied request": "Αίτημα μεσολάβησης προσωρινής μνήμης",
    "Caption": "Λεζάντα",
    "Center map on your location": "Κεντράρισμα του χάρτη στην τοποθεσία σας",
    "Change map background": "Αλλαγή υποβάθρου του χάρτη",
    "Change tilelayers": "Αλλαγή χαρτογραφικού υπόβαθρου",
    "Change": "Αλλαγή",
    "Choose the data format": "Επιλογή μορφοποίησης δεδομένων",
    "Choropleth breakpoints": "Χωροπληθή σημεία διακοπής",
    "Choropleth classes": "Χωροπληθείς κατηγορίες",
    "Choropleth color palette": "Χωροπληθής παλέτα χρωμάτων",
    "Choropleth mode": "Χωροπληθής λειτουργία",
    "Choropleth property value": "Χωροπληθής τιμή ιδιότητας",
    "Choropleth": "Χωροπληθής χάρτης",
    "Circle": "Κύκλος",
    "clear": "Εκκαθάριση",
    "Click last point to finish shape": "Πατήστε στο τελευταίο σημείο για να ολοκληρωθεί το σχήμα",
    "Click to add a marker": "Πατήστε για την εισαγωγή σημείου",
    "Click to continue drawing": "Πατήστε για συνέχεια σχεδίασης",
    "Click to edit": "Πατήστε για επεξεργασία",
    "Click to start drawing a line": "Πατήστε για έναρξη σχεδιασμού γραμμής",
    "Click to start drawing a polygon": "Πατήστε για έναρξη σχεδιασμού πολυγώνου",
    "Clone of {name}": "Κλωνοποίηση του {name}",
    "Clone this feature": "Κλωνοποίηση αυτού του στοιχείου",
    "Clone this map": "Κλωνοποίηση αυτού του χάρτη",
    "Clone": "Κλωνοποίηση",
    "Close": "Κλείσιμο",
    "Clustered": "Σύμπλεγμα",
    "Clustering radius": "Ακτίνα συμπλέγματος",
    "collapsed": "Κατέρρευσε",
    "color": "Χρώμα",
    "Comma separated list of numbers, including min and max values.": "Λίστα αριθμών διαχωρισμένη με κόμμα, συμπεριλαμβανομένων των ελάχιστων και μέγιστων τιμών.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Τιμές διαχωρισμένες με κόμμα, tab ή άνω τελεία. Εννοείται και η μορφή SRS WGS84. Εισάγονται μόνο γεωμετρίες σημείων. Η διαδικασία εισαγωγής ελέγχει τις επικεφαλίδες των στηλών για τις ενδείξεις «lat» και «lon» στην αρχή της επικεφαλίδας και κάνει διάκριση πεζών - κεφαλαίων γραμμάτων. Όλες οι άλλες στήλες εισάγονται ως ιδιότητες.",
    "Congratulations, your map has been created!": "Συγχαρητήρια, ο χάρτης σας δημιουργήθηκε!",
    "Continue line": "Συνέχεια γραμμής",
    "Coordinates": "Συντεταγμένες",
    "copy": "αντιγραφή",
    "Credits": "Εύσημα",
    "Current map view": "Τρέχουσα προβολή χάρτη",
    "Current view instead of default map view?": "Τρέχουσα προβολή χάρτη αντί της προεπιλεγμένης",
    "Custom background": "Προσαρμοσμένο υπόβαθρο",
    "Custom overlay": "Προσαρμοσμένη επικάλυψη",
    "dash array": "Διάταξη παύλας",
    "Data is browsable": "Τα δεδομένα είναι περιηγήσιμα",
    "Datalayers": "Επίπεδα δεδομένων",
    "Default interaction options": "Αλληλεπίδραση",
    "Default properties": "Προεπιλεγμένες ιδιότητες",
    "Default shape properties": "Ιδιότητες σχημάτων",
    "Default view": "Default view",
    "Default zoom level": "Προεπιλεγμένο επίπεδο μεγέθυνσης",
    "Default": "Προεπιλογή",
    "Default: name": "Προεπιλογή: Όνομα",
    "Define link to open in a new window on polygon click.": "Προσδιορισμός συνδέσμου για άνοιγμα σε νέο παράθυρο με κλικ στο πολύγωνο",
    "define": "Ορισμός",
    "Delay between two transitions when in play mode": "Καθυστέρηση μεταξύ μεταβάσεων κατά την παρουσίαση",
    "Delete layer": "Διαγραφή επιπέδου",
    "Delete this feature": "Διαγραφή αυτού του στοιχείου",
    "Delete this shape": "Διαγραφή σχήματος",
    "Delete this vertex (Alt+Click)": "Διαγραφή αυτής της κορυφής (Alt+Click)",
    "Delete": "Διαγραφή",
    "description": "Περιγραφή",
    "Direct link": "Απευθείας σύνδεσμος",
    "Directions from here": "Κατευθύνσεις από εδώ",
    "Display label": "Εμφάνιση ετικέτας",
    "Display measure": "Εμφάνιση μέτρησης",
    "display name": "Όνομα που εμφανίζεται",
    "Display on load": "Εμφάνιση κατά την φόρτωση",
    "Display the control to open OpenStreetMap editor": "Εμφάνιση εικονιδίου επεξεργασίας OpenStreetMap",
    "Display the embed control": "Εμφάνιση εικονιδίου διαμοιρασμού",
    "Display the fullscreen control": "Εμφάνιση εικονιδίου πλήρους οθόνης",
    "Display the locate control": "Εμφάνιση εικονιδίου γεωεντοπισμού",
    "Display the measure control": "Εμφάνιση εικονιδίου μέτρησης",
    "Display the search control": "Εμφάνιση εικονιδίου αναζήτησης",
    "Display the tile layers control": "Εμφάνιση εικονιδίου αλλαγής υποβάθρων",
    "Display the zoom control": "Εμφάνιση εικονιδίου εστίασης",
    "Do you want to display a caption bar?": "Εμφάνιση λεζάντας",
    "Do you want to display a minimap?": "Εμφάνιση χάρτη προσανατολισμού",
    "Do you want to display a panel on load?": "Εμφάνιση καρτέλας κατά την φόρτωση",
    "Do you want to display caption menus?": "Θέλετε να εμφανίζονται τα μενού των λεζαντών;",
    "Do you want to display popup footer?": "Εμφάνιση αναδυόμενου υποσέλιδου",
    "Do you want to display the scale control?": "Εμφάνιση κλίμακας",
    "Do you want to display the «more» control?": "Εμφάνιση περισσότερων επιλογών",
    "Download": "Λήψη",
    "Drag to reorder": "Σύρετε για αναδιάταξη",
    "Draw a marker": "Σχεδιασμός σημείου",
    "Draw a polygon": "Σχεδιασμός πολυγώνου",
    "Draw a polyline": "Σχεδιασμός σύνθετης γραμμής",
    "Drawing": "Σχεδίαση",
    "Drop": "Σταγόνα",
    "Dynamic properties": "Δυναμικές ιδιότητες",
    "Dynamic": "Δυναμική",
    "Edit feature's layer": "Επεξεργασία επιπέδου του στοιχείου",
    "Edit properties in a table": "Επεξεργασία ιδιοτήτων σε πίνακα",
    "Edit the title of the map": "Επεξεργασία τίτλου του χάρτη",
    "Edit this feature": "Επεξεργασία αυτού του στοιχείου",
    "Edit": "Επεξεργασία",
    "Embed and link options": "Επιλογές ενσωμάτωσης και σύνδεσης",
    "Embed the map": "Ένθεση του χάρτη",
    "Emoji & Character": "Emoji & Χαρακτήρες",
    "Empty": "Κενό",
    "Equidistant": "Ισαπέχουσα",
    "Error in the overlay URL": "Σφάλμα στη διεύθυνση URL επικάλυψης",
    "Error in the tilelayer URL": "Σφάλμα συνδέσμου υποβάθρου",
    "Exit Fullscreen": "Κλείσιμο πλήρους οθόνης",
    "expanded": "Αναπτυγμένος",
    "Extract shape to separate feature": "Εξαγωγή σχήματος σε ξεχωριστό στοιχείο",
    "Feature identifier key": "Κλειδί αναγνώρισης στοιχείου",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Ανάκτηση δεδομένων κάθε φορά που αλλάζει η προβολή του χάρτη.",
    "fill color": "Χρώμα γεμίσματος",
    "fill opacity": "Αδιαφάνεια γεμίσματος",
    "fill": "Γέμισμα",
    "Fit all data": "Μεγέθυνση στα δεδομένα",
    "Format": "Μορφοποίηση",
    "From zoom": "Από εστίαση",
    "full backup": "πλήρες αντίγραφο ασφαλείας",
    "Generic": "Γενικός",
    "GeoRSS (only link)": "GeoRSS (μόνο σύνδεσμος)",
    "GeoRSS (title + image)": "GeoRSS (τίτλος + εικόνα)",
    "Go to \"{coords}\"": "Πήγαινε στις \"{coords}\"",
    "Go to the homepage": "Μετάβαση στην αρχική σελίδα",
    "Go to «{feature}»": "Μετάβαση στο «{feature}»",
    "Heatmap intensity property": "Ένταση του χάρτη εγγύτητας",
    "Heatmap radius": "Ακτίνα του χάρτη εγγύτητας",
    "Heatmap": "Χάρτης θερμότητας",
    "height": "Ύψος",
    "Help": "Βοήθεια",
    "hidden": "Απόκρυψη",
    "Hide controls": "Απόκρυψη εργαλείων ελέγχου",
    "Home": "Αρχική",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Πόσο απλοποιείται η συνθέτη γραμμή σε κάθε επίπεδο εστίασης (περισσότερο = καλύτερη απόδοση και ομαλότερη εμφάνιση, λιγότερο = περισσότερη ακρίβεια)",
    "icon opacity": "icon opacity",
    "Icon shape": "Μορφή εικονιδίου",
    "Icon symbol": "Σύμβολο εικονιδίου",
    "If false, the polygon or line will act as a part of the underlying map.": "Εάν είναι ψευδές, το πολύγωνο ή η γραμμή θα ενεργεί ως μέρος του υποκείμενου χάρτη.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe με προσαρμοσμένο ύψος (σε px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe με προσαρμοσμένο ύψος και πλάτος (σε px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Εικόνα με προσαρμοσμένο πλάτος (σε px): {{http://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Εικόνα: {{http://image.url.com}}",
    "Import data": "Εισαγωγή δεδομένων",
    "Import in a new layer": "Εισαγωγή σε νέο επίπεδο",
    "Imports all umap data, including layers and settings.": "Εισάγει όλα τα δεδομένα umap, μαζί με τα επίπεδα και τις ρυθμίσεις.",
    "Include full screen link?": "Συμπερίληψη συνδέσμου πλήρους οθόνης;",
    "Inherit": "Κληρονομημένο",
    "inherit": "Κληρονομημένο",
    "Interaction options": "Επιλογές αλληλεπίδρασης",
    "Invalid latitude or longitude": "Μη έγκυρο γεωγραφικό πλάτος ή μήκος",
    "Invalid umap data in {filename}": "Μη έγκυρα δεδομένα στο αρχείο {filename}",
    "Invalid umap data": "Μη έγκυρα δεδομένα umap",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Διατήρηση τρεχουσών ορατών επιπέδων",
    "kilometers": "Χιλιόμετρα",
    "km": "χμ.",
    "Label direction": "Κατεύθυνση ετικέτας",
    "Label key": "Κλειδί ετικέτας",
    "Labels are clickable": "Οι ετικέτες είναι ενεργές",
    "Latest feature": "Latest feature",
    "Latitude": "Γεωγραφικό πλάτος",
    "Layer properties": "Ιδιότητες επιπέδου",
    "Layer": "Επίπεδο",
    "Licence": "Άδεια",
    "licence": "Άδεια",
    "Limit bounds": "Περιορισμός ορίων",
    "Link to view the map": "Σύνδεσμος για προβολή του χάρτη",
    "Link to…": "Σύνδεση με...",
    "Link with text: [[https://example.com|text of the link]]": "Σύνδεση με κείμενο: [[http://example.com|text του συνδέσμου]]",
    "Long credits": "Αναλυτικές πιστώσεις",
    "Longitude": "Γεωγραφικό μήκος",
    "Make main shape": "Ορίστε το ως κύριο σχήμα",
    "Manage layers": "Διαχείριση επιπέδων",
    "Manual": "Χειροκίνητα",
    "Map background credits": "Πιστοποιητικά υποβάθρου του χάρτη",
    "Map has been attached to your account": "Ο χάρτης έχει συνδεθεί με τον λογαριασμό σας",
    "Map has been saved!": "Ο χάρτης έχει αποθηκευτεί!",
    "Map has been starred": "Ο χάρτης έχει επισημανθεί με αστέρι",
    "Map has been unstarred": "Το αστέρι αφαιρέθηκε από τον χάρτη",
    "Map user content has been published under licence": "Το περιεχόμενο του χάρτη έχει δημοσιευτεί με συγκεκριμένη άδεια",
    "Map's editors": "Συντάκτες",
    "Map's owner": "Ιδιοκτησία",
    "max East": "Μέγιστο ανατολικά",
    "max North": "Μέγιστο βόρεια",
    "max South": "Μέγιστο νότια",
    "max West": "Μέγιστο δυτικά",
    "max zoom": "Μέγιστη εστίαση",
    "Measure distances": "Μέτρηση αποστάσεων",
    "Merge lines": "Συγχώνευση γραμμών",
    "mi": "μλ.",
    "miles": "Μίλια",
    "min zoom": "Ελάχιστη εστίαση",
    "More controls": "Περισσότερα εργαλεία ελέγχου",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Πρέπει να είναι έγκυρη τιμή CSS (π.χ.: DarkBlue ή #123456)",
    "name": "Όνομα",
    "nautical miles": "Ναυτικά μίλια",
    "never": "Ποτέ",
    "new window": "Νέο Παράθυρο",
    "next": "Επόμενο",
    "NM": "ΝΜ",
    "No cache": "Δεν υπάρχει προσωρινή μνήμη",
    "No licence has been set": "Δεν έχει οριστεί άδεια χρήσης",
    "No results": "Δεν υπάρχουν αποτελέσματα",
    "no": "όχι",
    "No.": "Όχι.",
    "None": "Κανένα",
    "Number of desired classes (default 5)": "Αριθμός επιθυμητών κατηγοριών (προεπιλογή 5)",
    "On the bottom": "Στο κάτω μέρος",
    "On the left": "Στο αριστερό μέρος",
    "On the right": "Στο δεξί μέρος",
    "On the top": "Στο πάνω μέρος",
    "Only visible layers' data": "Μόνο δεδομένα ορατών στρώσεων",
    "opacity": "Αδιαφάνεια",
    "Opacity": "Αδιαφάνεια",
    "Open current feature on load": "Άνοιγμα τρέχοντος στοιχείου κατά τη φόρτωση",
    "Open link in…": "Άνοιγμα συνδέσμου σε…",
    "Open share & download panel": "Άνοιγμα πλαισίου διαμοιρασμού και λήψης",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ανοίξτε τον χάρτη σε έναν επεξεργαστή χαρτών για να παρέχετε πιο ακριβή δεδομένα στο OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Προαιρετική ιδιότητα έντασης για τον χάρτη εγγύτητας",
    "Optional. Same as color if not set.": "Προαιρετικό. Ίδιο με το χρώμα αν δεν οριστεί.",
    "Optional.": "Προαιρετικό",
    "Override clustering radius (default 80)": "Παράκαμψη ακτίνας συμπλέγματος (προεπιλογή 80)",
    "Override heatmap radius (default 25)": "Παράκαμψη ακτίνας χάρτη εγγύτητας (προεπιλογή 25)",
    "parent window": "Γονικό παράθυρο",
    "Paste your data here": "Επικόλληση των δεδομένων σας εδώ",
    "Permalink": "Μόνιμος σύνδεσμος",
    "Permanent credits background": "Φόντο μόνιμων ευσήμων",
    "Permanent credits": "Μόνιμα εύσημα",
    "Please be sure the licence is compliant with your use.": "Παρακαλώ βεβαιωθείτε ότι η άδεια είναι σύμφωνη με την χρήση σας",
    "Please choose a format": "Παρακαλώ επιλέξτε μια μορφοποίηση",
    "Please enter the name of the property": "Παρακαλώ εισαγάγετε το όνομα της ιδιότητας",
    "Please enter the new name of this property": "Παρακαλώ εισαγάγετε το νέο όνομα αυτής της ιδιότητας",
    "Please save the map first": "Παρακαλώ αποθηκεύστε τον χάρτη πρώτα",
    "Popup (large)": "Αναδυόμενο (μεγάλο)",
    "Popup content style": "Στυλ περιεχομένου αναδυόμενου",
    "Popup content template": "Αναδυόμενο πρότυπο περιεχομένου",
    "Popup shape": "Σχήμα αναδυόμενου",
    "Popup": "Αναδυόμενο",
    "Powered by uMap": "Με την υποστήριξη του uMap",
    "previous": "Προηγούμενο",
    "Problem in the response": "Πρόβλημα στην απόκριση",
    "Properties imported:": "Ιδιότητες που έχουν εισαχθεί:",
    "Provide an URL here": "Δώστε έναν σύνδεσμο εδώ",
    "Proxy request": "Αίτημα απομακρυσμένου διαμεσολαβητή",
    "Quantiles": "Ποσοστημόρια",
    "Recent": "Πρόσφατα",
    "Remote data": "Απομακρυσμένα δεδομένα",
    "Remove shape from the multi": "Αφαίρεση σχήματος από πολυδεδομένο",
    "Replace layer content": "Αντικατάσταση περιεχομένου του επιπέδου",
    "Restore this version": "Επαναφορά αυτής της έκδοσης",
    "Save current edits": "Αποθήκευση τρέχουσας επεξεργασίας",
    "Save map": "Αποθήκευση χάρτη",
    "Save": "Αποθήκευση",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Αναζήτηση τοποθεσίας",
    "Search": "Αναζήτηση",
    "Secret edit link:": "Μυστικός σύνδεσμος επεξεργασίας:",
    "See full screen": "Εμφάνιση πλήρους οθόνης",
    "See on OpenStreetMap": "Δείτε στο OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Απενεργοποίηση εάν επιθυμείτε την απόκρυψη του επιπέδου κατά την προβολή των διαφανειών, την περιήγηση δεδομένων, την αναδυόμενη πλοήγηση...",
    "settings": "ρυθμίσεις",
    "Shape properties": "Ιδιότητες σχήματος",
    "Share and download": "Κοινοποίηση και λήψη",
    "Share this link to open a customized map view": "Μοιραστείτε αυτόν τον σύνδεσμο για να ανοίξετε μια προσαρμοσμένη προβολή χάρτη",
    "Short credits": "Εύσημα εν συντομία",
    "Short link": "Σύντομος σύνδεσμος",
    "Show this layer in the caption": "Εμφάνιση αυτού του επιπέδου στη λεζάντα",
    "Show/hide layer": "Εμφάνιση/απόκρυψη επιπέδου",
    "Side panel": "Πλευρική εργαλειοθήκη",
    "Simple link: [[https://example.com]]": "Απλός σύνδεσμος: [[http://example.com]]",
    "Simplify": "Απλοποίηση",
    "Skipping unknown geometry.type: {type}": "Παράλειψη άγνωστου geometry.type: {type}",
    "Slideshow": "Παρουσίαση",
    "Sort key": "Κλειδί ταξινόμησης",
    "Split line": "Διαίρεση γραμμής",
    "Star this map": "Τοποθέτηση αστεριού σε αυτόν τον χάρτη",
    "Start a hole here": "Δημιουργία κενής περιοχής εδώ",
    "Start slideshow": "Έναρξη παρουσίασης",
    "Stop editing": "Τερματισμός επεξεργασίας",
    "Stop slideshow": "Τερματισμός παρουσίασης",
    "Street": "Οδός",
    "stroke": "Πινέλο",
    "Supported scheme": "Υποστηριζόμενο σχέδιο",
    "Supported variables that will be dynamically replaced": "Υποστηριζόμενες μεταβλητές που θα αντικατασταθούν δυναμικά",
    "Symbol": "Σύμβολο",
    "Table": "Πίνακας",
    "Text color for the cluster label": "Χρώμα κειμένου για την ετικέτα συμπλέγματος",
    "Text formatting": "Μορφοποίηση κειμένου",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Το όνομα της ιδιότητας που θα χρησιμοποιηθεί ως ετικέτα χαρακτηριστικών (π.χ.: «nom»). Μπορείτε επίσης να χρησιμοποιήσετε ιδιότητες μέσα σε αγκύλες, για να έχετε περισσότερες από μία ή να αναμίξετε με στατικό περιεχόμενο (π.χ.: «&lcub;name&rcub; in &lcub;place&rcub;»)",
    "The name of the property to use as feature unique identifier.": "Το όνομα της ιδιότητας που θα χρησιμοποιείται ως μοναδικό αναγνωριστικό.",
    "The zoom and center have been modified.": "Η εστίαση και το κέντρο έχουν τροποποιηθεί.",
    "TMS format": "Μορφοποίηση TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Για χρήση εάν ο απομακρυσμένος διακομιστής δεν επιτρέπει cross domain (πιο αργή)",
    "To zoom": "Για εστίαση",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Εναλλαγή λειτουργίας επεξεργασίας",
    "Transfer shape to edited feature": "Μεταφορά σχήματος σε επεξεργασμένο στοιχείο",
    "Transform to lines": "Μετασχηματισμός σε γραμμές",
    "Transform to polygon": "Μετασχηματισμός σε πολύγωνο",
    "Type a place name or coordinates": "Πληκτρολογήστε ένα όνομα τόπου ή τις συντεταγμένες του",
    "Type char or paste emoji": "Πληκτρολογήστε χαρακτήρα ή επικολλήστε emoji",
    "Type of layer": "Τύπος επιπέδου",
    "Unable to detect format of file {filename}": "Δεν είναι δυνατή η αναγνώριση της μορφοποίησης του αρχείου {filename}",
    "Untitled layer": "Επίπεδο χωρίς όνομα",
    "Untitled map": "Χάρτης χωρίς όνομα",
    "Update permissions and editors": "Ενημέρωση δικαιωμάτων και συντακτών",
    "Update permissions": "Ενημέρωση δικαιωμάτων χάρτη",
    "Update who can see and edit the map": "Ενημερώστε ποιος μπορεί να δει και ποιος να επεξεργαστεί τον χάρτη",
    "Url": "Σύνδεσμος",
    "URL": "URL",
    "Use current bounds": "Χρήση τρεχόντων ορίων",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Χρησιμοποιήστε σύμβολα υποκατάστασης με τις ιδιότητες του στοιχείου μεταξύ αγκυλών, π.χ. &#123;name&#125;, θα αντικατασταθούν δυναμικά από τις αντίστοιχες τιμές.",
    "User content credits": "Εύσημα περιεχομένου χρήστη",
    "User interface options": "Περιβάλλον χρήστη",
    "User location": "User location",
    "Verify remote URL": "Επαλήθευση απομακρυσμένης διεύθυνσης URL",
    "Versions": "Εκδόσεις",
    "View Fullscreen": "Προβολή πλήρους οθόνης",
    "View": "Προβολή",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "Βάρος",
    "Where do we go from here?": "Πού πάμε από εδώ;",
    "Whether to display or not polygons paths.": "Εάν πρόκειται να εμφανίσετε ή όχι μονοπάτια πολυγώνων.",
    "Whether to fill polygons with color.": "Εάν πρόκειται να γεμίσετε πολύγωνα με χρώμα.",
    "Who can edit \"{layer}\"": "Ποιος μπορεί να επεξεργαστεί \"{layer}\"",
    "Who can edit": "Επεξεργασία",
    "Who can view": "Προβολή",
    "width": "Πλάτος",
    "Will be displayed in the bottom right corner of the map": "Θα εμφανιστεί στην κάτω δεξιά γωνία του χάρτη",
    "Will be permanently visible in the bottom left corner of the map": "Θα είναι μόνιμα ορατό στην κάτω αριστερή γωνία του χάρτη.",
    "Will be visible in the caption of the map": "Θα είναι ορατό στη λεζάντα του χάρτη",
    "yes": "ναι",
    "Zoom in": "Μεγέθυνση",
    "Zoom level for automatic zooms": "Επίπεδο εστίασης για αυτόματες μεγεθύνσεις/σμικρύνσεις",
    "Zoom out": "Σμίκρυνση",
    "Zoom to layer extent": "Εστίαση στο χώρο κάλυψης του επίπεδου",
    "Zoom to the next": "Εστίαση στο επόμενο",
    "Zoom to the previous": "Εστίαση στο προηγούμενο",
    "Zoom to this feature": "Εστίαση σε αυτό το στοιχείο",
    "{area}&#8239;acres": "{area}&#8239;έικρ",
    "{area}&#8239;ha": "{area}&#8239;εκτάρια",
    "{area}&#8239;m&sup2;": "{area}&#8239;μέτρα&sup2;",
    "{area}&#8239;mi&sup2;": "{area}&#8239;μίλια&sup2;",
    "{area}&#8239;yd&sup2;": "{area}&#8239;γιάρδες&sup2;",
    "{count} errors during import: {message}": "{count} σφάλματα κατά την εισαγωγή: {message}",
    "{delay} seconds": "{delay} δευτερόλεπτα",
    "{distance}&#8239;km": "{distance}&#8239;χιλιόμετρα",
    "{distance}&#8239;m": "{distance}&#8239;μέτρα",
    "{distance}&#8239;miles": "{distance}&#8239;μίλια",
    "{distance}&#8239;NM": "{distance}&#8239;ναυτικά μίλια",
    "{distance}&#8239;yd": "{distance}&#8239;γιάρδες",
    "Edit map name and caption": "Επεξεργασία ονόματος και λεζάντας χάρτη",
    "Map advanced properties": "Σύνθετες ιδιότητες χάρτη",
    "Edit map details": "Επεξεργασία λεπτομερειών χάρτη",
    "Back to browser": "Πίσω στον περιηγητή",
    "Toggle size": "Εναλλαγή μεγέθους",
    "Display the caption control": "Εμφάνιση του χειριστηρίου λεζάντας",
    "<empty value>": "<empty value>",
    "Min": "Ελάχιστο",
    "Max": "Μέγιστο",
    "From": "Από",
    "Until": "Μέχρι",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Παράδειγμα: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Επεξεργασία στο OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Δεν είναι δυνατός ο προσδιορισμός των στηλών γεωγραφικού πλάτους και γεωγραφικού μήκους.",
    "Back to layers": "Πίσω στις στρώσεις",
    "Filters": "Φίλτρα",
    "Comma separated list of properties to use when filtering features by text input": "Λίστα ιδιοτήτων διαχωρισμένων με κόμμα, που θα χρησιμοποιηθούν κατά το φιλτράρισμα χαρακτηριστικών με εισαγωγή κειμένου.",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Λίστα ιδιοτήτων διαχωρισμένων με κόμμα, που θα χρησιμοποιηθούν για τα φίλτρα (π.χ.: mykey,otherkey). Για να ελέγξετε την ετικέτα, προσθέστε την μετά από ένα | (π.χ.: mykey|My Key,otherkey|Other Key). Για να ελέγξετε τον τύπο του πεδίου εισόδου, προσθέστε το μετά από ένα άλλο | (π.χ.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Οι επιτρεπόμενες τιμές για τον τύπο πεδίου εισόδου είναι checkbox (προεπιλογή), radio, number, date και datetime.",
    "Search keys": "Αναζήτηση κλειδιών",
    "Filters keys": "Πλήκτρα φίλτρων",
    "Filter data": "Δεδομένα φίλτρου",
    "Search map features…": "Χαρακτηριστικά αναζήτησης του χάρτη...",
    "Reset all": "Επαναφορά όλων",
    "Open browser": "Άνοιγμα προγράμματος περιήγησης",
    "Open caption": "Άνοιγμα λεζάντας",
    "Your map has been created with an anonymous account!": "Ο χάρτης σας δημιουργήθηκε με ανώνυμο λογαριασμό!",
    "Real-time collaboration": "Συνεργασία σε πραγματικό χρόνο",
    "Cannot parse data": "Δεν είναι δυνατή η ανάλυση δεδομένων",
    "Start typing...": "Έναρξη πληκτρολόγησης...",
    "No result": "Κανένα αποτέλεσμα",
    "Data browser": "Περιηγητής δεδομένων",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Όταν παρέχεται μια διεύθυνση URL, το uMap μπορεί να αντιγράψει τα απομακρυσμένα δεδομένα σε ένα επίπεδο ή να προσθέσει αυτή τη διεύθυνση URL ως απομακρυσμένη πηγή του επιπέδου. Σε αυτή την περίπτωση, τα δεδομένα θα αντλούνται πάντα από αυτή τη διεύθυνση URL, και έτσι θα είναι ενημερωμένα, αλλά δεν θα είναι δυνατή η επεξεργασία τους μέσα στο uMap.",
    "Overpass supported expressions": "Υποστηριζόμενες εκφράσεις υπέρβασης",
    "key (eg. building)": "κλειδί (π.χ. κτίριο)",
    "!key (eg. !name)": "!κλειδί (π.χ. !όνομα)",
    "key=value (eg. building=yes)": "κλειδί=τιμή (π.χ. κτίριο=ναι)",
    "key!=value (eg. building!=yes)": "κλειδί!=τιμή (π.χ. κτίριο!=ναι)",
    "key~value (eg. name~Grisy)": "κλειδί~τιμή (π.χ. όνομα~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "κλειδί=\"value|value2\" (eg. όνομα=\"Παρίσι|Βερολίνο\")",
    "More info about Overpass syntax": "Περισσότερες πληροφορίες σχετικά με τη σύνταξη της Υπέρβασης",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Συνθήκη",
    "key=value or key!=value": "key=value ή key!=value",
    "Are you sure you want to delete this rule?": "Θέλετε σίγουρα να διαγραφεί αυτός ο κανόνας;",
    "empty rule": "κενός κανόνας",
    "Conditional style rules": "Κανόνες μορφοποίησης υπό όρους",
    "Add rule": "Προσθήκη κανόνα",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Αντιγράφηκε!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Αναζήτηση διοικητικού ορίου",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Έκφραση",
    "Geometry mode": "Λειτουργία γεωμετρίας",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Παλέτα χρωμάτων",
    "Categories": "Κατηγορίες",
    "Comma separated list of categories.": "Λίστα κατηγοριών χωρισμένες με κόμμα.",
    "Categories mode": "Λειτουργία κατηγοριών",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Η έκφραση είναι κενή",
    "OK": "OK",
    "Cancel": "Άκυρο",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("el", locale)
L.setLocale("el")
