const locale = {
    "(area: {measure})": "(gorread: {measure})",
    "(length: {measure})": "(hirder: {measure})",
    "# one hash for main heading": "# un diezenn evit an titl pennañ",
    "## two hashes for second heading": "## div ziezenn evit an eil titl",
    "### three hashes for third heading": "### teir diezenn evit an trede titl",
    "**double star for bold**": "**div steredennig evit tevaat**",
    "*single star for italic*": "*ur steredennig simpl evit italek*",
    "--- for a horizontal rule": "--- evit ul linenn-disparti a-blaen",
    "1 day": "1 deiz",
    "1 hour": "1 eur",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Diwar-benn",
    "Action not allowed :(": "N'oc'h ket aotreet d'ober kement-se :(",
    "Activate slideshow mode": "Gweredekaat ar mod diaporama",
    "Add a layer": "Ouzhpennañ ur gwiskad",
    "Add a line to the current multi": "Ouzhpennañ ul linenn d'ar strollad a-vremañ",
    "Add a new property": "Ouzhpennañ ur perzh nevez",
    "Add a polygon to the current multi": "Ouzhpennañ ul lieskorn d'ar strollad a-vremañ",
    "Add image URL": "Ouzhpennañ URL ar skeudenn",
    "Advanced actions": "Oberoù araokaet",
    "Advanced properties": "Perzhioù araokaet",
    "All data and settings of the map": "Holl roadennoù hag arventennoù ar gartenn",
    "All properties are imported.": "Enporzhiet eo bet an holl berzhioù.",
    "Allow interactions": "Aotren an etreoberiadennoù",
    "Allow scroll wheel zoom?": "Aotren ar zoum gant ar rodell?",
    "always": "bepred",
    "Animated transitions": "Tremenoù buhezek",
    "Are you sure you want to clone this map and all its datalayers?": "Ha sur oc'h e faot deoc'h doublañ ar gartenn-mañ hag hec'h holl wiskadoù roadennoù?",
    "Are you sure you want to delete this map?": "Ha sur oc'h e faot deoc'h dilemel ar gartenn-mañ?",
    "Are you sure you want to delete this property on all the features?": "Ha sur oc'h a faot deoc'h lemel ar perzh-mañ diwar an holl elfennoù?",
    "Are you sure you want to restore this version?": "Ha sur oc'h e faot deoc'h adsevel ar stumm-mañ?",
    "Attach the map to my account": "Stagañ ar gartenn d'am c'hont",
    "attribution": "deroadur",
    "Auto": "Emgefre",
    "Automatic": "Emgefreek",
    "Autostart when map is loaded": "Loc'hañ pa vez karget ar gartenn",
    "Back to preview": "Distreiñ d'ar rakwel",
    "Background overlay url": "URL ar foñs",
    "Ball": "Spilhenn",
    "Bring feature to center": "Kreizañ ar gartenn war an elfenn-mañ",
    "Browse data": "Furchal ar roadennoù",
    "by": "gant",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Alc'hwez",
    "Center map on your location": "Kreizañ ar gartenn war al lec'h m'emaoc'h",
    "Change map background": "Cheñch foñs ar gartenn",
    "Change tilelayers": "Cheñch foñs ar gartenn",
    "Change": "Kemmañ",
    "Choose the data format": "Diuzañ furmad ar roadennoù",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Kelc'h",
    "clear": "skarzhañ",
    "Click last point to finish shape": "Klikañ war ar poent diwezhañ evit echuiñ an tres",
    "Click to add a marker": "Klikañ evit ouzhpennañ ur valizenn",
    "Click to continue drawing": "Klikañ evit kenderc'hel da dresañ",
    "Click to edit": "Klikañ evit aozañ",
    "Click to start drawing a line": "Klikañ evit tresañ ul linenn",
    "Click to start drawing a polygon": "Klikañ evit tresañ ul lieskorn",
    "Clone of {name}": "Eilenn eus {name}",
    "Clone this feature": "Doublañ an elfenn-mañ",
    "Clone this map": "Doublañ ar gartenn-mañ",
    "Clone": "Doublañ",
    "Close": "Serriñ",
    "Clustered": "Clustered",
    "Clustering radius": "Clustering radius",
    "collapsed": "serret",
    "color": "liv",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Gourc'hemennoù, ho kartenn zo bet krouet!",
    "Continue line": "Kenderc'hel al linenn",
    "Coordinates": "Daveennoù",
    "copy": "eilañ",
    "Credits": "Kredadoù",
    "Current map view": "Listenn an objedoù a c'haller gwelet",
    "Current view instead of default map view?": "Gwel a-vremañ e-lec'h ar gwel dre ziouer?",
    "Custom background": "Foñs personelaet",
    "Custom overlay": "Gwiskad personelaet",
    "dash array": "Barrennoùigoù",
    "Data is browsable": "Ar roadennoù a c'haller merdeiñ",
    "Datalayers": "Gwiskadoù",
    "Default interaction options": "Dibarzhioù etreoberiañ dre ziouer",
    "Default properties": "Perzhioù dre ziouer",
    "Default shape properties": "Perzhioù ar furm dre ziouer",
    "Default view": "Gwel dre ziouer",
    "Default zoom level": "Live zoum dre ziouer",
    "Default": "Dre ziouer",
    "Default: name": "Dre ziouer: anv",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "termenañ",
    "Delay between two transitions when in play mode": "Dale etre daou dremen pa vez e mod lenn",
    "Delete layer": "Dilemel ar gwiskad",
    "Delete this feature": "Dilemel an elfenn-mañ",
    "Delete this shape": "Dilemel an tres-mañ",
    "Delete this vertex (Alt+Click)": "Dilemel ar poent-mañ (Erl+Klik)",
    "Delete": "Dilemel",
    "description": "deskrivadur",
    "Direct link": "Liamm eeun",
    "Directions from here": "Heñchadurioù adalek amañ",
    "Display label": "Diskouez un dikedenn",
    "Display measure": "Diskouez ar muzulioù",
    "display name": "anv diskwel",
    "Display on load": "Diskwel en ur gargañ",
    "Display the control to open OpenStreetMap editor": "Diskwel an afell evit digeriñ an aozer OpenStreetMap",
    "Display the embed control": "Diskwel an afell \"enframmañ\"",
    "Display the fullscreen control": "Diskwel an afell \"skramm a-bezh\"",
    "Display the locate control": "Diskwel an afell \"lec'hiañ\"",
    "Display the measure control": "Diskwel an afell muzuliañ",
    "Display the search control": "Diskwel an afell \"klask\"",
    "Display the tile layers control": "Diskwel an afell \"cheñch foñs ar gartenn\"",
    "Display the zoom control": "Diskwel an afelloù \"zoumañ\" ha \"dizoumañ\"",
    "Do you want to display a caption bar?": "Diskwel ur varrenn alc'hwez?",
    "Do you want to display a minimap?": "Diskwel ur gartennig evit en em lec'hiañ?",
    "Do you want to display a panel on load?": "Do you want to display a panel on load?",
    "Do you want to display caption menus?": "Diskwel lañser an alc'hwezioù?",
    "Do you want to display popup footer?": "Diskwel an diflugell e traoñ ar bajenn?",
    "Do you want to display the scale control?": "Diskwel skeul ar gartenn?",
    "Do you want to display the «more» control?": "Diskwel an afell \"muioc'h\"?",
    "Download": "Pellgargañ",
    "Drag to reorder": "Riklañ evit adurzhiañ",
    "Draw a marker": "Ouzhpennañ ur valizenn",
    "Draw a polygon": "Tresañ ul lieskorn",
    "Draw a polyline": "Tresañ ul linenn",
    "Drawing": "Tres",
    "Drop": "Takenn",
    "Dynamic properties": "Perzhioù buhezek",
    "Dynamic": "Buhezek",
    "Edit feature's layer": "Kemmañ gwiskad an elfenn",
    "Edit properties in a table": "Aozañ ar perzhioù en un daolenn",
    "Edit the title of the map": "Kemmañ titl ar gartenn",
    "Edit this feature": "Kemmañ an elfenn-mañ",
    "Edit": "Aozañ",
    "Embed and link options": "Dibarzhioù enframmañ ha liammoù",
    "Embed the map": "Enframmañ ar gartenn",
    "Emoji & Character": "Emoji & Testenn",
    "Empty": "Goullonderiñ",
    "Equidistant": "Keitpell",
    "Error in the overlay URL": "URL foñs ar gartenn direizh",
    "Error in the tilelayer URL": "Ur fazi zo en URL foñs ar gartenn",
    "Exit Fullscreen": "Kuitaat ar mod skramm a-bezh",
    "expanded": "digor",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Feature identifier key": "Alc'hwez anaout un elfenn",
    "Feature properties": "Perzhioù an elfenn",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "liv leuniañ",
    "fill opacity": "demerez al leuniañ",
    "fill": "leuniañ",
    "Fit all data": "Zoumañ war ar roadennoù",
    "Format": "Furmad",
    "From zoom": "Adalek ar zoum",
    "full backup": "gwarez klok",
    "Generic": "Standard",
    "GeoRSS (only link)": "GeoRSS (liamm hepken)",
    "GeoRSS (title + image)": "GeoRSS (titl + skeudenn)",
    "Go to \"{coords}\"": "Mont da \"{coords}\"",
    "Go to the homepage": "Mont d'ar bajenn degemer",
    "Go to «{feature}»": "Mont da «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Skin ar gartenn dermek",
    "Heatmap": "Kartenn dermek",
    "height": "uhelder",
    "Help": "Skoazell",
    "hidden": "kuzhet",
    "Hide controls": "Kuzhat ar binvioù",
    "Home": "Degemer",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "icon opacity": "Demerez an ikon",
    "Icon shape": "Furm an ikon",
    "Icon symbol": "Arouez an ikon",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe gant uhelder personelaet (e pikselioù): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe gant mentoù personelaet (e pikselioù): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Skeudenn gant ledander personelaet (e pikselioù): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Skeudenn: {{https://image.url.com}}",
    "Import data": "Enporzhiañ roadennoù",
    "Import in a new layer": "Enporzhiañ ur gwiskad nevez",
    "Imports all umap data, including layers and settings.": "Enporzhiañ holl roadennoù ar gartenn, ar gwiskadoù hag an arventennoù en o zouez.",
    "Include full screen link?": "Lakaat ul liamm \"skramm a-bezh\" e-barzh?",
    "Inherit": "Heritañ",
    "inherit": "heritañ",
    "Interaction options": "Dibarzhioù etre-ober",
    "Invalid latitude or longitude": "Hedred pe ledred direizh",
    "Invalid umap data in {filename}": "Roadennoù umap direizh e-barzh {filename}",
    "Invalid umap data": "Roadennoù umap direizh",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Derc'hel ar gwiskadoù a c'haller gwelet bremañ",
    "kilometers": "kilometroù",
    "km": "km",
    "Label direction": "Durc'hadur an dikedenn",
    "Label key": "Alc'hwez an dikedenn",
    "Labels are clickable": "An dikedennoù a c'haller klikañ",
    "Latest feature": "Elfenn diwezhañ",
    "Latitude": "Ledred",
    "Layer properties": "Perzhioù ar gwiskad",
    "Layer": "Gwiskad",
    "Licence": "Aotre-implijout",
    "licence": "aotre-implijout",
    "Limit bounds": "Bevennoù geografek",
    "Link to view the map": "Liamm evit gwelet ar gartenn",
    "Link to…": "Liamm etrezek...",
    "Link with text: [[https://example.com|text of the link]]": "Liamm gant testenn: [[https://skouer.bzh|testenn al liamm]]",
    "Long credits": "Kredadoù hir",
    "Longitude": "Hedred",
    "Make main shape": "Tres pennañ",
    "Manage layers": "Merañ ar gwiskadoù",
    "Manual": "Sturlevr",
    "Map background credits": "Kredadoù foñs ar gartenn",
    "Map has been attached to your account": "Staget eo bet ar gartenn d'ho kont",
    "Map has been saved!": "Enrollet eo bet ar gartenn!",
    "Map has been starred": "Spilhennet eo bet ar gartenn",
    "Map has been unstarred": "Dispilhennet eo bet ar gartenn",
    "Map user content has been published under licence": "Endalc'had ar gartenn zo bet embannet gant an aotre-implijout",
    "Map's editors": "Aozerien ar gartenn",
    "Map's owner": "Perc'henner ar gartenn",
    "max East": "bevenn reterañ",
    "max North": "bevenn norzhañ",
    "max South": "bevenn suañ",
    "max West": "bevenn gornôgañ",
    "max zoom": "zoum brasañ",
    "Measure distances": "Muzuliañ pellderioù",
    "Merge lines": "Kendeuziñ al linennoù",
    "mi": "mi",
    "miles": "miltirioù",
    "min zoom": "zoum bihanañ",
    "More controls": "Binvioù all",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Rankout a ra bezañ un talvoud CSS reizh (da sk.: DarkBlue pe #123456)",
    "name": "anv",
    "nautical miles": "milmorioù",
    "never": "morse",
    "new window": "prenestr nevez",
    "next": "war-lerc'h",
    "NM": "NM",
    "No cache": "Krubuilh ebet",
    "No licence has been set": "Aotre-implijout ebet bet termenet",
    "No results": "Disoc'h ebet",
    "no": "ket",
    "No.": "Ket.",
    "None": "Hini ebet",
    "Number of desired classes (default 5)": "Niver a renkadoù hoc'h eus c'hoant (5 dre ziouer)",
    "On the bottom": "D'an traoñ",
    "On the left": "A-gleiz",
    "On the right": "A-zehoù",
    "On the top": "D'an nec'h",
    "Only visible layers' data": "Roadennoù ar gwiskadoù a c'haller gwelet hepken",
    "opacity": "demerez",
    "Opacity": "Demerez",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Digeriñ al liamm e...",
    "Open share & download panel": "Digeriñ ar banell \"rannañ ha pellgargañ\"",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Diret. Al liv pennañ a vo implijet ma ne vez ket termenet.",
    "Optional.": "Diret.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "prenestr kar",
    "Paste your data here": "Pegit ho roadennoù amañ",
    "Permalink": "Liamm padus",
    "Permanent credits background": "Foñs ar c'hredadoù padus",
    "Permanent credits": "Kredadoù padus",
    "Please be sure the licence is compliant with your use.": "Gwiriit m'az oc'h aotreet da implijout ar roadennoù-mañ mar plij.",
    "Please choose a format": "Diuzit ur furmad mar plij",
    "Please enter the name of the property": "Enankit anv ar perzh mar plij",
    "Please enter the new name of this property": "Enankit anv nevez ar perzh-mañ mar plij",
    "Please save the map first": "Ret eo deoc'h enrollañ ar gartenn da gentañ",
    "Popup (large)": "Diflugell (vras)",
    "Popup content style": "Neuz endalc'had an diflugell",
    "Popup content template": "Popup content template",
    "Popup shape": "Stumm an diflugell",
    "Popup": "Diflugell",
    "Powered by uMap": "Lusket gant uMap",
    "previous": "kent",
    "Problem in the response": "Kudenn e respont ar servijer",
    "Properties imported:": "Perzhioù enporzhiet:",
    "Provide an URL here": "Pourchas un URL amañ",
    "Proxy request": "Reked proksi",
    "Quantiles": "Kwantiloù",
    "Recent": "Nevez zo",
    "Remote data": "Roadennoù a-bell",
    "Remove shape from the multi": "Tennañ ar furm diouzh ar strollad",
    "Replace layer content": "Erlec'hiañ endalc'had ar gwiskad",
    "Restore this version": "Adsevel ar stumm-mañ?",
    "Save current edits": "Enrollañ ar c'hemmoù a-vremañ ",
    "Save map": "Enrollañ ar gartenn",
    "Save": "Enrollañ",
    "Saved center and zoom": "Kreiz ha zoum enrollet",
    "Search location": "Klask ul lec'h",
    "Search": "Klask",
    "Secret edit link:": "Liamm aozañ kuzh:",
    "See full screen": "Gwelet e skramm a-bezh",
    "See on OpenStreetMap": "Gwelet war OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Diweredekaat evit kuzhat ar gwiskad-mañ ouzh an diaporama, ar merdeer roadennoù...",
    "settings": "arventennoù",
    "Shape properties": "Perzhioù ar furm",
    "Share and download": "Rannañ ha pellgargañ",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Kredadoù berr",
    "Short link": "Liamm berr",
    "Show this layer in the caption": "Diskouez ar gwiskad-mañ en alc'hwez",
    "Show/hide layer": "Diskouez/kuzhat ar gwiskad",
    "Side panel": "Panell gostez",
    "Simple link: [[https://example.com]]": "Liamm simpl: [[https://skouer.bzh]]",
    "Simplify": "Eeunaat",
    "Skipping unknown geometry.type: {type}": "Tremen e-bioù tikedenn geometry.type dianav: {type}",
    "Slideshow": "Diaporama",
    "Sort key": "Alc'hwez renkañ",
    "Split line": "Disrannañ al linenn",
    "Star this map": "Spilhennañ ar gartenn-mañ",
    "Start a hole here": "Ouzhpennañ un toull e-barzh",
    "Start slideshow": "Lenn",
    "Stop editing": "Paouez da aozañ",
    "Stop slideshow": "Ehan",
    "Street": "Straed",
    "stroke": "tres",
    "Supported scheme": "Steuñv skoret",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol": "Arouezenn",
    "Table": "Taolenn",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Furmaozañ an destenn",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "Kemmet eo bet ar zoum hag ar c'hreiz.",
    "TMS format": "Furmad TMS",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Betek ar zoum",
    "Toggle edit mode (⇧+Click)": "Gweredekaat ar mod aozañ (⇧+Click)",
    "Toggle edit mode": "Gweredekaat ar mod aozañ",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Treiñ da linennoù",
    "Transform to polygon": "Treiñ d'ul lieskorn",
    "Type a place name or coordinates": "Skrivit anv ul lec'h pe daveennoù",
    "Type char or paste emoji": "Skrivañ un destenn pe pegañ un emoji",
    "Type of layer": "Seurt ar gwiskad",
    "Unable to detect format of file {filename}": "N'haller ket anavezout furmad ar restr {filename}",
    "Untitled layer": "Gwiskad hep anv",
    "Untitled map": "Kartenn hep anv",
    "Update permissions and editors": "Kemmañ an aotreoù hag an aozerien",
    "Update permissions": "Kemmañ an aotreoù",
    "Update who can see and edit the map": "Termenañ piv a c'hall gwelet ha kemmañ ar gartenn",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Implij ar gwel a-vremañ",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Kredadoù evit danvez an implijer",
    "User interface options": "Dibarzhioù etrefas an implijer",
    "User location": "Lec'hiadur an implijer",
    "Verify remote URL": "Gwiriañ an URL",
    "Versions": "Stummoù",
    "View Fullscreen": "Mont e mod skramm a-bezh",
    "View": "Gwelet",
    "Visibility: {status}": "Gwelusted: {status}",
    "weight": "tevder",
    "Where do we go from here?": "Dre belec'h ez eomp adalek amañ?",
    "Whether to display or not polygons paths.": "Diskouez trolinennoù al lieskornoù",
    "Whether to fill polygons with color.": "Leuniañ al lieskornoù gant liv",
    "Who can edit \"{layer}\"": "Piv a c'hall aozañ \"{layer}\"",
    "Who can edit": "Piv a c'hall aozañ",
    "Who can view": "Piv a c'hall gwelet",
    "width": "ledander",
    "Will be displayed in the bottom right corner of the map": "Diskwelet e vo e traoñ a-zehoù ar gartenn",
    "Will be permanently visible in the bottom left corner of the map": "Diskwel dalc'hmat e traoñ a-gleiz ar gartenn",
    "Will be visible in the caption of the map": "Gwelus e vo en alc'hwez ar gartenn",
    "yes": "ya",
    "Zoom in": "Zoumañ",
    "Zoom level for automatic zooms": "Live ar zoum emgefreek",
    "Zoom out": "Dizoumañ",
    "Zoom to layer extent": "Zoumañ evit gwelet ar gwiskad en e bezh",
    "Zoom to the next": "War-lerc'h",
    "Zoom to the previous": "Kent",
    "Zoom to this feature": "Zoumañ war an elfenn-mañ",
    "{area}&#8239;acres": "{area} erv",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} fazi zo bet en ur enporzhiañ: {message}",
    "{delay} seconds": "{delay} segondenn",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miltir",
    "{distance}&#8239;NM": "{distance} milmor",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Kemmañ anv hag alc'hwez ar gartenn",
    "Map advanced properties": "Perzhioù araokaet ar gartenn",
    "Edit map details": "Kemmañ munudoù ar gartenn",
    "Back to browser": "Distreiñ d'ar merdeer",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Bihanañ",
    "Max": "Brasañ",
    "From": "Adalek",
    "Until": "Betek",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Kemmañ e-barzh OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Distreiñ d'ar gwiskadoù",
    "Filters": "Siloù",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Roadennoù ar sil",
    "Search map features…": "Klask perzhioù ar gartenn..",
    "Reset all": "Adlakaat pep tra",
    "Open browser": "Digeriñ ar merdeer",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "N'haller ket dielfennañ ar roadennoù",
    "Start typing...": "Krogit da skrivañ...",
    "No result": "Disoc'h ebet",
    "Data browser": "Furchal ar roadennoù",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Dibab ar roadennoù",
    "Choose the format": "Dibab ar furmad",
    "Choose the layer": "Dibab ar gwiskad",
    "Layer name": "Anv ar gwiskad",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Eilañ e-barzh ar gwiskad",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value pe key!=value",
    "Are you sure you want to delete this rule?": "Ha sur oc'h e faot deoc'h dilemel ar reolenn-mañ?",
    "empty rule": "Reolenn goullo",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Ouzhpennañ ur reolenn",
    "Browser: data": "Merdeer: roadennoù",
    "Browser: layers": "Merdeer: gwiskadoù",
    "Browser: filters": "Merdeer: siloù",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Eilet !",
    "Choose a dataset": "Dibab un hollad cheñchamantoù",
    "Choose this dataset": "Dibab an hollad cheñchamantoù-mañ",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Dibab un tem",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Dibab ar roadennoù-mañ",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Mod mentoniezh",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Roadennoù enporzhiet gant berzh!",
    "Clear data": "Skarzhañ ar roadennoù",
    "Remove layers": "Lemel ar gwiskadoù",
    "Categorized": "Dre rummad",
    "Alphabetical": "Urzh al lizherenneg",
    "Category property": "Perzh",
    "Color palette": "Color palette",
    "Categories": "Rummadoù",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Adenvel ar bann-mañ",
    "Delete this column": "Dilemel ar bann-mañ",
    "Name “{name}” should not contain a dot.": "Ne rankfe ket bout ur pik e-barzh an anv “{name}”.",
    "This name already exists: “{name}”": "Bout 'zo an anv-se dija:  “{name}”",
    "Delete selected rows": "Dilemel al linennoù diuzet",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "Mat eo",
    "Cancel": "Nullañ",
    "Attach map to a team": "Stagañ ar gartenn d'ur skipailh",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Skin bihanañ ar c'helc'h",
    "Max circle radius": "Skin brasañ ar c'helc'h",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Eilañ evel ur restr GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "Kartenn nevez",
    "My maps": "Ma c'hartennoù",
    "My teams": "Ma skipailhoù",
    "My profile": "Ma frofil",
    "Type new owner's username": "Skrivit anv-implijer ar perc'henner nevez",
    "Type editor's username": "Skrivit anv-implijer an aozer",
    "Map": "Kartenn",
    "Manage collaborators": "Merañ ar c'henlabourerien",
    "show/hide all layers": "diskouez/kuzhat an holl wiskadoù",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "Pellgargañ ar roadennoù war-wel",
    "Import helpers": "Skoazellerien enporzhiañ",
    "Import helpers will fill the URL field for you.": "Ar skoazellerien enporzhiañ a leunio maezienn an URL evidoc'h.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Enrollañ ar brouilhed",
    "No data has been found for import": "N'eus bet kavet roadenn ebet da enporzhiañ",
    "Successfully imported {count} feature(s)": "{count} elfenn bet enporzhiet gant berzh",
    "Disconnected": "Digennasket",
    "You must be logged in": "Ret eo deoc'h bezañ kennasket",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Enporzhiadur c'hwitet: roadennoù direizh",
    "Anonymous": "Dizanv",
    "created at {date}": "bet krouet d'an {date}",
    "modified at {date}": "bet kemmet d'an {date}",
    "Default zoom": "Zoum dre ziouer",
    "Default latitude": "Ledred dre ziouer",
    "Default longitude": "Hedred dre ziouer",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("br", locale)
L.setLocale("br")
