const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# un coixinet per a capçalera principal",
    "## two hashes for second heading": "## dos coixinets per a capçalera secundària",
    "### three hashes for third heading": "### tres coixinets per a capçalera tercera",
    "**double star for bold**": "**doble asteric per a negreta**",
    "*single star for italic*": "*sola asteric per a cursiva*",
    "--- for a horizontal rule": "--- per un separador horitzontal",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una llista de números separats per comes que defineix el patró de traç. Ex.: \"5, 10, 15\".",
    "About": "Quant a",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activa el mode de presentació",
    "Add a layer": "Afegeix una capa",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Advanced actions": "Opcions avançades",
    "Advanced properties": "Propietats avançades",
    "All data and settings of the map": "Totes les dades i configuracions del mapa",
    "All properties are imported.": "S'han importat totes les propietats",
    "Allow interactions": "Allow interactions",
    "Allow scroll wheel zoom?": "Voleu permetre el zoom amb la roda de desplaçament?",
    "always": "sempre",
    "Animated transitions": "Transicions animades",
    "Are you sure you want to clone this map and all its datalayers?": "Esteu segur de voler clonar aquest mapa i totes les capes de dades?",
    "Are you sure you want to delete this map?": "Esteu segur de voler suprimir aquest mapa?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Adjunta el mapa al meu compte",
    "attribution": "atribució",
    "Auto": "Auto",
    "Automatic": "Automàtic",
    "Autostart when map is loaded": "Inici automàtic quan es carregui el mapa",
    "Back to preview": "Tornar a la vista prèvia",
    "Background overlay url": "URL de superposició del fons",
    "Ball": "Bola",
    "Bring feature to center": "Porta el element al centre",
    "Browse data": "Explora les dades",
    "by": "per",
    "Cache proxied request": "Petició proxy en memòria cau",
    "Caption": "Llegenda",
    "Center map on your location": "Centra el mapa a la vostra ubicació",
    "Change map background": "Canvia el fons del mapa",
    "Change tilelayers": "Canvia les capes de tessel·les",
    "Change": "Change",
    "Choose the data format": "Trieu el format de dades",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Cercle",
    "clear": "esborrar",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Feu clic per a afegir una marca",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone of {name}": "Clona de {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Clona aquest mapa",
    "Clone": "Clona",
    "Close": "Tanca",
    "Clustered": "Clustered",
    "Clustering radius": "Clustering radius",
    "collapsed": "collapsed",
    "color": "color",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Llista separada per comes de les propietats a usar per a les característiques d'ordenació. Per a invertir l'ordre, afegiu un signe menys (-) abans. P. ex. lamevaclau, -unaslatraclau",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Enhorabona, s'ha creat el mapa!",
    "Continue line": "Continue line",
    "Coordinates": "Coordenades",
    "copy": "copiar",
    "Credits": "Crèdits",
    "Current map view": "Visualització del mapa actual",
    "Current view instead of default map view?": "Voleu la visualització actual en comptes de la visualització predeterminada?",
    "Custom background": "Fons personalitzat",
    "Custom overlay": "Superposició personalitzada",
    "dash array": "matriu de guions",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Capes de dades",
    "Default interaction options": "Opcions d'interacció predeterminades",
    "Default properties": "Propietats predeterminades",
    "Default shape properties": "Propietats de forma per defecte",
    "Default view": "Vista per defecte",
    "Default zoom level": "Nivell de l'escala per defecte",
    "Default": "Per defecte",
    "Default: name": "Per defecte: name",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Retard entre transicions en mode de reproducció",
    "Delete layer": "Suprimeix la capa",
    "Delete this feature": "Suprimeix aquesta característica",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "Suprimeix",
    "description": "descripció",
    "Direct link": "Enllaç directe",
    "Directions from here": "Direccions des d'aquí",
    "Display label": "Mostra l'etiqueta",
    "Display measure": "Display measure",
    "display name": "mostra el nom",
    "Display on load": "Mostrar en carregar",
    "Display the control to open OpenStreetMap editor": "Mostra el botó per obrir l'editor d'OpenStreetMap",
    "Display the embed control": "Mostra el control d'inserció",
    "Display the fullscreen control": "Mostrar el control de la pantalla completa",
    "Display the locate control": "Mostra el control de ubicar",
    "Display the measure control": "Mostra el botó mesura",
    "Display the search control": "Mostra el control de cerca",
    "Display the tile layers control": "Mostra el botó de les capes de tessel·les",
    "Display the zoom control": "Mostra el control del zoom",
    "Do you want to display a caption bar?": "Voleu mostrar la barra de llegenda?",
    "Do you want to display a minimap?": "Voleu mostrar un minimapa?",
    "Do you want to display a panel on load?": "Voleu mostrar el quandre en carregar?",
    "Do you want to display caption menus?": "Voleu mostrar menús de llegenda?",
    "Do you want to display popup footer?": "Voleu mostrar un peu emergent?",
    "Do you want to display the scale control?": "Voleu mostrar el control d'escala?",
    "Do you want to display the «more» control?": "Voleu mostrar el control \"més\"?",
    "Download": "Baixa",
    "Drag to reorder": "Arrossegar per reordenar",
    "Draw a marker": "Dibuixa un marcador",
    "Draw a polygon": "Dibuixa un polígon",
    "Draw a polyline": "Dibuixa una polilínia",
    "Drawing": "Drawing",
    "Drop": "Deixar",
    "Dynamic properties": "Propietats dinàmiques",
    "Dynamic": "Dinàmic",
    "Edit feature's layer": "Edita la capa de la característica",
    "Edit properties in a table": "Edita les propietats en una taula",
    "Edit the title of the map": "Edita el títol del mapa",
    "Edit this feature": "Edita aquesta característica",
    "Edit": "Edita",
    "Embed and link options": "Opcions d'inserció i enllaç",
    "Embed the map": "Incrusta el mapa",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Buit",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "S'ha produït un error en l'URL de superposició",
    "Error in the tilelayer URL": "Hi ha un error en l'URL de la cap de tessel·les",
    "Exit Fullscreen": "Exit Fullscreen",
    "expanded": "expanded",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Feature identifier key": "Clau identificadora de element",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "emplena el color",
    "fill opacity": "opacitat d'emplenament",
    "fill": "emplena",
    "Fit all data": "Encaixar totes les dades",
    "Format": "Format",
    "From zoom": "Del zoom",
    "full backup": "còpia de seguretat completa",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (només enllaç)",
    "GeoRSS (title + image)": "GeoRSS (títol i imatge)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Vés a la pàgina d'inici",
    "Go to «{feature}»": "Vés a «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Heatmap": "Heatmap",
    "height": "alçada",
    "Help": "Ajuda",
    "hidden": "amagat",
    "Hide controls": "Amaga els controls",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Quant simplificar la polilínia a cada nivell de l'escala (més = millor rendiment i aspecte més suau, menys = més precís)",
    "icon opacity": "opacitat de la icona",
    "Icon shape": "forma de la icona",
    "Icon symbol": "Imatge de la icona",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Importa dades",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Voleu incloure l'enllaç a pantalla completa?",
    "Inherit": "Hereta",
    "inherit": "heretat",
    "Interaction options": "Interaction options",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Invalid umap data": "Invalid umap data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Mantenir les capes visibles actuals",
    "kilometers": "quilòmetres",
    "km": "km",
    "Label direction": "Direcció de l'etiqueta",
    "Label key": "Clau d'etiqueta",
    "Labels are clickable": "Les etiquetes es poden fer clic",
    "Latest feature": "Darrera característica",
    "Latitude": "Latitud",
    "Layer properties": "Layer properties",
    "Layer": "Capa",
    "Licence": "Llicència",
    "licence": "llicència",
    "Limit bounds": "Límits",
    "Link to view the map": "Enllaç per veure el mapa",
    "Link to…": "Link to…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Crèdits llargs",
    "Longitude": "Longitud",
    "Make main shape": "Make main shape",
    "Manage layers": "Gestiona les capes",
    "Manual": "Manual",
    "Map background credits": "Crèdits del fons del mapa",
    "Map has been attached to your account": "El mapa s'ha adjuntat al vostre compte",
    "Map has been saved!": "S'ha desat el mapa!",
    "Map has been starred": "El mapa s'ha destacat",
    "Map has been unstarred": "El mapa ja no està destacat",
    "Map user content has been published under licence": "El contingut de l'usuari del mapa s'ha publicat sota la llicència",
    "Map's editors": "Editors del mapa",
    "Map's owner": "Propietari del mapa",
    "max East": "Est màxim",
    "max North": "Nord màxim",
    "max South": "Sud màxim",
    "max West": "Oest màxim",
    "max zoom": "escala màxima",
    "Measure distances": "Mesura distàncies",
    "Merge lines": "Merge lines",
    "mi": "mi",
    "miles": "milles",
    "min zoom": "escala mínima",
    "More controls": "Més controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Ha de ser un valor CSS vàlid (p. ex.: DarkBlue o #123456)",
    "name": "nom",
    "nautical miles": "miles nàutiques",
    "never": "mai",
    "new window": "new window",
    "next": "next",
    "NM": "NM",
    "No cache": "Sense memòria cau",
    "No licence has been set": "No s'ha establert cap llicència",
    "No results": "No results",
    "no": "no",
    "No.": "No.",
    "None": "Cap",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "A la part inferior",
    "On the left": "A l'esquerra",
    "On the right": "A la dreta",
    "On the top": "a la part superior",
    "Only visible layers' data": "Només les dades de les capes visibles",
    "opacity": "opacitat",
    "Opacity": "Opacitat",
    "Open current feature on load": "Obrir el element actual en càrregar",
    "Open link in…": "Obriu l'enllaç a…",
    "Open share & download panel": "Obrir el panell Comparteix i baixa",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Opcional. El mateix color si no s'estableix.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "parent window",
    "Paste your data here": "Enganxeu les dades aquí",
    "Permalink": "Permalink",
    "Permanent credits background": "Mostra un fons per al crèdit permanent",
    "Permanent credits": "Crèdits permanents",
    "Please be sure the licence is compliant with your use.": "Assegureu-vos que la llicència és compatible amb l'ús que en feu.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Introduïu el nom de la propietat",
    "Please enter the new name of this property": "Introduïu el nom d'aquesta propietat",
    "Please save the map first": "Abans deseu el mapa",
    "Popup (large)": "Finestra emergent (gran)",
    "Popup content style": "Estil del contingut de la finestra emergent",
    "Popup content template": "Plantilla de contingut de la finestra emergent",
    "Popup shape": "Forma de la finestra emergent",
    "Popup": "Finestra emergent",
    "Powered by uMap": "Desenvolupat per uMap",
    "previous": "previous",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Propietats importades:",
    "Provide an URL here": "Proporcioneu un URL aquí",
    "Proxy request": "Petició proxy",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Dades remotes",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save current edits": "Desa les edicions actuals",
    "Save map": "Deseu el mapa",
    "Save": "Desa",
    "Saved center and zoom": "Centre i escala desats",
    "Search location": "Cercar ubicacion",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Mostra-ho a pantalla completa",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Shape properties",
    "Share and download": "Comparteix i baixa",
    "Share this link to open a customized map view": "Comparteix aquest enllaç per obrir una vista de mapa personalitzada",
    "Short credits": "Crèdits curts",
    "Short link": "Enllaç curt",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Mostra/amaga la capa",
    "Side panel": "panell lateral",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "S'està ometent el tipus de geometria desconegut: {type}",
    "Slideshow": "Presentació",
    "Sort key": "Clau d'ordenació",
    "Split line": "Split line",
    "Star this map": "Destaca aquest mapa",
    "Start a hole here": "Start a hole here",
    "Start slideshow": "Inicia la presentació",
    "Stop editing": "Atura l'edició",
    "Stop slideshow": "Atura la presentació",
    "Street": "Street",
    "stroke": "stroke",
    "Supported scheme": "Esquema suportat",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol": "Symbol",
    "Table": "Taula",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Format del text",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "El nom de la propietat que s'utilitzarà com a etiqueta de característica (p. ex.: \"nom\"). També podeu utilitzar propietats entre claudàtors per utilitzar-ne més d'una o barrejar-les amb contingut estàtic (p. ex.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "El nom de la propietat que s'utilitzarà com a identificador únic de la característica",
    "The zoom and center have been modified.": "L'escala i el centre s'han modificat.",
    "TMS format": "Format TMS",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "A l'escala",
    "Toggle edit mode (⇧+Click)": "Activa o desactiva el mode d'edició (⇧+clic)",
    "Toggle edit mode": "Activa o desactiva el mode d'edició",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transforma a línies",
    "Transform to polygon": "Transforma a polígon",
    "Type a place name or coordinates": "Escriviu un nom de lloc o una coordenada",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tipus de capa",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Capa sense títol",
    "Untitled map": "Mapa sense títol",
    "Update permissions and editors": "Actualitza els permisos i editors",
    "Update permissions": "Actualitza els permisos",
    "Update who can see and edit the map": "Defineix qui pot veure i editar el mapa",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Usa els límits actuals",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilitzeu marcadors de posició amb propietats de característiques entre claudàtors, ex. &#123;name&#125;, seran substituïts dinàmicament pels valors corresponents.",
    "User content credits": "Crèdits dels continguts de l'usuari",
    "User interface options": "Opcions de la interfície d'usuari",
    "User location": "Ubicació de l'usuari",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versions",
    "View Fullscreen": "Veure pantalla completa",
    "View": "Vista",
    "Visibility: {status}": "Visibilitat: {status}",
    "weight": "pes",
    "Where do we go from here?": "On anem des d'aquí?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "emplenar polígons amb color..",
    "Who can edit \"{layer}\"": "Qui pot editar \"{layer}\"",
    "Who can edit": "Qui pot editar",
    "Who can view": "Qui pot visualitzar",
    "width": "amplada",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "yes": "sí",
    "Zoom in": "Apropa't",
    "Zoom level for automatic zooms": "Nivell de zoom per a zooms automàtics",
    "Zoom out": "Allunya't",
    "Zoom to layer extent": "Acostament fins que vegeu les dades de la capa",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Fes zoom a aquesta característica",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} milles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edita el nom i la llegenda del mapa",
    "Map advanced properties": "Propietats avançades del mapa",
    "Edit map details": "Edita les propietats del mapa",
    "Back to browser": "Back to browser",
    "Toggle size": "Canvia la mida",
    "Display the caption control": "Mostra el control de la llegenda",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Exemple: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edita a OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filtres",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Claus de cerca",
    "Filters keys": "Claus de filtres",
    "Filter data": "Filter data",
    "Search map features…": "Buscar elements del mapa…",
    "Reset all": "Restablir tot",
    "Open browser": "Obriu el navegador",
    "Open caption": "Obriu la llegenda",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Navegador de dades",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condició",
    "key=value or key!=value": "clau=valor o clau!=valor",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "regla buida",
    "Conditional style rules": "Regles d'estil condicional",
    "Add rule": "Afegeix una regla",
    "Browser: data": "Navegador: dades",
    "Browser: layers": "Navegador: capes",
    "Browser: filters": "Navegador: filtres",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Esborra les dades",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Mostra el botó d'obertura de l'explorador",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Escriviu el nom d'usuari de l'editor",
    "Map": "Mapa",
    "Manage collaborators": "Gestiona els col·laboradors",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("ca", locale)
L.setLocale("ca")
