const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# um cardinal para o cabeçalho principal",
    "## two hashes for second heading": "## dois cardinais para o segundo cabeçalho",
    "### three hashes for third heading": "### três cardinais para o terceiro cabeçalho",
    "**double star for bold**": "**dois asteriscos duplos para negrito**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Lista de números separada por vírgulas que define o padrão do traço. Por exemplo \"5, 10, 15\".",
    "About": "Sobre",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Ativar modo de apresentação",
    "Add a layer": "Adicionar camada",
    "Add a line to the current multi": "Adicionar uma linha para o multi atual",
    "Add a new property": "Adicionar uma nova propriedade",
    "Add a polygon to the current multi": "Adicionar um polígono para o multi atual",
    "Add image URL": "Add image URL",
    "Advanced actions": "Ações avançadas",
    "Advanced properties": "Propriedades avançadas",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Foram importadas todas as propriedades.",
    "Allow interactions": "Permitir interações",
    "Allow scroll wheel zoom?": "Permitir zoom com roda do mause?",
    "always": "sempre",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Tem a certeza que quer clonar este mapa, incluindo todas as camadas de dados?",
    "Are you sure you want to delete this map?": "Tem a certeza que quer eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "Tem a certeza que quer eliminar esta propriedade em todos os elementos?",
    "Are you sure you want to restore this version?": "Tem a certeza que quer restaurar esta versão?",
    "Attach the map to my account": "Anexar o mapa à minha conta",
    "attribution": "atribuição",
    "Auto": "Auto",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Iniciar ao abrir o mapa",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Bola",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Explorar dados",
    "by": "por",
    "Cache proxied request": "Pedido cache com proxy",
    "Caption": "Cabeçalho",
    "Center map on your location": "Centrar mapa na sua localização",
    "Change map background": "Mudar fundo do mapa",
    "Change tilelayers": "Alterar camadas de telas",
    "Change": "Change",
    "Choose the data format": "Escolha o formato dos dados",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Círculo",
    "clear": "limpar",
    "Click last point to finish shape": "Clique no último ponto para terminar a forma geométrica",
    "Click to add a marker": "Clique para adicionar um marcador",
    "Click to continue drawing": "Clique para continuar a desenhar",
    "Click to edit": "Clique para editar",
    "Click to start drawing a line": "Clique para começar a desenhar uma linha",
    "Click to start drawing a polygon": "Clique para começar a desenhar um polígono",
    "Clone of {name}": "Clone de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Fechar",
    "Clustered": "Agregado",
    "Clustering radius": "Raio do aglomerado",
    "collapsed": "colapsado",
    "color": "cor",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por vírgula, tabulação ou ponto-e-vírgula. É implícito o sistema de referência espacial WGS84. Apenas são importadas as geometrias de ponto. A importação irá ver se aparece no cabeçalho das colunas «lat» e «lon», ignorando diferença de maiúsculas e minúsculas. Todas a outras colunas são importadas como propriedades.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Continuar linha",
    "Coordinates": "Coordenadas",
    "copy": "copy",
    "Credits": "Créditos",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Vista atual e não a vista padrão do mapa?",
    "Custom background": "Fundo personalizado",
    "Custom overlay": "Custom overlay",
    "dash array": "série de traços",
    "Data is browsable": "Os dados são navegáveis",
    "Datalayers": "Datalayers",
    "Default interaction options": "Opções padrão de interação",
    "Default properties": "Propriedades padrão",
    "Default shape properties": "Propriedades padrão de formas geométricas",
    "Default view": "Default view",
    "Default zoom level": "Nível de aproximação padrão",
    "Default": "Padrão",
    "Default: name": "Padrão: nome",
    "Define link to open in a new window on polygon click.": "Definir link para abrir numa nova janela ao clicar no polígono.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Atraso entre 2 transições ao reproduzir a apresentação",
    "Delete layer": "Eliminar camada",
    "Delete this feature": "Eliminar este elemento",
    "Delete this shape": "Eliminar esta forma geométrica",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Clique)",
    "Delete": "Eliminar",
    "description": "descrição",
    "Direct link": "Direct link",
    "Directions from here": "Direções a partir daqui",
    "Display label": "Mostrar etiqueta",
    "Display measure": "Mostrar medição",
    "display name": "mostrar nome",
    "Display on load": "Mostrar ao carregar",
    "Display the control to open OpenStreetMap editor": "Mostrar o controle para abrir o editor OpenStreetMap",
    "Display the embed control": "Mostrar o controle de embeber",
    "Display the fullscreen control": "Mostrar o controle de ecrã total",
    "Display the locate control": "Mostrar o controle de localizar",
    "Display the measure control": "Mostrar o controle de medição",
    "Display the search control": "Mostrar o controle de procura",
    "Display the tile layers control": "Mostrar o controle de camadas de telas",
    "Display the zoom control": "Mostrar o controle de aproximar e afastar (zoom)",
    "Do you want to display a caption bar?": "Mostrar uma barra de cabeçalho?",
    "Do you want to display a minimap?": "Pretende mostrar um mini-mapa?",
    "Do you want to display a panel on load?": "Mostrar um painel ao carregar?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Pretende mostrar um popup no rodapé?",
    "Do you want to display the scale control?": "Pretende mostrar o controle de escala?",
    "Do you want to display the «more» control?": "Mostrar o botão «mostrar mais botões»?",
    "Download": "Descarregar",
    "Drag to reorder": "Arrastar para reordenar",
    "Draw a marker": "Desenhar um marco",
    "Draw a polygon": "Desenhar um polígono",
    "Draw a polyline": "Desenhar uma polilinha",
    "Drawing": "Drawing",
    "Drop": "Comum",
    "Dynamic properties": "Propriedades dinâmicas",
    "Dynamic": "Dinâmico",
    "Edit feature's layer": "Editar camada do elemento",
    "Edit properties in a table": "Editar propriedades numa tabela",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Embeber o mapa",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Vazio",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Erro no URL de telas",
    "Exit Fullscreen": "Sair de Ecrã Total",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extrair forma geométrica para separar o elemento",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Processar dados cada vez que o mapa é alterado.",
    "fill color": "cor do preenchimento",
    "fill opacity": "opacidade do preenchimento",
    "fill": "preenchimento",
    "Fit all data": "Fit all data",
    "Format": "Formato",
    "From zoom": "Do zoom",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (apenas o link)",
    "GeoRSS (title + image)": "GeoRSS (título + imagem)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propriedade da intensidade do mapa térmico",
    "Heatmap radius": "Raio do mapa térmico",
    "Heatmap": "Mapa térmico",
    "height": "altura",
    "Help": "Ajuda",
    "hidden": "oculto",
    "Hide controls": "Ocultar controles",
    "Home": "Início",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Por quanto simplificar a polilinha em cada nível de aproximação (mais = melhor desempenho e aspeto mais suave, menos = mais preciso)",
    "icon opacity": "icon opacity",
    "Icon shape": "Forma do ícone",
    "Icon symbol": "Símbolo do ícone",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Importar dados",
    "Import in a new layer": "Importar uma nova camada",
    "Imports all umap data, including layers and settings.": "Importa todos os dados uMap, incluindo camadas e definições.",
    "Include full screen link?": "Incluir link de encrã total?",
    "Inherit": "Herdado",
    "inherit": "herdado",
    "Interaction options": "Opções de interação",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Dados uMap inválidos em {filename}",
    "Invalid umap data": "Dados uMap inválidos",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Manter camadas atualmente visíveis",
    "kilometers": "quilómetros",
    "km": "km",
    "Label direction": "Direção da etiqueta",
    "Label key": "Chave da etiqueta",
    "Labels are clickable": "Etiquetas são clicáveis",
    "Latest feature": "Latest feature",
    "Latitude": "Latitude",
    "Layer properties": "Propriedades da camada",
    "Layer": "Camada",
    "Licence": "Licença",
    "licence": "licença",
    "Limit bounds": "Extremos dos limites",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link para...",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Créditos por extenso",
    "Longitude": "Longitude",
    "Make main shape": "Fazer forma geométrica principal",
    "Manage layers": "Gerir camadas",
    "Manual": "Manual",
    "Map background credits": "Créditos do fundo do mapa",
    "Map has been attached to your account": "O mapa foi anexado à sua conta",
    "Map has been saved!": "O mapa foi gravado!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "O conteúdo do mapa foi publicado sob a licença",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Proprietário do mapa",
    "max East": "Este máx.",
    "max North": "Norte máx.",
    "max South": "Sul máx.",
    "max West": "Oeste máx.",
    "max zoom": "aproximação máxima",
    "Measure distances": "Medir distâncias",
    "Merge lines": "Fundir linhas",
    "mi": "mi",
    "miles": "milhas",
    "min zoom": "aproximação mínima",
    "More controls": "Mais controles",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Tem de ser um valor CSS válido (p.ex.: DarkBlue ou #123456)",
    "name": "nome",
    "nautical miles": "milhas náuticas",
    "never": "nunca",
    "new window": "nova janela",
    "next": "seguinte",
    "NM": "NM",
    "No cache": "Sem cache",
    "No licence has been set": "Não foi definida nenhuma licença",
    "No results": "Sem resultados",
    "no": "não",
    "No.": "No.",
    "None": "Nenhum",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "No fundo",
    "On the left": "Na esquerda",
    "On the right": "Na direita",
    "On the top": "No topo",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "opacidade",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Abrir link numa...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abrir esta região do mapa num editor de mapas para fornecer dados mais precisos ao OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propriedade opcional da intensidade do mapa térmico",
    "Optional. Same as color if not set.": "Opcional. Igual à cor se não for definido.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrepor raio do aglomerado (padrão 80)",
    "Override heatmap radius (default 25)": "Sobrepor raio do mapa térmico (padrão 80)",
    "parent window": "janela pai",
    "Paste your data here": "Cole seus dados aqui",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Por favor tenha a certeza que a utilização está conforme a licença.",
    "Please choose a format": "Por favor escolha um formato",
    "Please enter the name of the property": "Por favor introduza o nome da propriedade",
    "Please enter the new name of this property": "Por favor introduza um novo nome desta propriedade",
    "Please save the map first": "Por favor, primeiro salve o mapa",
    "Popup (large)": "Popup (largo)",
    "Popup content style": "Estilo do conteúdo do popup",
    "Popup content template": "Modelo de conteúdo do popup",
    "Popup shape": "Forma do popup",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "anterior",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Propriedades importadas:",
    "Provide an URL here": "Forneça um URL aqui",
    "Proxy request": "Pedido proxy",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Dados remotos",
    "Remove shape from the multi": "Remover forma do multi",
    "Replace layer content": "Substituir o conteúdo da camada",
    "Restore this version": "Restaurar esta versão",
    "Save current edits": "Gravar edições atuais",
    "Save map": "Save map",
    "Save": "Gravar",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Procurar localização",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Ver em ecrã total",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Defina como falso para ocultar esta camada da apresentação de slides, o navegador de dados e da navegação do popup…",
    "settings": "settings",
    "Shape properties": "Propriedades de formas geométricas",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Créditos resumidos",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Mostrar/ocultar camada",
    "Side panel": "Painel lateral",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "Ignorando geometry.type desconhecido: {type}",
    "Slideshow": "Apresentação",
    "Sort key": "Chave de ordenação",
    "Split line": "Linha de separação",
    "Star this map": "Star this map",
    "Start a hole here": "Começar um buraco aqui",
    "Start slideshow": "Iniciar apresentação",
    "Stop editing": "Parar edição",
    "Stop slideshow": "Parar apresentação",
    "Street": "Street",
    "stroke": "traço",
    "Supported scheme": "Esquema suportado",
    "Supported variables that will be dynamically replaced": "Variáveis suportadas que serão substituídas de forma dinâmica",
    "Symbol": "Symbol",
    "Table": "Tabela",
    "Text color for the cluster label": "Cor do texto para a etiqueta do aglomerado",
    "Text formatting": "Formatação do texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "Formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Para usar caso o servidor remoto não permitir domínios cruzados (mais lento)",
    "To zoom": "Ao zoom",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transferir a forma geométrica para o elemento editado",
    "Transform to lines": "Transformar em linha",
    "Transform to polygon": "Transformar em polígono",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tipo de camada",
    "Unable to detect format of file {filename}": "Não foi possível detetar o formato do ficheiro {filename}",
    "Untitled layer": "Camada sem nome",
    "Untitled map": "Mapa sem nome",
    "Update permissions and editors": "Alterar permisões e editores",
    "Update permissions": "Permissões de atualização",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Usar extremos atuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use espaços reservados como propriedades de elementos entre parêntesis. Por ex. &#123;nome&#125; e serão substituídos pelos valores correspondentes.",
    "User content credits": "Créditos do conteúdo do usuário",
    "User interface options": "Opções da interface de usuário",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versões",
    "View Fullscreen": "Ver em Ecrã Total",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "espessura",
    "Where do we go from here?": "Para onde vamos a partir daqui?",
    "Whether to display or not polygons paths.": "Se mostrar ou não os caminhos dos polígonos.",
    "Whether to fill polygons with color.": "Se mostrar ou não os polígonos preenchidos a cor.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Quem pode editar",
    "Who can view": "Quem pode ver",
    "width": "largura",
    "Will be displayed in the bottom right corner of the map": "Será mostrado no fundo à direita do mapa",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Será visível no cabeçalho do mapa",
    "yes": "sim",
    "Zoom in": "Aproximar",
    "Zoom level for automatic zooms": "Nível de aproximação para aproximações automáticas",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Aproximar ao tamanho da camada",
    "Zoom to the next": "Aproximar para o seguinte",
    "Zoom to the previous": "Aproximar para o anterior",
    "Zoom to this feature": "Aproximar a este elemento",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} erros ao importar: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("pt_BR", locale)
L.setLocale("pt_BR")
