{% extends "40x.html" %}

{% load i18n static %}

{% block content %}
  <div class="content-40x content-404">
    <h1>{% trans "404 Page Not Found" %}</h1>
    <p><a href="{% url 'home' %}">{% trans "← Go to the homepage" %}</a></p>
  </div>
{% endblock content %}
