const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# סולמית אחת לכותרת ראשית",
    "## two hashes for second heading": "## שתי סולמיות לכותרת מסדר שני",
    "### three hashes for third heading": "### שלוש סולמיות לכותרת מסדר שלישי",
    "**double star for bold**": "**כוכבית כפולה להדגשה**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "יום",
    "1 hour": "שעה",
    "5 min": "5 דקות",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "רשימה מופרדת בפסיקים של מספרים שמגדירים את תבנית הלוכסנים והמקפים. למשל: „5, 10, 15”.",
    "About": "על אודות",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "הפעלת מצב מצגת",
    "Add a layer": "הוספת שכבה",
    "Add a line to the current multi": "הוספת קו לרב המצולעים הנוכחי",
    "Add a new property": "הוספת מאפיין חדש",
    "Add a polygon to the current multi": "הוספת מצולע לרב המצולעים הנוכחי",
    "Add image URL": "Add image URL",
    "Advanced actions": "פעולות מתקדמות",
    "Advanced properties": "מאפיינים מתקדמים",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "כל המאפיינים ייובאו.",
    "Allow interactions": "לאפשר אינטראקציות",
    "Allow scroll wheel zoom?": "לאפשר תקריב עם גלגלת העכבר?",
    "always": "תמיד",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "לשכפל את המפה הזאת ואת כל שכבות הנתונים שלה?",
    "Are you sure you want to delete this map?": "למחוק את המפה הזו?",
    "Are you sure you want to delete this property on all the features?": "למחוק את המאפיין הזה מכל התכונות?",
    "Are you sure you want to restore this version?": "לשחזר את הגרסה הזו?",
    "Attach the map to my account": "הצמדת מפה לחשבון שלי",
    "attribution": "ייחוס",
    "Auto": "אוטומטית",
    "Automatic": "אוטומטי",
    "Autostart when map is loaded": "להתחיל אוטומטית עם טעינת המפה",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "כדור",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "עיון בנתונים",
    "by": "מאת",
    "Cache proxied request": "שמירת בקשות שעברו דרך המתווך במטמון",
    "Caption": "כותרת",
    "Center map on your location": "מרכוז המפה על המיקום שלך",
    "Change map background": "החלפת רקע המפה",
    "Change tilelayers": "החלפת שכבות אריחים",
    "Change": "Change",
    "Choose the data format": "נא לבחור את מבנה הנתונים",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "עיגול",
    "clear": "למחוק",
    "Click last point to finish shape": "יש ללחוץ על הנקודה האחרונה כדי לסיים את הצורה",
    "Click to add a marker": "יש ללחוץ כדי להוסיף סמן",
    "Click to continue drawing": "יש ללחוץ כדי להמשיך בציור",
    "Click to edit": "יש ללחוץ כדי לערוך",
    "Click to start drawing a line": "יש ללחוץ כדי להתחיל לצייר קו",
    "Click to start drawing a polygon": "יש ללחוץ כדי להתחיל לצייר מצולע",
    "Clone of {name}": "שכפול של {name}",
    "Clone this feature": "שכפול התכונה הזו",
    "Clone this map": "שכפול המפה הזו",
    "Clone": "שכפול",
    "Close": "סגירה",
    "Clustered": "בקבוצה",
    "Clustering radius": "רדיוס קיבוץ",
    "collapsed": "מצומצם",
    "color": "צבע",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "ערכים מופרדים בפסיקים, טאבים או נקודה פסיק. עם רמיזה ל־SRS WGS84. רק גואמטריית נקודות מייובאת. הייבוא יסתכל על כותרות העמודות לאיתור אזכורים של „lat” (קו רוחב) ו־„lon” (קו אורך) בתחילת הכותרת, לא משנה אותיות קטנות/גדולות. כל שאר העמודות ייובאו כמאפיינים.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "להמשיך את הקו",
    "Coordinates": "נקודות ציון",
    "copy": "copy",
    "Credits": "תודות",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "התצוגה הנוכחית במקום תצוגת בררת המחדל של המפה?",
    "Custom background": "רקע בהתאמה אישית",
    "Custom overlay": "Custom overlay",
    "dash array": "סדרה של מקפים",
    "Data is browsable": "הנתונים זמינים לעיון",
    "Datalayers": "Datalayers",
    "Default interaction options": "אפשרויות אינטראקציה כבררת מחדל",
    "Default properties": "מאפיינים כבררת מחדל",
    "Default shape properties": "מאפייני צורה כבררת מחדל",
    "Default view": "Default view",
    "Default zoom level": "רמת תקריב כבררת מחדל",
    "Default": "בררת מחדל",
    "Default: name": "בררת מחדל: שם",
    "Define link to open in a new window on polygon click.": "יש להגדיר קישור לפתיחה בחלון חדש עם לחיצה על מצולע.",
    "define": "הגדרה",
    "Delay between two transitions when in play mode": "השהיה בין שתי העברות כשמדובר במצב משחק",
    "Delete layer": "מחיקת שכבה",
    "Delete this feature": "מחיקת התכונה הזו",
    "Delete this shape": "מחיקת הצורה הזו",
    "Delete this vertex (Alt+Click)": "מחיקת הקודקוד הזה ‪(Alt+לחיצה)",
    "Delete": "מחיקה",
    "description": "תיאור",
    "Direct link": "Direct link",
    "Directions from here": "הכוונה מכאן",
    "Display label": "הצגת תווית",
    "Display measure": "הצגת מדידה",
    "display name": "שם תצוגה",
    "Display on load": "הצגה עם הטעינה",
    "Display the control to open OpenStreetMap editor": "יש להציג את הפקד לפתיחת העורך של OpenStreetMap",
    "Display the embed control": "הצגת פקד ההטמעה",
    "Display the fullscreen control": "הצגת פקד מסך מלא",
    "Display the locate control": "הצגת פקד האיתור",
    "Display the measure control": "הצגת פקד המדידה",
    "Display the search control": "הצגת פקד החיפוש",
    "Display the tile layers control": "הצגת פקד שכבת האריחים",
    "Display the zoom control": "הצגת פקד התקריב",
    "Do you want to display a caption bar?": "להציג פס כותרת?",
    "Do you want to display a minimap?": "להציג מפה ממוזערת?",
    "Do you want to display a panel on load?": "להציג לוח צד בטעינה?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "להציג כותרת תחתונה קופצת?",
    "Do you want to display the scale control?": "להציג את פקד קנה המידה?",
    "Do you want to display the «more» control?": "להציג את הפקד „עוד”?",
    "Download": "הורדה",
    "Drag to reorder": "יש לגרור כדי לסדר מחדש",
    "Draw a marker": "ציור סמן",
    "Draw a polygon": "ציור מצולע",
    "Draw a polyline": "ציור קו שבור",
    "Drawing": "Drawing",
    "Drop": "נעץ",
    "Dynamic properties": "מאפיינים דינמיים",
    "Dynamic": "דינמי",
    "Edit feature's layer": "עריכת שכבת התכונה",
    "Edit properties in a table": "עריכת מאפיינים בטבלה",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "עריכת תכונה זו",
    "Edit": "עריכה",
    "Embed and link options": "Embed and link options",
    "Embed the map": "הטמעת המפה",
    "Emoji & Character": "Emoji & Character",
    "Empty": "לרוקן",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "שגיאה בכתובת שכבת האריחים",
    "Exit Fullscreen": "יציאה ממסך מלא",
    "expanded": "מורחב",
    "Extract shape to separate feature": "יש לחלץ צורה כדי להפריד תכונה",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "לקבל נתונים בכל פעם שתצוגת המפה משתנה.",
    "fill color": "צבע מילוי",
    "fill opacity": "אטימות מילוי",
    "fill": "מילוי",
    "Fit all data": "Fit all data",
    "Format": "תצורה",
    "From zoom": "מרמת תקריב",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (קישור בלבד)",
    "GeoRSS (title + image)": "GeoRSS (כותרת + תמונה)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "מעבר אל «{feature}»",
    "Heatmap intensity property": "מאפיין עצמת מפת חום",
    "Heatmap radius": "רדיוס מפת חום",
    "Heatmap": "מפת חום",
    "height": "גובה",
    "Help": "עזרה",
    "hidden": "מוסתר",
    "Hide controls": "הסתרת פקדים",
    "Home": "בית",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "כמה לפשט את הקו השבור בכל רמת תקריב (יותר = ביצועים משופרים ומראה חלק יותר, פחות = דיוק גבוה יותר)",
    "icon opacity": "icon opacity",
    "Icon shape": "צורת סמל",
    "Icon symbol": "סמן סמל",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "מסגרת פנימית",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "ייבוא נתונים",
    "Import in a new layer": "ייבוא לשכבה חדשה",
    "Imports all umap data, including layers and settings.": "יבוצע ייבוא של כל הנתונים של umap לרבות שכבות והגדרות.",
    "Include full screen link?": "לכלול קישור למסך מלא?",
    "Inherit": "ירושה",
    "inherit": "ירושה",
    "Interaction options": "אפשרויות אינטראקציה",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "נתוני umap שגויים בתוך {filename}",
    "Invalid umap data": "נתוני umap שגויים",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "להשאיר את השכבות שגלויות כרגע",
    "kilometers": "קילומטרים",
    "km": "ק״מ",
    "Label direction": "כיוון התווית",
    "Label key": "מפתח תווית",
    "Labels are clickable": "התוויות זמינות ללחיצה",
    "Latest feature": "Latest feature",
    "Latitude": "קו רוחב",
    "Layer properties": "מאפייני שכבה",
    "Layer": "שכבה",
    "Licence": "רישיון",
    "licence": "רישיון",
    "Limit bounds": "גבולות חוסמים",
    "Link to view the map": "Link to view the map",
    "Link to…": "קישור אל…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "תודות ארוכות",
    "Longitude": "קו אורך",
    "Make main shape": "להפוך לצורה עיקרית",
    "Manage layers": "ניהול שכבות",
    "Manual": "Manual",
    "Map background credits": "תודות על רקע המפה",
    "Map has been attached to your account": "המפה הוצמדה לחשבון שלך",
    "Map has been saved!": "המפה נשמרה!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "תוכן המשתמש של המפה פורסם תחת רישיון",
    "Map's editors": "עורכי המפה",
    "Map's owner": "בעלי המפה",
    "max East": "מזרח מרבי",
    "max North": "צפון מרבי",
    "max South": "דרום מרבי",
    "max West": "מערב מרבי",
    "max zoom": "תקריב מרבי",
    "Measure distances": "מדידת מרחקים",
    "Merge lines": "מיזוג קווים",
    "mi": "מייל",
    "miles": "מיילים",
    "min zoom": "תקריב מזערי",
    "More controls": "פקדים נוספים",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "חייב להיות ערך CSS תקני (למשל: DarkBlue או #123456)",
    "name": "שם",
    "nautical miles": "מיילים ימיים",
    "never": "מעולם לא",
    "new window": "חלון חדש",
    "next": "הבא",
    "NM": "מיילים ימיים",
    "No cache": "אין מטמון",
    "No licence has been set": "לא הוגדר רישיון",
    "No results": "אין תוצאות",
    "no": "לא",
    "No.": "No.",
    "None": "ללא",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "בתחתית",
    "On the left": "משמאל",
    "On the right": "מימין",
    "On the top": "מלמעלה",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "אטימות",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "פתיחת קישור עם…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "פתיחת היקף מפה זו בעורך מפות כדי לספק נתונים מדויקים יותר ל־OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "מאפיין עצמה כרשות למפת חום",
    "Optional. Same as color if not set.": "רשות. כנ״ל לגבי צבע אם לא הוגדר.",
    "Optional.": "רשות.",
    "Override clustering radius (default 80)": "דריסת רדיוס הקבוצה (בררת המחדל היא 80)",
    "Override heatmap radius (default 25)": "דריסת רדיוס מפת החום (בררת המחדל היא 25)",
    "parent window": "חלון הורה",
    "Paste your data here": "נא להדביק את הנתונים שלך כאן",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "נא לוודא שהרישיון תואם לשימוש שלך.",
    "Please choose a format": "נא לבחור תבנית",
    "Please enter the name of the property": "נא למלא את שם המאפיין",
    "Please enter the new name of this property": "נא למלא את השם החדש של המאפיין הזה",
    "Please save the map first": "נא לשמור את המפה קודם",
    "Popup (large)": "חלונית מוקפצת (גדולה)",
    "Popup content style": "סגנון תוכן חלונית מוקפצת",
    "Popup content template": "תבנית תוכן מוקפצת",
    "Popup shape": "צורת חלונית מוקפצת",
    "Popup": "חלונית מוקפצת",
    "Powered by uMap": "Powered by uMap",
    "previous": "הקודם",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "יובאו מאפיינים:",
    "Provide an URL here": "נא לספק כאן כתובת",
    "Proxy request": "בקשת מתווך",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "נתונים מרוחקים",
    "Remove shape from the multi": "הסרת צורת מרב מצולעים",
    "Replace layer content": "החלפת תוכן השכבה",
    "Restore this version": "שחזור הגרסה הזו",
    "Save current edits": "לשמור את העריכות הנוכחיות",
    "Save map": "Save map",
    "Save": "לשמור",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "חיפוש מיקום",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "הצגת מסך מלא",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "יש להגדיר לשקר כדי להסתיר את השכבה הזאת מהמצגת, דפדפן הנתונים, הניווט המוקפץ…",
    "settings": "settings",
    "Shape properties": "מאפייני צורה",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "תודות מקוצרות",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "הצגת/הסתרת שכבה",
    "Side panel": "לוח צד",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "פישוט",
    "Skipping unknown geometry.type: {type}": "יתבצע דילוג על geometry.type לא ידוע: {type}",
    "Slideshow": "מצגת",
    "Sort key": "מפתח סידור",
    "Split line": "פיצול קו",
    "Star this map": "Star this map",
    "Start a hole here": "להתחיל חור מכאן",
    "Start slideshow": "התחלת מצגת",
    "Stop editing": "הפסקת עריכה",
    "Stop slideshow": "הפסקת מצגת",
    "Street": "Street",
    "stroke": "לוכסן",
    "Supported scheme": "סכמה נתמכת",
    "Supported variables that will be dynamically replaced": "משתנים נתמכים שיוחלפו באופן דינמי",
    "Symbol": "Symbol",
    "Table": "טבלה",
    "Text color for the cluster label": "צבע טקסט לתווית הקבוצה",
    "Text formatting": "עיצוב טקסט",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "מבנה TMS",
    "To use if remote server doesn't allow cross domain (slower)": "יש להשתמש אם השרת המרוחק לא מאפשר קישור בין שמות תחומים (Cross Origin - אטי יותר)",
    "To zoom": "לתקריב",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "המרת צורה לתכונה לעריכה",
    "Transform to lines": "המרה לקווים",
    "Transform to polygon": "המרה למצולע",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "סוג שכבה",
    "Unable to detect format of file {filename}": "לא ניתן לזהות את מבנה הקובץ {filename}",
    "Untitled layer": "שכבה ללא שם",
    "Untitled map": "מפה ללא שם",
    "Update permissions and editors": "עדכון הרשאות ועורכים",
    "Update permissions": "עדכון הרשאות",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "כתובת",
    "URL": "URL",
    "Use current bounds": "להשתמש בגבולות הנוכחיים",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "ניתן להשתמש בממלאי מקום למאפייני תכונות בתוך סוגריים, למשל: &#123;name&#125;, הם יוחלפו דינמית בערכים המתאימים.",
    "User content credits": "תודות על תוכן המשתמש",
    "User interface options": "אפשרויות מנשק משתמש",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "גרסאות",
    "View Fullscreen": "הצגה במסך מלא",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "משקל",
    "Where do we go from here?": "לאן מתקדמים מכאן?",
    "Whether to display or not polygons paths.": "האם להציג נתיבי מצולעים או לא.",
    "Whether to fill polygons with color.": "האם למלא מצולעים בצבע.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "למי יש אפשרות לערוך",
    "Who can view": "למי יש אפשרות לצפות",
    "width": "רוחב",
    "Will be displayed in the bottom right corner of the map": "יוצג בפינה הימנית התחתונה של המפה",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "יופיע בכותרת המפה",
    "yes": "כן",
    "Zoom in": "התקרבות",
    "Zoom level for automatic zooms": "רמת תקריב לתקריבים אוטומטיים",
    "Zoom out": "התרחקות",
    "Zoom to layer extent": "התמקדות על היקף השכבה",
    "Zoom to the next": "התמקדות על הבא",
    "Zoom to the previous": "התמקדות על הקודם",
    "Zoom to this feature": "התמקדות על תכונה זו",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} שגיאות במהלך הייבוא: {message}",
    "{delay} seconds": "{delay} שניות",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("he", locale)
L.setLocale("he")
