const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# Eine Raute für große Überschrift",
    "## two hashes for second heading": "## Zwei Rauten für mittlere Überschrift",
    "### three hashes for third heading": "### Drei Rauten für kleine Überschrift",
    "**double star for bold**": "**Zwei Sterne für Fett**",
    "*single star for italic*": "*einfache Sternchen für kursiv*",
    "--- for a horizontal rule": "--- für eine horizontale Linie",
    "1 day": "1 Tag",
    "1 hour": "1 Stunde",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Eine kommagetrennte Zahlenfolge, die die Linienart (Strichmuster) der Kontur definiert, z. B.: \"5, 10, 15\".",
    "About": "Über",
    "Action not allowed :(": "Aktion nicht erlaubt :(",
    "Activate slideshow mode": "Diashowmodus aktivieren",
    "Add a layer": "Ebene hinzufügen",
    "Add a line to the current multi": "Linie zur vorhandene Gruppe hinzufügen",
    "Add a new property": "Ein Merkmal hinzufügen",
    "Add a polygon to the current multi": "Fläche zur vorhandene Gruppe hinzufügen",
    "Add image URL": "Bild-URL hinzufügen",
    "Advanced actions": "Erweiterte Aktionen",
    "Advanced properties": "Erweiterte Eigenschaften",
    "All data and settings of the map": "Alle Daten und Karteneinstellungen",
    "All properties are imported.": "Alle Merkmale wurden importiert.",
    "Allow interactions": "Interaktionen erlauben",
    "Allow scroll wheel zoom?": "Zoomen mit dem Mausrad erlauben?",
    "always": "immer",
    "Animated transitions": "Animierte Übergänge",
    "Are you sure you want to clone this map and all its datalayers?": "Möchtest du die Karte und ihre Datenebenen wirklich duplizieren?",
    "Are you sure you want to delete this map?": "Willst du diese Karte wirklich löschen?",
    "Are you sure you want to delete this property on all the features?": "Bist du sicher, dass du dieses Merkmal bei allen Elementen löschen willst?",
    "Are you sure you want to restore this version?": "Bist du sicher, dass du diese Version wiederherstellen willst?",
    "Attach the map to my account": "Die Karte meinem Benutzerkonto zuordnen",
    "attribution": "Copyright-Hinweis",
    "Auto": "Automatisch",
    "Automatic": "Automatisch",
    "Autostart when map is loaded": "Automatischer Start, wenn Karte geladen ist",
    "Back to preview": "Zurück zur Vorschau",
    "Background overlay url": "URL der Hintergrundkarte",
    "Ball": "Stecknadel",
    "Bring feature to center": "Zentriere auf das Element",
    "Browse data": "Daten anzeigen",
    "by": "von",
    "Cache proxied request": "Proxycache-Anfrage",
    "Caption": "Überschrift",
    "Center map on your location": "Die Karte auf deinen Standort ausrichten",
    "Change map background": "Hintergrundkarte ändern",
    "Change tilelayers": "Kachelebenen ändern",
    "Change": "Ändern",
    "Choose the data format": "Wähle das Datenformat",
    "Choropleth breakpoints": "Choroplethen Intervallgrenzen",
    "Choropleth classes": "Choroplethen-Klassen",
    "Choropleth color palette": "Choroplethen-Farbpalette",
    "Choropleth mode": "Choroplethen-Modus",
    "Choropleth property value": "Choroplethen-Eigenschaftswert",
    "Choropleth": "Choroplethen",
    "Circle": "Kreis",
    "clear": "leeren",
    "Click last point to finish shape": "Klicke den letzten Punkt an, um die Form abzuschließen",
    "Click to add a marker": "Klicke, um einen Marker hinzuzufügen",
    "Click to continue drawing": "Klicke, um weiter zu zeichnen",
    "Click to edit": "Zum Bearbeiten klicken",
    "Click to start drawing a line": "Klicke, um eine Linie zu zeichnen",
    "Click to start drawing a polygon": "Klicke, um eine Fläche zu zeichnen",
    "Clone of {name}": "Duplikat von {name}",
    "Clone this feature": "Dieses Element duplizieren",
    "Clone this map": "Dupliziere diese Karte",
    "Clone": "Duplizieren",
    "Close": "Schließen",
    "Clustered": "Gruppiert",
    "Clustering radius": "Gruppierungsradius",
    "collapsed": "eingeklappt",
    "color": "Farbe",
    "Comma separated list of numbers, including min and max values.": "Kommaseparierte Liste an Zahlen, enthält min und max Werte.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Komma-getrennte Liste von Eigenschaften, die für die Sortierung verwendet werden sollen. Um die Sortierung umzukehren, setzen ein Minuszeichen (-) davor, z. B. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma-, Tabulator-, oder Semikolongetrennte Werte. SRS WGS84 ist impliziert. Nur Punktgeometrien werden importiert. Beim Import wird nach Spaltenüberschriften mit jeder Nennung von „lat“ und „lon“ am Anfang der Überschrift gesucht (ohne Beachtung von Groß-/Kleinschreibung). Alle anderen Spalten werden als Merkmale importiert.",
    "Congratulations, your map has been created!": "Glückwunsch, deine Karte wurde erstellt!",
    "Continue line": "Linie fortführen",
    "Coordinates": "Koordinaten",
    "copy": "kopieren",
    "Credits": "Credits",
    "Current map view": "Aktuelle Kartenansicht",
    "Current view instead of default map view?": "Aktuelle Kartenansicht anstatt der Standard-Kartenansicht verwenden?",
    "Custom background": "Benutzerdefinierter Hintergrund",
    "Custom overlay": "Benutzerdefinierter Overlay",
    "dash array": "Linienart",
    "Data is browsable": "Daten sind durchsuchbar",
    "Datalayers": "Datenebenen",
    "Default interaction options": "Standard-Interaktionsoptionen",
    "Default properties": "Standardeigenschaften",
    "Default shape properties": "Standard-Formeigenschaften",
    "Default view": "Standardansicht",
    "Default zoom level": "Standard-Zoomstufe",
    "Default": "Standard",
    "Default: name": "Standard: Name",
    "Define link to open in a new window on polygon click.": "Definiere einen externen Link, der sich beim Klick auf die Fläche in einem neuen Fenster öffnet.",
    "define": "festlegen",
    "Delay between two transitions when in play mode": "Verzögerung zwischen zwei Übergängen im Abspielmodus",
    "Delete layer": "Ebene löschen",
    "Delete this feature": "Dieses Element löschen",
    "Delete this shape": "Diese Form löschen",
    "Delete this vertex (Alt+Click)": "Diesen Eckpunkt löschen (Alt+Klick)",
    "Delete": "Löschen",
    "description": "Beschreibung",
    "Direct link": "Direktlink",
    "Directions from here": "Route von hier",
    "Display label": "Beschriftung anzeigen",
    "Display measure": "Display measure",
    "display name": "Namen anzeigen",
    "Display on load": "Beim Seitenaufruf anzeigen.",
    "Display the control to open OpenStreetMap editor": "Den Button zum OpenStreetMap-Editor anzeigen",
    "Display the embed control": "Eingebettete Steuerung anzeigen",
    "Display the fullscreen control": "Vollbildsteuerung anzeigen",
    "Display the locate control": "Den Ortungsbutton anzeigen.",
    "Display the measure control": "Messsteuerung anzeigen",
    "Display the search control": "Suchsteuerung anzeigen",
    "Display the tile layers control": "Kachelebenensteuerung anzeigen",
    "Display the zoom control": "Zoomsteuerung anzeigen",
    "Do you want to display a caption bar?": "Möchtest du eine Überschrift (Fußzeile) anzeigen?",
    "Do you want to display a minimap?": "Möchtest du eine Übersichtskarte anzeigen?",
    "Do you want to display a panel on load?": "Möchtest du beim Seitenaufruf eine Seitenleiste anzeigen?",
    "Do you want to display caption menus?": "Möchtest du Beschriftungsmenüs anzeigen?",
    "Do you want to display popup footer?": "Möchtest du eine Fußzeile im Popup anzeigen?",
    "Do you want to display the scale control?": "Möchtest du die Maßstabsleiste anzeigen?",
    "Do you want to display the «more» control?": "Möchtest du die „Mehr“-Schaltfläche anzeigen?",
    "Download": "Herunterladen",
    "Drag to reorder": "Ziehen zum Neuanordnen",
    "Draw a marker": "Einen Marker zeichnen",
    "Draw a polygon": "Eine Fläche zeichnen",
    "Draw a polyline": "Eine Linie zeichnen",
    "Drawing": "Zeichnen",
    "Drop": "Tropfen",
    "Dynamic properties": "Dynamische Merkmale",
    "Dynamic": "Dynamisch",
    "Edit feature's layer": "Elementebene bearbeiten",
    "Edit properties in a table": "Merkmale in einer Tabelle bearbeiten",
    "Edit the title of the map": "Die Überschrift der Karte bearbeiten",
    "Edit this feature": "Dieses Element bearbeiten",
    "Edit": "Bearbeiten",
    "Embed and link options": "Optionen zum Einbetten und für eine angepasste Kartenansicht",
    "Embed the map": "Karte einbinden",
    "Emoji & Character": "Emoji & Schriftzeichen",
    "Empty": "Leeren",
    "Equidistant": "Äquidistant",
    "Error in the overlay URL": "Fehler in der Overlay-URL",
    "Error in the tilelayer URL": "Fehler in der Kachelebenen-URL",
    "Exit Fullscreen": "Vollbild beenden",
    "expanded": "ausgeklappt",
    "Extract shape to separate feature": "Form als separates Element extrahieren",
    "Feature identifier key": "Schlüssel zur Identifizierung des Elements",
    "Feature properties": "Eigenschaften des Elements",
    "Fetch data each time map view changes.": "Daten jedes Mal abrufen, wenn sich die Kartenansicht ändert.",
    "fill color": "Farbe der Füllung",
    "fill opacity": "Deckkraft der Füllung",
    "fill": "Füllung",
    "Fit all data": "Alle Daten einpassen",
    "Format": "Format",
    "From zoom": "Von Zoomstufe",
    "full backup": "Komplettes Backup",
    "Generic": "Generisch",
    "GeoRSS (only link)": "GeoRSS (nur Link)",
    "GeoRSS (title + image)": "GeoRSS (Titel + Bild)",
    "Go to \"{coords}\"": "Gehe zu „{coords}“",
    "Go to the homepage": "Zur Startseite gehen",
    "Go to «{feature}»": "Zu „{feature}“ wechseln",
    "Heatmap intensity property": "Heatmap-Intensität",
    "Heatmap radius": "Radius der Heatmap",
    "Heatmap": "Heatmap",
    "height": "Höhe",
    "Help": "Hilfe",
    "hidden": "ausgeblendet",
    "Hide controls": "Schaltflächen ausblenden",
    "Home": "Startseite",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Wie stark Linien mit jeder Zoomstufe vereinfacht werden (mehr = bessere Performance und glatteres Aussehen, weniger = präziser)",
    "icon opacity": "Symbol-Deckkraft",
    "Icon shape": "Bildzeichenform",
    "Icon symbol": "Bildzeichensymbol",
    "If false, the polygon or line will act as a part of the underlying map.": "Wenn auf Nein gesetzt, dann verhält sich die Fläche als Teil der Hintergrundkarte.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe mit benutzerdefinierten Höhe (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe Iframe mit benutzerdefinierten Höhe und Breite (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Bild mit benutzerdefinierter Breite (in Pixel): {{http://bild.url.com|Breite}}",
    "Image: {{https://image.url.com}}": "Bild: {{http://bild.url.com}}",
    "Import data": "Daten importieren",
    "Import in a new layer": "In eine neue Ebene importieren",
    "Imports all umap data, including layers and settings.": "Importiert alle uMap-Daten inklusive Ebenen und Einstellungen",
    "Include full screen link?": "Link für Vollbildanzeige einbeziehen?",
    "Inherit": "erben",
    "inherit": "erben",
    "Interaction options": "Interaktionsoptionen",
    "Invalid latitude or longitude": "Ungültiger Längen- oder Breitengrad",
    "Invalid umap data in {filename}": "Ungültige uMap-Daten in {filename}",
    "Invalid umap data": "Ungütige uMap-Daten",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Aktuell eingeblendete Ebenen übernehmen?",
    "kilometers": "Kilometer",
    "km": "km",
    "Label direction": "Beschriftungsrichtung",
    "Label key": "Anzeigeschlüssel",
    "Labels are clickable": "Beschriftungen sind klickbar",
    "Latest feature": "Neuestes Element",
    "Latitude": "Geogr. Breite",
    "Layer properties": "Ebeneneigenschaften",
    "Layer": "Ebene",
    "Licence": "Lizenz",
    "licence": "Lizenz",
    "Limit bounds": "Kartenverschiebung begrenzen",
    "Link to view the map": "Link zur Kartenansicht",
    "Link to…": "Verlinke zu...",
    "Link with text: [[https://example.com|text of the link]]": "Link mit Text: [[http://beispiel.com|Text für den Link]]",
    "Long credits": "Lange Credits",
    "Longitude": "Geogr. Länge",
    "Make main shape": "Hauptform erstellen",
    "Manage layers": "Ebenen verwalten",
    "Manual": "Anleitung",
    "Map background credits": "Credits der Hintergrundkarte",
    "Map has been attached to your account": "Die Karte wurde deinem Benutzerkonto zugeordnet.",
    "Map has been saved!": "Karte gespeichert!",
    "Map has been starred": "Die Karte wurde deiner Sternseite hinzugefügt",
    "Map has been unstarred": "Die Karte wurde von deiner Sternseite entfernt",
    "Map user content has been published under licence": "Der Benutzerinhalt wurde veröffentlicht unter der Lizenz",
    "Map's editors": "Kartenbearbeiter",
    "Map's owner": "Karteneigentümer",
    "max East": "Östliche Begrenzung",
    "max North": "Nördliche Begrenzung",
    "max South": "Südliche Begrenzung",
    "max West": "Westliche Begrenzung",
    "max zoom": "höchste Zoomstufe",
    "Measure distances": "Entfernungen messen",
    "Merge lines": "Linien zusammenführen",
    "mi": "mi",
    "miles": "Meilen",
    "min zoom": "kleinste Zoomstufe",
    "More controls": "Mehr Schaltflächen",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Muss ein gültiger CSS-Wert sein (z.B.: DarkBlue oder #123456)",
    "name": "Name",
    "nautical miles": "Nautische Meilen",
    "never": "nie",
    "new window": "neues Fenster",
    "next": "weiter",
    "NM": "NM",
    "No cache": "Kein Cache",
    "No licence has been set": "Keine Lizenz ausgewählt",
    "No results": "Keine Ergebnisse",
    "no": "Nein",
    "No.": "Nr.",
    "None": "Keine",
    "Number of desired classes (default 5)": "Anzahl der gewünschten Klassen (Standardwert 5)",
    "On the bottom": "An der Unterseite",
    "On the left": "An der linken Seite",
    "On the right": "An der rechten Seite",
    "On the top": "An der Oberseite",
    "Only visible layers' data": "Nur Daten aus eingeblendeten Ebenen",
    "opacity": "Deckkraft",
    "Opacity": "Deckkraft",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Link öffnen in…",
    "Open share & download panel": "Teilen & Herunterladen anzeigen",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Diesen Kartenauschnitt in einem Karten-Editor öffnen, um genauere Daten für OpenStreetMap bereitzustellen.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optionale Intensitätseigenschaft für die Heatmap",
    "Optional. Same as color if not set.": "Optional. Gleich wie Farbe, falls nicht ausgefüllt.",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "Gruppierungsradius überschreiben (Standard: 80)",
    "Override heatmap radius (default 25)": "Heatmap-Radius überschreiben (Standard: 25)",
    "parent window": "übergeordnetes Fenster",
    "Paste your data here": "Füge deine Daten hier ein",
    "Permalink": "Permalink",
    "Permanent credits background": "Dauerhafte Danksagung im Hintergrund",
    "Permanent credits": "Dauerhafte Danksagung",
    "Please be sure the licence is compliant with your use.": "Stelle bitte sicher, dass die Lizenz mit deiner Verwendung kompatibel ist.",
    "Please choose a format": "Bitte wähle ein Format",
    "Please enter the name of the property": "Bitte gib den Namen des Merkmals ein",
    "Please enter the new name of this property": "Bitte gib den neuen Namen des Merkmals ein",
    "Please save the map first": "Bitte zuerst die Karte speichern",
    "Popup (large)": "Popup (groß)",
    "Popup content style": "Popupinhaltstil",
    "Popup content template": "Popup Vorlage",
    "Popup shape": "Popupform",
    "Popup": "Popup",
    "Powered by uMap": "Karte zusammengestellt mit uMap",
    "previous": "zurück",
    "Problem in the response": "Fehler in der Antwort",
    "Properties imported:": "Importierte Merkmale:",
    "Provide an URL here": "Hier eine URL angeben",
    "Proxy request": "Proxyanforderung",
    "Quantiles": "Quantile",
    "Recent": "Neueste",
    "Remote data": "Ausgelagerte Daten",
    "Remove shape from the multi": "Form aus der Gruppe löschen",
    "Replace layer content": "Ebeneninhalt ersetzen",
    "Restore this version": "Diese Version wiederherstellen",
    "Save current edits": "Aktuelle Änderungen speichern",
    "Save map": "Karte speichern",
    "Save": "Speichern",
    "Saved center and zoom": "Mittelpunkt und Zoom gespeichert",
    "Search location": "Ort suchen",
    "Search": "Suche",
    "Secret edit link:": "Geheimer Bearbeitungslink:",
    "See full screen": "Vollbildanzeige",
    "See on OpenStreetMap": "Auf OpenStreetMap ansehen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Setze es auf Nein, um diese Ebene in der Diashow, im Datenbrowser, in der Popup-Navigation,... auszublenden.",
    "settings": "Einstellungen",
    "Shape properties": "Formeigenschaften",
    "Share and download": "Teilen und Herunterladen",
    "Share this link to open a customized map view": "Teile diesen Link, um eine angepasste Kartenansicht zu öffnen",
    "Short credits": "Kurze Credits",
    "Short link": "Kurzlink",
    "Show this layer in the caption": "Legende im Info-Fenster anzeigen.",
    "Show/hide layer": "Ebene einblenden/ausblenden",
    "Side panel": "Seitenleiste",
    "Simple link: [[https://example.com]]": "Einfacher Link: [[http://beispiel.com]]",
    "Simplify": "Vereinfachen",
    "Skipping unknown geometry.type: {type}": "Überspringe unbekannten Geometrietyp: {type}",
    "Slideshow": "Diashow",
    "Sort key": "Sortierschlüssel",
    "Split line": "Linie teilen",
    "Star this map": "Diese Karte mit einem Sternchen versehen",
    "Start a hole here": "Hier ein Loch beginnen",
    "Start slideshow": "Diashow starten",
    "Stop editing": "Bearbeitung beenden",
    "Stop slideshow": "Diashow beenden",
    "Street": "Straße",
    "stroke": "Umrisslinie",
    "Supported scheme": "Unterstütztes Schema",
    "Supported variables that will be dynamically replaced": "Unterstützte Variablen, die dynamisch ersetzt werden",
    "Symbol": "Symbol",
    "Table": "Tabelle",
    "Text color for the cluster label": "Textfarbe für die Gruppierungsbezeichnung",
    "Text formatting": "Textformatierung",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Der Name des Attributes der zur Beschriftung benutzt werden soll z.B. (\"name\"). Es können auch Eigenschaften in Klammern benutzt werden, um mehr als eine zu verwenden oder mit statischem Inhalt zu mischen (z. B.: „&lcub;name&rcub; in &lcub;place&rcub;“)",
    "The name of the property to use as feature unique identifier.": "Name des Merkmals, das als eindeutiger Identifikationsschlüssel für jedes Element verwendet wird",
    "The zoom and center have been modified.": "Mittelpunkt und Zoomstufe sind angepasst.",
    "TMS format": "TMS-Format",
    "To use if remote server doesn't allow cross domain (slower)": "Anzuwenden, wenn der Zielserver kein Cross Origin Resource Sharing (CORS) erlaubt (langsamer).",
    "To zoom": "Bis Zoomstufe",
    "Toggle edit mode (⇧+Click)": "Bearbeitungsmodus umschalten (⇧+Mausklick)",
    "Toggle edit mode": "Bearbeitungsmodus umschalten",
    "Transfer shape to edited feature": "Form in bearbeitetes Element überführen",
    "Transform to lines": "In Linien umwandeln",
    "Transform to polygon": "In Fläche umwandeln",
    "Type a place name or coordinates": "Gib einen Ortsnamen oder Koordinaten ein",
    "Type char or paste emoji": "Gib ein Zeichen ein oder füge ein Emoji aus der Zwischenablage ein.",
    "Type of layer": "Ebenentyp",
    "Unable to detect format of file {filename}": "Format der Datei {filename} kann nicht erkannt werden",
    "Untitled layer": "Unbenannte Ebene",
    "Untitled map": "Unbenannte Karte",
    "Update permissions and editors": "Berechtigungen und Bearbeiter ändern",
    "Update permissions": "Berechtigungen aktualisieren",
    "Update who can see and edit the map": "Ändere, wer deine Karte sehen und bearbeiten kann.",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Nutze aktuelle Kartenansicht",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Nutze Platzhalter mit Elementmerkmalen innerhalb der Klammern, z.B. &#123;name&#125;, sie werden dynamisch durch die entsprechenden Werte ersetzt.",
    "User content credits": "Credits der Benutzerinhalte",
    "User interface options": "Einstellungen Benutzeroberfläche",
    "User location": "Benutzerstandort",
    "Verify remote URL": "Remote-URL überprüfen",
    "Versions": "Versionen",
    "View Fullscreen": "Vollbild ansehen",
    "View": "Ansicht",
    "Visibility: {status}": "Sichtbarkeit: {status}",
    "weight": "Stärke",
    "Where do we go from here?": "Wie geht es weiter?",
    "Whether to display or not polygons paths.": "Umrisslinie von Flächen anzeigen oder nicht anzeigen.",
    "Whether to fill polygons with color.": "Ob Flächen mit Farbe gefüllt werden.",
    "Who can edit \"{layer}\"": "Wer darf \"{layer}\" bearbeiten",
    "Who can edit": "Wer darf bearbeiten",
    "Who can view": "Wer darf betrachten",
    "width": "Breite",
    "Will be displayed in the bottom right corner of the map": "Wird in rechten unteren Ecke der Karte angezeigt",
    "Will be permanently visible in the bottom left corner of the map": "Wird in der unteren linken Ecke der Karte permanent sichtbar sein",
    "Will be visible in the caption of the map": "Wird in der Überschrift der Karte angezeigt",
    "yes": "Ja",
    "Zoom in": "Hineinzoomen",
    "Zoom level for automatic zooms": "Zommstufe für automatischen Zoom",
    "Zoom out": "Herauszoomen",
    "Zoom to layer extent": "Auf Ebenenausdehnung zoomen",
    "Zoom to the next": "Zum nächsten zoomen",
    "Zoom to the previous": "Zum vorherigen zoomen",
    "Zoom to this feature": "Auf dieses Element zoomen",
    "{area}&#8239;acres": "{area} Hektar",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} Fehler während des Imports: {message}",
    "{delay} seconds": "{delay} Sekunden",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} Meilen",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Name und Titel der Karte bearbeiten",
    "Map advanced properties": "Erweiterte Eigenschaften der Karte",
    "Edit map details": "Kartendetails bearbeiten",
    "Back to browser": "Zurück zum Browser",
    "Toggle size": "Größe umschalten",
    "Display the caption control": "Anzeige der Beschriftungssteuerung",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "Von",
    "Until": "Bis",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Beispiel: key1,key2|Beschriftung 2,key3|Beschriftung 3|checkbox",
    "Edit in OpenStreetMap": "Bearbeiten in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Die Spalten für Breiten- und Längengrad können nicht bestimmt werden.",
    "Back to layers": "Zurück zu den Kartenebenen",
    "Filters": "Filter",
    "Comma separated list of properties to use when filtering features by text input": "Kommagetrennte Liste der Merkmale, welche beim Filtern von Elementen verwendet werden sollen",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Durch Kommata getrennte Liste von Eigenschaften, die für Filter verwendet werden sollen (z. B.: mykey,otherkey). Um die Beschriftung zu steuern, füge einen | hinzu (z. B.: mykey|My Key,otherkey|Other Key). Um den Typ des Eingabefeldes zu steuern, füge ihn nach einem weiteren | hinzu (z. B.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Erlaubte Werte für den Eingabefeldtyp sind checkbox (Standard), radio, Zahl, date und datetime.",
    "Search keys": "Suchbegriffe",
    "Filters keys": "Filterbegriffe",
    "Filter data": "Daten filtern",
    "Search map features…": "Suche auf der Karte...",
    "Reset all": "Alles zurücksetzen",
    "Open browser": "Browser öffnen",
    "Open caption": "Info-Fenster öffnen",
    "Your map has been created with an anonymous account!": "Ihre Karte wurde mit einem anonymen Konto erstellt!",
    "Real-time collaboration": "Echtzeit-Zusammenarbeit",
    "Cannot parse data": "Daten können nicht geparst werden",
    "Start typing...": "Beginne mit der Eingabe...",
    "No result": "Keine Ergebnisse",
    "Data browser": "Datenbrowser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Wenn Sie eine URL angeben, kann uMap die entfernten Daten in einen Layer kopieren oder diese URL als entfernte Quelle des Layers hinzufügen. In diesem Fall werden die Daten immer von dieser URL geholt und sind somit auf dem neuesten Stand, aber es ist nicht möglich, sie in uMap zu bearbeiten.",
    "Overpass supported expressions": "Von Overpass unterstützte Abfrage",
    "key (eg. building)": "key (z.b. building)",
    "!key (eg. !name)": "!key (z.B. !name)",
    "key=value (eg. building=yes)": "key=value (z.B. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (z.B. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (z.B. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (z.B.. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Weitere Informationen zur Overpass-Syntax",
    "For more complex needs, see": "Für komplexere Abfragen, siehe",
    "Choose data": "Daten auswählen",
    "Choose the format": "Wähle das Datenformat",
    "Choose the layer": "Ebenenauswahl",
    "Layer name": "Ebenenname",
    "Choose import mode": "Wähle Importmodus",
    "Copy into the layer": "In die Ebene kopieren",
    "Link to the layer as remote data": "Link zur Ebene als Remote-Data",
    "Condition": "Bedingung",
    "key=value or key!=value": "key=value oder key!=value",
    "Are you sure you want to delete this rule?": "Bist du sicher, dass du diese Regel löschen willst?",
    "empty rule": "leere Regel",
    "Conditional style rules": "Bedingte Stileregeln",
    "Add rule": "Regel hinzufügen",
    "Browser: data": "Browser: Daten",
    "Browser: layers": "Browser: Ebenen",
    "Browser: filters": "Browser: Filter",
    "Enable real-time collaboration": "Aktiviere Echtzeit-Zusammenarbeit",
    "✅ Copied!": "✅ Kopiert!",
    "Choose a dataset": "Datensatz auswählen",
    "Choose this dataset": "Diesen Datensatz auswählen",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematische Daten von OpenStreetMap",
    "Choose a theme": "Thema auswählen",
    "Symplify all geometries to points": "Alle Geometrien zu Punkten vereinfachen",
    "Choose this data": "Diese Daten auswählen",
    "Search admin boundary": "Administrative Grenze suchen",
    "Please choose a theme and a boundary first.": "Bitte wähle zuerst ein Thema und eine administrative Grenze.",
    "Expression": "Ausdruck",
    "Geometry mode": "Geometriemodus",
    "Only geometry centers": "Nur Geometriezentren",
    "Search area": "Suchgebiet",
    "Type area name, or let empty to load data in current map view": "Gib den Namen des Gebiets ein, oder lass dieses Feld leer um die Daten in dem aktuellen Kartenausschnitt zu laden",
    "Data successfully imported!": "Daten erfolgreich importiert!",
    "Clear data": "Daten Löschen",
    "Remove layers": "Ebene entfernen",
    "Categorized": "Kategorisiert",
    "Alphabetical": "Alphabetisch",
    "Category property": "Kategoriekriterium",
    "Color palette": "Farbpalette",
    "Categories": "Kategorien",
    "Comma separated list of categories.": "Kommagetrennte Liste von Kategorien.",
    "Categories mode": "Kategoriemodus",
    "Remove filter for this column": "Entferne Filter für diese Spalte",
    "Add filter for this column": "Füge Filter für diese Spalte hinzu",
    "Rename this column": "Spalte umbenennen",
    "Delete this column": "Spalte löschen",
    "Name “{name}” should not contain a dot.": "Der Name \"{name}\" darf keinen Punkt enthalten.",
    "This name already exists: “{name}”": "Dieser Name existiert bereits: \"{name}\"",
    "Delete selected rows": "Ausgewählte Zeilen löschen",
    "Found {count} rows. Are you sure you want to delete all?": "{count} Zeilen gefunden. Bist du sicher, dass du diese löschen willst?",
    "Expression is empty": "Ausdruck ist leer",
    "OK": "OK",
    "Cancel": "Abbrechen",
    "Attach map to a team": "Die Karte einem Team zuordnen",
    "Display the polygon inverted": "Das Polygon invertiert anzeigen",
    "Proportional circles": "Kreise mit proportionaler Größe",
    "Property name to compute circles": "Name der Eigenschaft zur Berechnung der Kreise",
    "Min circle radius": "Minimaler Kreis-Radius",
    "Max circle radius": "Maximaler Kreis-Radius",
    "Display the open browser control": "Browsersteuerung Öffnen anzeigen",
    "Copy as GeoJSON": "Als GeoJSON kopieren",
    "Please zoom in to edit the geometry": "Bitte hineinzoomen, um die Geometrie zu editieren",
    "New map": "Neue Karte",
    "My maps": "Meine Karten",
    "My teams": "Meine Teams",
    "My profile": "Mein Profil",
    "Type new owner's username": "Benutzernamen des neuen Besitzers eingeben...",
    "Type editor's username": "Benutzernamen eingeben für Bearbeitungsrechte",
    "Map": "Karte",
    "Manage collaborators": "Mitwirkende verwalten",
    "show/hide all layers": "Alle Ebenen ein-/ausblenden",
    "zoom to data extent": "Auf Ebenenausdehnung zoomen",
    "download visible data": "Daten im sichtbaren Bereich herunterladen",
    "Import helpers": "Import-Assistenten",
    "Import helpers will fill the URL field for you.": "Import-Assistenten füllen für dich das URL-Eingabefeld aus.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Entwurf speichern",
    "No data has been found for import": "Es wurden keine Daten zum Importieren gefunden",
    "Successfully imported {count} feature(s)": "Erfolgreich {count} Feature(s) importiert",
    "Disconnected": "Getrennt",
    "You must be logged in": "Du musst angemeldet sein",
    "on hover": "beim Draufzeigen",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Laden der externen Daten fehlgeschlagen für Ebene \"{layer}\" mit der URL \"{url}\"<br data-mce-bogus=\"1\">",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Zerlegen/parsen der externen Daten fehlgeschlagen für Ebene \"{layer}\" mit der URL \"{url}\"<br data-mce-bogus=\"1\">",
    "Import failed: invalid data": "Import fehlgeschlagen: ungültige Daten",
    "Anonymous": "Anonym",
    "created at {date}": "erstellt am {date}<br data-mce-bogus=\"1\">",
    "modified at {date}": "bearbeitet am {date}<br data-mce-bogus=\"1\">",
    "Default zoom": "Standard-Zoomstufe",
    "Default latitude": "Standard-Breitengrad",
    "Default longitude": "Standard-Längengrad",
    "Edit map default view": "Standardansicht der Karte bearbeiten",
    "Use current center and zoom": "Aktuelle Position und Zoomstufe speichern",
    "Layer permalink": "Permalink für Ebene",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("de", locale)
L.setLocale("de")
