.importers h3 {
  font-size: 1rem;
}
.importers h4 {
  font-size: .9rem;
}

.importers ul [type=button] {
    background: none;
    font-size: 0.75rem;
    border: none;
    width: initial;
    display: inline-block;
    line-height: 1rem;
}
.importer h3:before {
    background-image: url(../img/importers/random.svg);
    background-repeat: no-repeat;
    background-position: center;
    content: '';
    width: 36px;
    height: 36px;
    display: inline-block;
    margin-inline-end: 10px;
    background-size: 100%;
    vertical-align: -10px;
}
.importers ul [type=button]:before {
    background-image: url(../img/importers/random.svg);
    background-repeat: no-repeat;
    background-position: center;
    content: '';
    width: 100%;
    height: 50px;
    display: block;
    margin-bottom: var(--gutter);
}
.importer.geodatamine h3:before,
.importers ul .geodatamine:before {
    background-image: url(../img/importers/geodatamine.svg);
}
.importer.communesfr h3:before,
.importers ul .communesfr:before {
    background-image: url(../img/importers/communesfr.svg);
}
.importer.cadastrefr h3:before,
.importers ul .cadastrefr:before {
    background-image: url(../img/importers/cadastrefr.svg);
}
.importer.overpass h3:before,
.importers ul .overpass:before {
    background-image: url(../img/importers/overpass.svg);
}
.importer.datasets h3:before,
.importers ul .datasets:before {
    background-image: url(../img/importers/datasets.svg);
}
.importer.banfr h3:before,
.importers ul .banfr:before {
    background-image: url(../img/importers/banfr.svg);
}
.importer table {
    width: calc(var(--dialog-width) - 2 * var(--box-margin));
}
