const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# en znak za prvi glavni naslov",
    "## two hashes for second heading": "## dva znaka za drugi naslov",
    "### three hashes for third heading": "### trije znaki za tretji naslov",
    "**double star for bold**": "**dvojna zvezdica za krepko pisavo**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 dan",
    "1 hour": "1 ura",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Z vejilo ločen seznam števil, ki določajo vzorec poteze. Na primer »5, 10, 15«.",
    "About": "O zemljevidu",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Omogoči predstavitveni način",
    "Add a layer": "Dodaj plast",
    "Add a line to the current multi": "Dodaj črto k trenutnemu večtočkovnemu predmetu",
    "Add a new property": "Dodaj novo lastnost",
    "Add a polygon to the current multi": "Dodaj mnogokotnik k trenutnemu večtočkovnemu predmetu",
    "Add image URL": "Add image URL",
    "Advanced actions": "Napredna dejanja",
    "Advanced properties": "Napredne nastavitve",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Vse lastnosti so uvožene.",
    "Allow interactions": "Dovoli interakcije",
    "Allow scroll wheel zoom?": "Ali naj se dovoli približanje pogleda s kolescem miške?",
    "always": "vedno",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Ali ste prepričani, da želite klonirati ta zemljevid in vse njegove podatkovne plasti?",
    "Are you sure you want to delete this map?": "Ali ste prepričani, da želite izbrisati ta zemljevid?",
    "Are you sure you want to delete this property on all the features?": "Ali res želite izbrisati to lastnost pri vseh vstavljenih predmetih?",
    "Are you sure you want to restore this version?": "Ali res želite obnoviti to različico?",
    "Attach the map to my account": "Attach the map to my account",
    "attribution": "pripisovanje",
    "Auto": "Samodejno",
    "Automatic": "Samodejno",
    "Autostart when map is loaded": "Samodejno zaženi, ko je zemljevid naložen",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Bucika",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Prebrskaj podatke",
    "by": "–",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Naslov",
    "Center map on your location": "Postavi trenutno točko v središče zemljevida",
    "Change map background": "Zamenjaj ozadje zemljevida",
    "Change tilelayers": "Spremeni plasti",
    "Change": "Change",
    "Choose the data format": "Izbor zapisa podatkov",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Točka",
    "clear": "počisti",
    "Click last point to finish shape": "Kliknite na zadnjo točko za dokončanje risanja oblike",
    "Click to add a marker": "Kliknite za dodajanje označbe",
    "Click to continue drawing": "Kliknite za nadaljevanje risanja",
    "Click to edit": "Kliknite za urejanje",
    "Click to start drawing a line": "Kliknite za začetek risanja črte",
    "Click to start drawing a polygon": "Kliknite za začetek risanja mnogokotnika",
    "Clone of {name}": "Klon zemljevida {name}",
    "Clone this feature": "Kloniraj predmet",
    "Clone this map": "Kloniraj zemljevid",
    "Clone": "Kloniraj",
    "Close": "Zapri",
    "Clustered": "Zbrano območje",
    "Clustering radius": "Radij zbranega omgočja",
    "collapsed": "zloženo",
    "color": "barva",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Z vejico, tabulatorjem ali podpičjem ločene vrednosti, nakazane prek SRS WGS84. Uvoženi so le točkovni podatki. Med uvozom bo preiskan stolpec glav za podatke geografske »širine« in«dolžine«, neupoštevajoč velikost pisave. Vsi ostali stolpci bodo uvoženi kot lastnosti predmetov.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Nadaljuj z risanjem črte",
    "Coordinates": "Koordinate",
    "copy": "copy",
    "Credits": "Zasluge",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Ali želite omogočiti trenutni pogled namesto privzetega pogleda zemljevida?",
    "Custom background": "Ozadje po meri",
    "Custom overlay": "Custom overlay",
    "dash array": "črtkano",
    "Data is browsable": "Podatke je mogoče brskati",
    "Datalayers": "Datalayers",
    "Default interaction options": "Privzete možnosti interakcije",
    "Default properties": "Privzete lastnosti",
    "Default shape properties": "Privzete možnosti oblike",
    "Default view": "Default view",
    "Default zoom level": "Privzeta raven približanja",
    "Default": "Privzeto",
    "Default: name": "Privzeto: ime",
    "Define link to open in a new window on polygon click.": "Določitev povezave za odpiranje v novem oknu ob kliku na mnogokotnik.",
    "define": "določi",
    "Delay between two transitions when in play mode": "Zamik med prehodi v načinu predvajanja",
    "Delete layer": "Izbriši plast",
    "Delete this feature": "Izbriši ta predmet",
    "Delete this shape": "Izbriši ta predmet",
    "Delete this vertex (Alt+Click)": "Izbriši to točko (Alt+Klik)",
    "Delete": "Izbriši",
    "description": "opis",
    "Direct link": "Direct link",
    "Directions from here": "Navigacija od tu",
    "Display label": "Pokaži oznako",
    "Display measure": "Pokaži merilo",
    "display name": "prikazno ime",
    "Display on load": "Prikaži ob nalaganju",
    "Display the control to open OpenStreetMap editor": "Pokaži gumb za odpiranje urejevalnika OpenstreetMap",
    "Display the embed control": "Pokaži gumb za vstavljanje predmetov",
    "Display the fullscreen control": "Pokaži gumb za preklop v celozaslonski način",
    "Display the locate control": "Pokaži gumb za omogočanje lokacijskih storitev",
    "Display the measure control": "Pokaži gumb za merjenje razdalij",
    "Display the search control": "Pokaži možnosti za iskanje",
    "Display the tile layers control": "Pokaži gumb za upravljanje s sličicami plasti",
    "Display the zoom control": "Pokaži gumb za približanje",
    "Do you want to display a caption bar?": "Ali želite pokazati naslovno vrstico?",
    "Do you want to display a minimap?": "Ali želite prikazati mini zemljevid?",
    "Do you want to display a panel on load?": "Ali želite pokazati bočno okno ob zagonu?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Ali želite prikazati pojavno okno noge?",
    "Do you want to display the scale control?": "Ali želite prikazati gumbe merila?",
    "Do you want to display the «more» control?": "Ali želite pokazati orodno vrstico »več možnosti«?",
    "Download": "Prenos",
    "Drag to reorder": "Potegni za prerazvrstitev",
    "Draw a marker": "Nariši označbo",
    "Draw a polygon": "Nariši mnogokotnik",
    "Draw a polyline": "Nariši črto v več koleni",
    "Drawing": "Drawing",
    "Drop": "Kapljica",
    "Dynamic properties": "Dinamične lastnosti",
    "Dynamic": "Dinamično",
    "Edit feature's layer": "Uredi plast predmeta",
    "Edit properties in a table": "Uredi lastnosti v razpredelnici",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Uredi predmet",
    "Edit": "Uredi",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Vstavi zemljevid",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Prazno",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Napaka v naslovu URL plasti",
    "Exit Fullscreen": "Končaj celozaslonski način",
    "expanded": "razširjeno",
    "Extract shape to separate feature": "Izloči obliko v ločen predmet",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Pridobi podatke vsakič, ko se spremeni pogled zemljevida.",
    "fill color": "barva polnila",
    "fill opacity": "prosojnost polnila",
    "fill": "polnilo",
    "Fit all data": "Fit all data",
    "Format": "zapis",
    "From zoom": "Iz približanja",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (le povezava)",
    "GeoRSS (title + image)": "GeoRSS (naslov in slika)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Skoči na »{feature}«",
    "Heatmap intensity property": "Lastnosti jakosti vročinskih točk",
    "Heatmap radius": "Radij vročinskih točk",
    "Heatmap": "Vročinske točke",
    "height": "višina",
    "Help": "Pomoč",
    "hidden": "skrito",
    "Hide controls": "Skrij orodja",
    "Home": "Začetna stran",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Kako močno naj bodo poenostavljene prte na posamezni ravni približanja (močno = boljše delovanje in prijetnejši videz ali malo = bolj natančen prikaz)",
    "icon opacity": "icon opacity",
    "Icon shape": "Oblika ikone",
    "Icon symbol": "Simbol ikone",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Uvozi podatke",
    "Import in a new layer": "Uvozi v novo plast",
    "Imports all umap data, including layers and settings.": "Uvozi vse podatke umap, vključno s plastmi in nastavitvami.",
    "Include full screen link?": "Ali želite vključiti povezavo do celozaslonskega prikaza?",
    "Inherit": "Prevzemi",
    "inherit": "prevzemi",
    "Interaction options": "Možnosti interakcije",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Neveljavni podatki umap v datoteki {filename}",
    "Invalid umap data": "Neveljavni podatki umap",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Ohrani trenutno vidne plasti",
    "kilometers": "kilometri",
    "km": "km",
    "Label direction": "Usmerjenost oznake",
    "Label key": "Oznaka",
    "Labels are clickable": "Oznake so klikljive",
    "Latest feature": "Latest feature",
    "Latitude": "Geografska širina",
    "Layer properties": "Lastnosti plasti",
    "Layer": "Plast",
    "Licence": "Dovoljenje",
    "licence": "dovoljenje",
    "Limit bounds": "Omejitev področja",
    "Link to view the map": "Link to view the map",
    "Link to…": "Povezava z ...",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Poln seznam zaslug",
    "Longitude": "Geografska dolžina",
    "Make main shape": "Nastavi kot glavni predmet",
    "Manage layers": "Upravljanje s plastmi",
    "Manual": "Manual",
    "Map background credits": "Zasluge ozadij zemljevida",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Zemljevid je shranjen!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Uporabniška vsebina  zemljevida je objavljena z dovoljenjem",
    "Map's editors": "Uredniki zemljevida",
    "Map's owner": "Lastnik zemljevida",
    "max East": "najbolj vzhodno",
    "max North": "najbolj severno",
    "max South": "najbolj južno",
    "max West": "najbolj zahodno",
    "max zoom": "največje približanje",
    "Measure distances": "Merjenje razdalj",
    "Merge lines": "Združi črte",
    "mi": "mi",
    "miles": "milje",
    "min zoom": "največje oddaljanje",
    "More controls": "Več orodij",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Vrednost mora biti skladna z zapisom CSS (na primer: DarkBlue ali #123456)",
    "name": "ime",
    "nautical miles": "navtične milje",
    "never": "nikoli",
    "new window": "novo okno",
    "next": "naslednji",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "Ni določenega dovoljenja za uporabo",
    "No results": "Ni zadetkov",
    "no": "ne",
    "No.": "No.",
    "None": "Brez",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Na dnu",
    "On the left": "Na levi",
    "On the right": "Na desni",
    "On the top": "Na vrhu",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "prosojnost",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Odpri povezavo v ...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Odpri obseg zemljevida v urejevalniku za prenos podrobnejših podatkov na OpenStreetMap.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Izbirna lastnost jakosti vročinskih točke",
    "Optional. Same as color if not set.": "Izbirno. Enako, kot nedoločena barva.",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "Prekliči radij združevanja (privzeto 80)",
    "Override heatmap radius (default 25)": "Prekliči radij vročinskih točk (privzeto 25)",
    "parent window": "glavno okno",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Prepričajte se, da je zemljevid uporabljen v skladu z dovoljenjem.",
    "Please choose a format": "Izbrati je treba zapis",
    "Please enter the name of the property": "Ime lastnosti",
    "Please enter the new name of this property": "Novo ime lastnosti",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "Predloga pojavne vsebine",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "predhodni",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Lastnosti so uvožene:",
    "Provide an URL here": "Vpis naslova URL",
    "Proxy request": "Zahteva posredniškega strežnika",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Oddaljeni podatki",
    "Remove shape from the multi": "Odstrani obliko iz večtočkovnega predmeta",
    "Replace layer content": "Zamenjaj vsebino plasti",
    "Restore this version": "Obnovi različico",
    "Save current edits": "Shrani urejanje",
    "Save map": "Save map",
    "Save": "Shrani",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Preišči mesto",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Pokaži v celozaslonskem načinu",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Neizbrana možnost skrije plast med predstavitvijo,  v pregledovalniku podatkov, ...",
    "settings": "settings",
    "Shape properties": "Lastnosti oblike",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Kratek zapis zaslug",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Pokaži / Skrij plast",
    "Side panel": "Bočno okno",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Poenostavi",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "Predstavitev",
    "Sort key": "Razvrščanje",
    "Split line": "Ločitvena črta",
    "Star this map": "Star this map",
    "Start a hole here": "Začni z vrisovanjem luknje",
    "Start slideshow": "Začni s predstavitvijo",
    "Stop editing": "Končaj z urejanjem",
    "Stop slideshow": "Zaustavi predstavitev",
    "Street": "Street",
    "stroke": "prečrtano",
    "Supported scheme": "Podprta shema",
    "Supported variables that will be dynamically replaced": "Podprte spremenljivke, ki bodo dinamično zamenjane",
    "Symbol": "Symbol",
    "Table": "Razpredelnica",
    "Text color for the cluster label": "Barva besedila za oznako polja",
    "Text formatting": "Oblikovanje besedila",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "Zapis TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Za uporabo, ko oddaljeni stražnik ne dovoli vzporednih domen (počasneje)",
    "To zoom": "Za približanje",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Prenesi obliko na urejen predmet",
    "Transform to lines": "Pretvori v črte",
    "Transform to polygon": "Pretvori v mnogokotnik",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Vrsta plasti",
    "Unable to detect format of file {filename}": "Ni mogoče zaznati zapisa datoteke {filename}",
    "Untitled layer": "Neimenovana plast",
    "Untitled map": "Neimenovan zemljevid",
    "Update permissions and editors": "Posodobitev dovoljenj in urednikov",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Naslov URL",
    "URL": "URL",
    "Use current bounds": "Uporabi trenutne meje",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Uporabi ročnike lastnosti predmetov, pri zapisu podatkov. Vpis &#123;ime&#125; bo dinamično zamenjan z ustrezno vrednostjo.",
    "User content credits": "Zasluge za uporabniško vsebino",
    "User interface options": "Možnosti uporabniškega vmesnika",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Različice",
    "View Fullscreen": "Pokaži v celozaslonskem načinu",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "debelina",
    "Where do we go from here?": "Kam naj se usmerimo?",
    "Whether to display or not polygons paths.": "Ali naj bodo izrisane daljice mnogokotnika.",
    "Whether to fill polygons with color.": "Ali naj bodo mnogokotniki zapolnjeni z barvo.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Kdo lahko ureja",
    "Who can view": "Kdo lahko vidi",
    "width": "širina",
    "Will be displayed in the bottom right corner of the map": "Prikazan bo v spodnjem desnem kotu zemljevida",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Prikazan bo v naslovu zemljevida",
    "yes": "da",
    "Zoom in": "Približaj",
    "Zoom level for automatic zooms": "Raven za samodejno približanje",
    "Zoom out": "Oddalji",
    "Zoom to layer extent": "Približaj na obseg plasti",
    "Zoom to the next": "Približaj na naslednjo točko",
    "Zoom to the previous": "Približaj na predhodno točko",
    "Zoom to this feature": "Približaj k predmetu",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "Zaznane so napake ({count}) med uvozom: {message}",
    "{delay} seconds": "{delay} sekund",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode"
}
L.registerLocale("sl", locale)
L.setLocale("sl")
